@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu-tab.h,v 1.2 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: amenu-tab.h,v 1.8 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_TAB_H
@@ -33,14 +33,14 @@
 
 /* ưޡ˥塼 */
 
-static menu_t	ls_menu_auto_mark[1 + 1 + ((1 + 3) * AUTO_MARK_MAX_N) + 1];
+static menu_t	ls_menu_auto_mark[1 + 1 + ((1 + 5) * AUTO_MARK_MAX_N) + 1];
 
 static menu_t	ls_menu_appoint_item
 		[1 + 1 + (AUTO_MARK_APPOINT_ITEM_MAX_N * 2) + 1];
 
 static menu_t	ls_menu_auto_mark_edit[] = {
 	{
-		"/Edit",
+		"/edit",
 		"<Branch>",
 		'\0',
 		"",
@@ -49,7 +49,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Title",
+		"/edit/title",
 		"<Title>",
 		'\0',
 		"",
@@ -59,7 +59,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 	},
 /* Target */
 	{
-		"/Edit/Target",
+		"/edit/target",
 		"<Branch>",
 		'T',
 		"",
@@ -68,7 +68,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Title",
+		"/edit/target/title",
 		"<Title>",
 		'\0',
 		"",
@@ -77,7 +77,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Monster",
+		"/edit/target/monster",
 		"<Item>",
 		'X',
 		"",
@@ -86,7 +86,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Item",
+		"/edit/target/item",
 		"<Item>",
 		'I',
 		"",
@@ -95,7 +95,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Door",
+		"/edit/target/door",
 		"<Item>",
 		'D',
 		"",
@@ -104,7 +104,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Trap",
+		"/edit/target/trap",
 		"<Item>",
 		'T',
 		"",
@@ -113,7 +113,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Member",
+		"/edit/target/member",
 		"<Item>",
 		'P',
 		"",
@@ -122,7 +122,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Unchange",
+		"/edit/target/unchange",
 		"<Item>",
 		'U',
 		"",
@@ -131,7 +131,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Target/Clear",
+		"/edit/target/clear",
 		"<Item>",
 		'C',
 		"",
@@ -141,7 +141,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 	},
 /* Dist */
 	{
-		"/Edit/Dist",
+		"/edit/dist",
 		"<Branch>",
 		'D',
 		"",
@@ -150,7 +150,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Dist/Title",
+		"/edit/dist/title",
 		"<Title>",
 		'\0',
 		"",
@@ -159,7 +159,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Dist/Near",
+		"/edit/dist/near",
 		"<Item>",
 		'N',
 		"",
@@ -168,7 +168,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Dist/Medium",
+		"/edit/dist/medium",
 		"<Item>",
 		'M',
 		"",
@@ -177,7 +177,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Dist/Far",
+		"/edit/dist/far",
 		"<Item>",
 		'F',
 		"",
@@ -187,7 +187,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 	},
 /* Action */
 	{
-		"/Edit/Action",
+		"/edit/action",
 		"<Branch>",
 		'A',
 		"",
@@ -196,7 +196,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Title",
+		"/edit/action/title",
 		"<Title>",
 		'\0',
 		"",
@@ -205,7 +205,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Fight",
+		"/edit/action/fight",
 		"<Item>",
 		'F',
 		"",
@@ -214,7 +214,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Throw",
+		"/edit/action/throw",
 		"<Item>",
 		'T',
 		"",
@@ -223,7 +223,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Steal",
+		"/edit/action/steal",
 		"<Item>",
 		'S',
 		"",
@@ -232,7 +232,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Tail",
+		"/edit/action/tail",
 		"<Item>",
 		'L',
 		"",
@@ -241,7 +241,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Pick up",
+		"/edit/action/pick up",
 		"<Item>",
 		'P',
 		"",
@@ -250,7 +250,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Open",
+		"/edit/action/open",
 		"<Item>",
 		'O',
 		"",
@@ -259,7 +259,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Close",
+		"/edit/action/close",
 		"<Item>",
 		'C',
 		"",
@@ -268,7 +268,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Jam",
+		"/edit/action/jam",
 		"<Item>",
 		'J',
 		"",
@@ -277,7 +277,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Disarm",
+		"/edit/action/disarm",
 		"<Item>",
 		'D',
 		"",
@@ -286,7 +286,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Break",
+		"/edit/action/break",
 		"<Item>",
 		'B',
 		"",
@@ -295,7 +295,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Peep",
+		"/edit/action/peep",
 		"<Item>",
 		'P',
 		"",
@@ -304,7 +304,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Action/Search",
+		"/edit/action/search",
 		"<Item>",
 		'S',
 		"",
@@ -314,7 +314,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 	},
 /* Condition */
 	{
-		"/Edit/Condition",
+		"/edit/condition",
 		"<Branch>",
 		'C',
 		"",
@@ -323,7 +323,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Condition/Title",
+		"/edit/condition/title",
 		"<Title>",
 		'\0',
 		"",
@@ -332,7 +332,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Condition/Nearest",
+		"/edit/condition/nearest",
 		"<Item>",
 		'N',
 		"",
@@ -341,7 +341,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Condition/Disperse",
+		"/edit/condition/disperse",
 		"<Item>",
 		'D',
 		"",
@@ -350,7 +350,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Condition/Stagger",
+		"/edit/condition/stagger",
 		"<Item>",
 		'S',
 		"",
@@ -359,7 +359,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Condition/Own",
+		"/edit/condition/own",
 		"<Item>",
 		'O',
 		"",
@@ -369,7 +369,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 	},
 /* Appoint Item */
 	{
-		"/Edit/Appoint item",
+		"/edit/appoint item",
 		"<Branch>",
 		'I',
 		"",
@@ -377,9 +377,19 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		cb_menu_auto_mark_appoint_item, NULL,
 		FLG_NULL,
 	},
+/* Macro */
+	{
+		"/edit/macro",
+		"<OpenWinItem>",
+		'M',
+		"",
+		N_MSG_MENU_AUTO_MARK_EDIT_MACRO, "",
+		cb_menu_auto_mark_macro, NULL,
+		FLG_NULL,
+	},
 /**/
 	{
-		"/Edit/Continue",
+		"/edit/continue",
 		"<CheckItem>",
 		'O',
 		"",
@@ -388,7 +398,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit/Priority",
+		"/edit/priority",
 		"<CheckItem>",
 		'P',
 		"",
@@ -396,6 +406,24 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		cb_menu_auto_mark_priority, NULL,
 		FLG_NULL,
 	},
+	{
+		"/edit/copy",
+		"<Item>",
+		'W',
+		"",
+		N_MSG_MENU_AUTO_MARK_COPY, "",
+		cb_menu_auto_mark_copy_small, NULL,
+		FLG_NULL,
+	},
+	{
+		"/edit/paste",
+		"<Item>",
+		'Y',
+		"",
+		N_MSG_MENU_AUTO_MARK_PASTE, "",
+		cb_menu_auto_mark_paste_small, NULL,
+		FLG_NULL,
+	},
 	{
 		"",
 		"",
