@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,61 +25,27 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.42 2004/12/20 22:40:42 bowkenken Exp $
+* $Id: amenu.c,v 1.53 2006/01/14 15:59:04 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-#include	"item.h"
-/*#include	"spell.h"*/
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-/*#include	"pet.h"*/
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-#include	"menu.h"
-#include	"amenu.h"
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-#include	"dun-prot.h"
-/*#include	"town-prot.h"*/
-#include	"item-prot.h"
-/*#include	"spell-prot.h"*/
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-/*#include	"pet-prot.h"*/
-/*#include	"fight-prot.h"*/
-/*#include	"fx-prot.h"*/
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-#include	"menu-prot.h"
-/*#include	"tmenu-prot.h"*/
-#include	"amenu-prot.h"
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* ưޡ
+***************************************************************/
 
-/**/
+#define	AMENU_C
+#include	"inc.h"
 
-/* ưޡ */
+/***************************************************************/
 
 static auto_mark_t	ls_auto_mark[LS_MBR_MAX_N][AUTO_MARK_MAX_N];
+static auto_mark_t	clip_board_large[LS_MBR_MAX_N];
+static auto_mark_t	clip_board_small;
+
 static char	msg_ttl_auto_mark[AUTO_MARK_MAX_N]
 		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+static char	clip_board_ttl
+		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+
 static long	auto_mark_cur_n;
 static mbr_t	*g_sel_mbr;
 
@@ -88,6 +54,7 @@ static auto_mark_t	dflt_auto_mark_fight = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_AUTO_MARK_EDIT_CONT,
 };
 
@@ -96,6 +63,7 @@ static auto_mark_t	dflt_auto_mark_fight_prio = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
 };
 
@@ -104,6 +72,7 @@ static auto_mark_t	dflt_auto_mark_throw = {
 	AUTO_MARK_DIST_MEDIUM,
 	AUTO_MARK_ACT_THROW,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_NULL,
 };
 
@@ -112,6 +81,7 @@ static auto_mark_t	dflt_auto_mark_throw_prio = {
 	AUTO_MARK_DIST_MEDIUM,
 	AUTO_MARK_ACT_THROW,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
 };
 
@@ -120,6 +90,7 @@ static auto_mark_t	dflt_auto_mark_fight_far = {
 	AUTO_MARK_DIST_FAR,
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_NULL,
 };
 
@@ -128,6 +99,7 @@ static auto_mark_t	dflt_auto_mark_fight_far_prio = {
 	AUTO_MARK_DIST_FAR,
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
 };
 
@@ -136,6 +108,7 @@ static auto_mark_t	dflt_auto_mark_fight_all = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_NULL,
 };
 
@@ -144,6 +117,7 @@ static auto_mark_t	dflt_auto_mark_fight_all_prio = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
 };
 
@@ -152,6 +126,7 @@ static auto_mark_t	dflt_auto_mark_item_all = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_PICK_UP,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
 };
 
@@ -160,6 +135,7 @@ static auto_mark_t	dflt_auto_mark_item_own = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_PICK_UP,
 	AUTO_MARK_COND_OWN,
+	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
 };
 
@@ -168,6 +144,7 @@ static auto_mark_t	dflt_auto_mark_clear = {
 	AUTO_MARK_DIST_NEAR,
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
+	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY,
 };
 
@@ -230,41 +207,71 @@ static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
 	{ FACE_MJR_MISC, FACE_MNR_TOBACCO, TRUE },
 	{ FACE_MJR_MISC, FACE_MNR_PIPE, TRUE },
 	{ FACE_MJR_MISC, FACE_MNR_RARE_GOODS, TRUE },
+	{ FACE_MJR_MISC, FACE_MNR_BONE_GOOD, FALSE },
+	{ FACE_MJR_MISC, FACE_MNR_BONE_EVIL, FALSE },
 	{ FACE_MJR_MISC, FACE_MNR_JUNK, FALSE },
 
 	{ FACE_MJR_NULL, FACE_MNR_NULL, FALSE },
 };
 
-/**/
+/***************************************************************/
 
 #include	"amenu-tab.h"
 
-/**/
-
 /***************************************************************
 * 
 ***************************************************************/
 
 void	init_auto_menu( void )
 {
-	long	i, j, k;
+	long	i;
 
 	g_sel_mbr = NULL;
-
 	auto_mark_cur_n = 0;
 
-	for( i = 0; i < LS_MBR_MAX_N; i++ ){
-		for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
-			for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
-				auto_mark_appoint_item_t	*a;
+	init_auto_mark_all_appoint();
+	init_auto_mark_all_mbr();
 
-				a = &(auto_mark_appoint_item_dflt[k]);
-				auto_mark_appoint_item[i][j][k] = *a;
-			}
+	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+		clip_board_large[i] = ls_auto_mark[i][0];
+
+		strncpy( clip_board_ttl,
+				msg_ttl_auto_mark[0],
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+	clip_board_small = ls_auto_mark[0][0];
+}
+
+/***************************************************************
+* ٤ƤΥСΥƥμν
+***************************************************************/
+
+void	init_auto_mark_all_appoint( void )
+{
+	long	i;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ )
+		init_auto_mark_appoint( i );
+}
+
+/***************************************************************
+* СΥƥμν
+***************************************************************/
+
+void	init_auto_mark_appoint( long ls_mbr_n )
+{
+	long	i, j, k;
+
+	i = ls_mbr_n;
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
+		for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
+			auto_mark_appoint_item_t	*a;
+
+			a = &(auto_mark_appoint_item_dflt[k]);
+			auto_mark_appoint_item[i][j][k] = *a;
 		}
 	}
-
-	init_auto_mark_all_mbr();
 }
 
 /***************************************************************
@@ -537,6 +544,16 @@ void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
 	}
 }
 
+/***************************************************************
+* ΥСʥå
+* long ls_mbr_n : СΥꥹֹ
+***************************************************************/
+
+void	ver_up_auto_mark_1_1_1( long ls_mbr_n )
+{
+	init_auto_mark_appoint( ls_mbr_n );
+}
+
 /***************************************************************
 * ˥塼
 * menu_t **pp : ˥塼
@@ -568,20 +585,20 @@ void	set_menu_auto_mark( menu_t **dflt )
 	p = ls_menu_auto_mark;
 	k = 0;
 
-	strncpy( p[k].path, "/Auto mark", MENU_PATH_MAX_LEN );
+	strncpy( p[k].path, "/auto mark", MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( p[k].path, "/Auto mark/Title", MENU_PATH_MAX_LEN );
+	strncpy( p[k].path, "/auto mark/title", MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	strncpy( p[k].msg, MSG_TTL_MENU_AUTO_MARK,
 			MENU_MSG_MAX_LEN );
 	p[k].call_back = NULL;
@@ -597,10 +614,10 @@ void	set_menu_auto_mark( menu_t **dflt )
 		if( i == auto_mark_cur_n )
 			*dflt = &(p[k]);
 
-		sprintf( p[k].path, "/Auto mark/%ld", i );
+		sprintf( p[k].path, "/auto mark/%ld", i );
 		strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-		p[k].key = (char)('A' + i);
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = (char)('A' + i);
+		p[k].short_key[0] = '\0';
 		strncpy( p[k].msg, get_msg_ttl_auto_mark( i ),
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
@@ -608,10 +625,10 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/Exec", p[kk].path );
+		sprintf( p[k].path, "%s/exec", p[kk].path );
 		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		p[k].key = 'X';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = 'X';
+		p[k].short_key[0] = '\0';
 		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_EXEC,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = cb_menu_auto_mark_exec;
@@ -619,10 +636,10 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/Edit", p[kk].path );
+		sprintf( p[k].path, "%s/edit", p[kk].path );
 		strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-		p[k].key = 'E';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = 'E';
+		p[k].short_key[0] = '\0';
 		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = cb_menu_auto_mark_edit;
@@ -630,10 +647,32 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/Arrange", p[kk].path );
+		sprintf( p[k].path, "%s/copy", p[kk].path );
 		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		p[k].key = 'A';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = 'W';
+		p[k].short_key[0] = '\0';
+		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_COPY,
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_auto_mark_copy_large;
+		p[k].arg = (void *)i;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		sprintf( p[k].path, "%s/paste", p[kk].path );
+		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'Y';
+		p[k].short_key[0] = '\0';
+		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_PASTE,
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_auto_mark_paste_large;
+		p[k].arg = (void *)i;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		sprintf( p[k].path, "%s/arrange", p[kk].path );
+		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'A';
+		p[k].short_key[0] = '\0';
 		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = cb_menu_auto_mark_arrange;
@@ -698,6 +737,7 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 {
 	auto_mark_t	*am;
 	bool_t	flg_clr;
+	char	*macro;
 
 	if( chk_flg_or( mbr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return FALSE;
@@ -746,6 +786,9 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 		mbr->flg_chr &= ~(FLG_CHR_AUTO_MARK_CONT);
 	}
 
+	macro = ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].macro;
+	set_key_buf_str( macro );
+
 	return TRUE;
 }
 
@@ -1150,7 +1193,7 @@ char	*cb_menu_auto_mark_edit_init(
 	menu_t	*p;
 
 	/* ȥ */
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_EDIT,
@@ -1158,28 +1201,28 @@ char	*cb_menu_auto_mark_edit_init(
 			g_sel_mbr->name );
 
 	/* о */
-	p = srch_menu( *pp, "Target" );
+	p = srch_menu( *pp, "target" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_TRGT,
 			get_msg_menu_auto_mark_edit_trgt( g_sel_mbr ) );
 
 	/* ֹ礤 */
-	p = srch_menu( *pp, "Dist" );
+	p = srch_menu( *pp, "dist" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_DIST,
 			get_msg_menu_auto_mark_edit_dist( g_sel_mbr ) );
 
 	/* ư */
-	p = srch_menu( *pp, "Action" );
+	p = srch_menu( *pp, "action" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_ACT,
 			get_msg_menu_auto_mark_edit_act( g_sel_mbr ) );
 
 	/*  */
-	p = srch_menu( *pp, "Condition" );
+	p = srch_menu( *pp, "condition" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_AUTO_MARK_EDIT_COND,
@@ -1188,25 +1231,27 @@ char	*cb_menu_auto_mark_edit_init(
 	/* ƥ */
 	if( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt
 			== AUTO_MARK_TRGT_ITEM ){
-		clr_flg_menu( *pp, "Appoint item", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "appoint item", FLG_MENU_HIDDEN );
 	} else {
-		set_flg_menu( *pp, "Appoint item", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "appoint item", FLG_MENU_HIDDEN );
 	}
 
+	/* ޥ */
+
 	/* Ϣ³ޡ */
 	if( chk_flg( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg,
 			FLG_AUTO_MARK_EDIT_CONT ) ){
-		set_chk_on_menu( *pp, "Continue" );
+		set_chk_on_menu( *pp, "continue" );
 	} else {
-		set_chk_off_menu( *pp, "Continue" );
+		set_chk_off_menu( *pp, "continue" );
 	}
 
 	/* ߤͥ */
 	if( chk_flg( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].flg,
 			FLG_AUTO_MARK_EDIT_PRIORITY ) ){
-		set_chk_on_menu( *pp, "Priority" );
+		set_chk_on_menu( *pp, "priority" );
 	} else {
-		set_chk_off_menu( *pp, "Priority" );
+		set_chk_off_menu( *pp, "priority" );
 	}
 
 	return NULL;
@@ -1226,7 +1271,7 @@ char	*cb_menu_auto_mark_trgt_init(
 	menu_t	*p;
 	char	*s;
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_TRGT,
@@ -1236,25 +1281,25 @@ char	*cb_menu_auto_mark_trgt_init(
 	s = NULL;
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
-		s = "Monster";
+		s = "monster";
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		s = "Item";
+		s = "item";
 		break;
 	case AUTO_MARK_TRGT_DOOR:
-		s = "Door";
+		s = "door";
 		break;
 	case AUTO_MARK_TRGT_TRAP:
-		s = "Trap";
+		s = "trap";
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		s = "Member";
+		s = "member";
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
-		s = "Unchange";
+		s = "unchange";
 		break;
 	case AUTO_MARK_TRGT_CLEAR:
-		s = "Clear";
+		s = "clear";
 		break;
 	}
 
@@ -1274,7 +1319,7 @@ char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt )
 {
 	auto_mark_trgt_t	trgt;
 
-	trgt = (auto_mark_trgt_t)((*pp)->arg);
+	trgt = (auto_mark_trgt_t)(long)((*pp)->arg);
 	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt = trgt;
 
 	switch( trgt ){
@@ -1329,7 +1374,7 @@ char	*cb_menu_auto_mark_dist_init(
 		return STR_MENU_CANCEL;
 	}
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_DIST,
@@ -1339,13 +1384,13 @@ char	*cb_menu_auto_mark_dist_init(
 	s = NULL;
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].dist ){
 	case AUTO_MARK_DIST_NEAR:
-		s = "Near";
+		s = "near";
 		break;
 	case AUTO_MARK_DIST_MEDIUM:
-		s = "Medium";
+		s = "medium";
 		break;
 	case AUTO_MARK_DIST_FAR:
-		s = "Far";
+		s = "far";
 		break;
 	}
 
@@ -1364,7 +1409,7 @@ char	*cb_menu_auto_mark_dist_init(
 char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt )
 {
 	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].dist
-			= (auto_mark_dist_t)((*pp)->arg);
+			= (auto_mark_dist_t)(long)((*pp)->arg);
 
 	return NULL;
 }
@@ -1392,7 +1437,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 		return STR_MENU_CANCEL;
 	}
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_ACT,
@@ -1402,40 +1447,40 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	s = NULL;
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act ){
 	case AUTO_MARK_ACT_FIGHT:
-		s = "Fight";
+		s = "fight";
 		break;
 	case AUTO_MARK_ACT_THROW:
-		s = "Throw";
+		s = "throw";
 		break;
 	case AUTO_MARK_ACT_STEAL:
-		s = "Steal";
+		s = "steal";
 		break;
 	case AUTO_MARK_ACT_TAIL:
-		s = "Tail";
+		s = "tail";
 		break;
 	case AUTO_MARK_ACT_PICK_UP:
-		s = "Pick up";
+		s = "pick up";
 		break;
 	case AUTO_MARK_ACT_OPEN:
-		s = "Open";
+		s = "open";
 		break;
 	case AUTO_MARK_ACT_CLOSE:
-		s = "Close";
+		s = "close";
 		break;
 	case AUTO_MARK_ACT_JAM:
-		s = "Jam";
+		s = "jam";
 		break;
 	case AUTO_MARK_ACT_DISARM:
-		s = "Disarm";
+		s = "disarm";
 		break;
 	case AUTO_MARK_ACT_BREAK:
-		s = "Break";
+		s = "break";
 		break;
 	case AUTO_MARK_ACT_PEEP:
-		s = "Peep";
+		s = "peep";
 		break;
 	case AUTO_MARK_ACT_CHK:
-		s = "Check";
+		s = "check";
 		break;
 	}
 
@@ -1445,51 +1490,51 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
-		set_flg_menu( *pp, "Pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Disarm", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Break", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Peep", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Search", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		set_flg_menu( *pp, "Fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Peep", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_DOOR:
-		set_flg_menu( *pp, "Fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Pick up", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_TRAP:
-		set_flg_menu( *pp, "Fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Peep", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		set_flg_menu( *pp, "Pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Disarm", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Break", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Peep", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Search", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
 	case AUTO_MARK_TRGT_CLEAR:
@@ -1512,7 +1557,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt )
 {
 	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].act
-			= (auto_mark_act_t)((*pp)->arg);
+			= (auto_mark_act_t)(long)((*pp)->arg);
 
 	return NULL;
 }
@@ -1542,7 +1587,7 @@ char	*cb_menu_auto_mark_cond_init(
 		return STR_MENU_CANCEL;
 	}
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
@@ -1554,16 +1599,16 @@ char	*cb_menu_auto_mark_cond_init(
 	s = NULL;
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond ){
 	case AUTO_MARK_COND_NEAREST:
-		s = "Nearest";
+		s = "nearest";
 		break;
 	case AUTO_MARK_COND_DISPERSE:
-		s = "Disperse";
+		s = "disperse";
 		break;
 	case AUTO_MARK_COND_STAGGER:
-		s = "Stagger";
+		s = "stagger";
 		break;
 	case AUTO_MARK_COND_OWN:
-		s = "Own";
+		s = "own";
 		break;
 	}
 	*dflt = srch_menu( *pp, s );
@@ -1574,14 +1619,14 @@ char	*cb_menu_auto_mark_cond_init(
 	case AUTO_MARK_TRGT_DOOR:
 	case AUTO_MARK_TRGT_TRAP:
 	case AUTO_MARK_TRGT_MNSTR:
-		set_flg_menu( *pp, "Stagger", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "Own", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		set_flg_menu( *pp, "Stagger", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		set_flg_menu( *pp, "Own", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
 	case AUTO_MARK_TRGT_CLEAR:
@@ -1591,7 +1636,7 @@ char	*cb_menu_auto_mark_cond_init(
 	if( (*dflt != NULL) && chk_flg( (*dflt)->flg, FLG_MENU_HIDDEN ) )
 		*dflt = NULL;
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
@@ -1610,7 +1655,7 @@ char	*cb_menu_auto_mark_cond_init(
 
 char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt )
 {
-	switch( (auto_mark_cond_t)((*pp)->arg) ){
+	switch( (auto_mark_cond_t)(long)((*pp)->arg) ){
 	case AUTO_MARK_COND_NEAREST:
 		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
 				= AUTO_MARK_COND_NEAREST;
@@ -1656,12 +1701,12 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls = ls_menu_appoint_item;
 	k = 0;
 
-	strncpy( ls[k].path, "/Appoint item",
+	strncpy( ls[k].path, "/appoint item",
 			MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
@@ -1669,12 +1714,12 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/Appoint item/Title",
+	strncpy( ls[k].path, "/appoint item/title",
 			MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Title>",
 			MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
 			get_msg_ttl_auto_mark( auto_mark_cur_n ),
@@ -1726,11 +1771,11 @@ char	*set_menu_auto_mark_appoint_item(
 
 	mjr = (*apo)->mjr;
 
-	sprintf( ls[*k].path, "/Appoint item/%c", mjr );
+	sprintf( ls[*k].path, "/appoint item/%c", mjr );
 	strncpy( ls[*k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
-	ls[*k].key = mjr_key;
-	ls[*k].accel_key[0] = '\0';
+	ls[*k].accel_key = mjr_key;
+	ls[*k].short_key[0] = '\0';
 	ls[*k].n_msg = N_MSG_NULL;
 	strncpy( ls[*k].msg, get_item_mjr_name( mjr ),
 			MENU_MSG_MAX_LEN );
@@ -1741,18 +1786,25 @@ char	*set_menu_auto_mark_appoint_item(
 
 	mnr_key = 'A';
 	for( ; (*apo)->mjr != FACE_MJR_NULL; (*apo)++ ){
+		char	*name;
+
 		if( (*apo)->mjr != mjr )
 			break;
 
-		sprintf( ls[*k].path, "/Appoint item/%c/%c",
+		name = get_item_mnr_name( mjr, (*apo)->mnr );
+		if( strcmp( name, MSG_ITEM_MNR_NAME_ERR ) == 0 )
+			continue;
+		if( strcmp( name, MSG_NULL ) == 0 )
+			continue;
+
+		sprintf( ls[*k].path, "/appoint item/%c/%c",
 				(*apo)->mjr, (*apo)->mnr );
 		strncpy( ls[*k].kind, "<CheckItem>",
 				MENU_KIND_MAX_LEN );
-		ls[*k].key = mnr_key;
-		ls[*k].accel_key[0] = '\0';
+		ls[*k].accel_key = mnr_key;
+		ls[*k].short_key[0] = '\0';
 		ls[*k].n_msg = N_MSG_NULL;
-		strncpy( ls[*k].msg, get_item_mnr_name( mjr, (*apo)->mnr ),
-				MENU_MSG_MAX_LEN );
+		strncpy( ls[*k].msg, name, MENU_MSG_MAX_LEN );
 		ls[*k].call_back = cb_menu_auto_mark_appoint_item_mnr;
 		ls[*k].arg = (void *)(*apo);
 		ls[*k].flg = FLG_NULL;
@@ -1818,6 +1870,65 @@ char	*cb_menu_auto_mark_appoint_item_mnr(
 	return STR_MENU_CANCEL;
 }
 
+/***************************************************************
+* Խ˥塼Υޥ
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt )
+{
+	char	*cmd;
+	static char	msg_cmd[WIN_MSG_DRAW_WIDTH + 1];
+	static char	buf_cmd[MACRO_MAX_LEN + 1];
+	long	x, y;
+
+	/* ȥɽ */
+
+	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_MACRO_TTL );
+
+	/* Υޥɽ */
+
+	cmd = ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro;
+	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_MACRO_PREV, cmd );
+
+	/* ץץȤɽ */
+
+	sprintf( msg_cmd, MSG_GETS_AUTO_MARK_MACRO_CMD, MACRO_MAX_LEN );
+	print_msg( FLG_NULL, msg_cmd );
+
+	/* ޥ桼 */
+
+	x = str_len_draw( msg_cmd );
+	y = get_max_line() - 1;
+	if( game_gets( x, y, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
+		long	len;
+
+		/* βԤ */
+
+		len = str_len_std( buf_cmd );
+		if( len >= 1 )
+			if( buf_cmd[len - 1] == '\n' )
+				buf_cmd[len - 1] = '\0';
+
+		/* Ϥ̵ʤ饭󥻥 */
+
+		if( buf_cmd[0] == '\0' )
+			return STR_MENU_CANCEL;
+	} else {
+		/* 顼ʤ饭󥻥 */
+		return STR_MENU_CANCEL;
+	}
+
+	/* ޥ */
+
+	strncpy( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro,
+			buf_cmd, MACRO_MAX_LEN );
+
+	return STR_MENU_CANCEL;
+}
+
 /***************************************************************
 * Խ˥塼Ϣ³ޡ
 * menu_t **pp : ˥塼
@@ -1858,6 +1969,96 @@ char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt )
 	return STR_MENU_CANCEL;
 }
 
+/***************************************************************
+* ʬॳԡ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+	long	i;
+
+	n = (long)((*pp)->arg);
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+		clip_board_large[i] = ls_auto_mark[i][n];
+
+		strncpy( clip_board_ttl,
+				msg_ttl_auto_mark[n],
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_COPY );
+
+	return STR_MENU_CANCEL;
+}
+
+/***************************************************************
+* ʬڡȡ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+	long	i;
+
+	n = (long)((*pp)->arg);
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+		ls_auto_mark[i][n] = clip_board_large[i];
+
+		strncpy( msg_ttl_auto_mark[n],
+				clip_board_ttl,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+
+	set_menu_auto_mark( dflt );
+
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_PASTE );
+
+	return "/auto mark/0";
+}
+
+/***************************************************************
+* ʬॳԡ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_copy_small( menu_t **pp, menu_t **dflt )
+{
+	clip_board_small = ls_auto_mark[g_sel_mbr->ls_mbr_n]
+			[auto_mark_cur_n];
+
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_COPY );
+
+	return STR_MENU_CANCEL;
+}
+
+/***************************************************************
+* ʬڡȡ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
+{
+	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n]
+			= clip_board_small;
+
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_PASTE );
+
+	return "/edit";
+}
+
 /***************************************************************
 * Ƭ¤ٴ˥塼򤷤
 * menu_t **pp : ˥塼
@@ -1903,7 +2104,9 @@ char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt )
 	set_menu_auto_mark( dflt );
 	auto_mark_cur_n = 0;
 
-	return "/Auto mark/0";
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_ARRANGE );
+
+	return "/auto mark/0";
 }
 
 /***************************************************************
