@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,61 +25,19 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.57 2004/12/26 01:22:16 bowkenken Exp $
+* $Id: curs.c,v 1.65 2006/01/15 14:23:02 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-/*#include	"item.h"*/
-/*#include	"spell.h"*/
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-/*#include	"pet.h"*/
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-#include	"curs.h"
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-/*#include	"dun-prot.h"*/
-/*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
-/*#include	"spell-prot.h"*/
-/*#include	"chr-prot.h"*/
-/*#include	"party-prot.h"*/
-/*#include	"mnstr-prot.h"*/
-/*#include	"pet-prot.h"*/
-/*#include	"fight-prot.h"*/
-/*#include	"fx-prot.h"*/
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* curses Υåѡ
+***************************************************************/
 
-#if	D_DOS
-# include	<windows.h>
-# include	<conio.h>
-# include	"lnl-dos/stdafx.h"
-#endif	/* D_DOS */
+#define	CURS_C
+#include	"inc.h"
 
-/***************************************************************/
+/***************************************************************
+* ѿ
+***************************************************************/
 
 /* ס󥹤Ȥäȿž°褹뤫? */
 #define	FLG_PRINT_REVERSE	0
@@ -182,7 +140,7 @@ void	init_curs( void )
 bool_t	init_curs_color( void )
 {
 #if	HAVE_LIBCURSES
-	curs_attr_n_t	n;
+	long	n;
 
 	if( !g_flg_cui )
 		return FALSE;
@@ -823,6 +781,8 @@ int	curs_getch( void )
 	int	c;
 	bool_t	flg_getc = FALSE;
 
+	if( g_gui_key_kind != GUI_KEY_KIND_CONSOLE )
+		return call_key_get_char();
 	if( !g_flg_cui )
 		return '\0';
 
@@ -919,7 +879,9 @@ long	get_max_line( void )
 	{
 		CONSOLE_SCREEN_BUFFER_INFO cInfo;
 
-		GetConsoleScreenBufferInfo( GetStdHandle( STD_OUTPUT_HANDLE ), &cInfo );
+		GetConsoleScreenBufferInfo(
+				GetStdHandle( STD_OUTPUT_HANDLE ),
+				&cInfo );
 		return( cInfo.srWindow.Bottom - cInfo.srWindow.Top + 1 );
 	}
 #endif	/* D_DOS */
