@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw-tab.h,v 1.5 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: draw-tab.h,v 1.9 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_TAB_H
@@ -260,29 +260,34 @@
 #define	WIN_MBR_DATA_STAT_PASSWALL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 9)
 
+#define	WIN_MBR_DATA_STAT_SENSE_INVISIBLE_DRAW_MIN_X	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+#define	WIN_MBR_DATA_STAT_SENSE_INVISIBLE_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 10)
+
 /* page 2/2 */
 
-#define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_X	(0 + 6)
+#define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_X	(0 + 4)
 #define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y	2
 
-#define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 18)
+#define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 20)
 #define	WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y	\
 		WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y
 
-#define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 25)
+#define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_X	(0 + 27)
 #define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_Y	\
 		WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y
 
 #define	WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_X	\
-		(WIN_MBR_DATA_DRAW_MID_X + 6)
+		(WIN_MBR_DATA_DRAW_MID_X + 4)
 #define	WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y	0
 
 #define	WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_X	\
-		(WIN_MBR_DATA_DRAW_MID_X + 18)
+		(WIN_MBR_DATA_DRAW_MID_X + 20)
 #define	WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_Y	0
 
 #define	WIN_MBR_DATA_NEED_EXP_TTL_RIGHT_DRAW_MIN_X	\
-		(WIN_MBR_DATA_DRAW_MID_X + 25)
+		(WIN_MBR_DATA_DRAW_MID_X + 27)
 #define	WIN_MBR_DATA_NEED_EXP_TTL_RIGHT_DRAW_MIN_Y	0
 
 /* abl 1/2 */
@@ -533,6 +538,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_VANISH, */
 		FALSE,	/* DATA_N_STAT_IRON_BODY, */
 		FALSE,	/* DATA_N_STAT_PASSWALL, */
+		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
@@ -630,6 +636,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_VANISH, */
 		FALSE,	/* DATA_N_STAT_IRON_BODY, */
 		FALSE,	/* DATA_N_STAT_PASSWALL, */
+		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
@@ -727,6 +734,7 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_VANISH, */
 		FALSE,	/* DATA_N_STAT_IRON_BODY, */
 		FALSE,	/* DATA_N_STAT_PASSWALL, */
+		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
@@ -827,6 +835,7 @@ long	data_page_n_tab[] = {
 	0,	/* DATA_N_STAT_VANISH, */
 	0,	/* DATA_N_STAT_IRON_BODY, */
 	0,	/* DATA_N_STAT_PASSWALL, */
+	0,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
 	1,	/* DATA_N_LEV_LEFT, */
 	1,	/* DATA_N_EXP_LEFT, */
