@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.37 2004/12/25 06:33:08 bowkenken Exp $
+* $Id: draw.h,v 1.48 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -41,7 +41,22 @@
 #include	"menu.h"
 #include	"request.h"
 
-/***************************************************************/
+/***************************************************************
+* 
+***************************************************************/
+
+/* ϤοͤοѤ */
+#define	WARNING_HP_RATE_GREEN	((rate_t)100)
+#define	WARNING_HP_RATE_YELLOW	((rate_t)50)
+#define	WARNING_HP_RATE_RED	((rate_t)25)
+/* ϤοͤοѤ */
+#define	WARNING_MP_RATE_GREEN	((rate_t)100)
+#define	WARNING_MP_RATE_YELLOW	((rate_t)50)
+#define	WARNING_MP_RATE_RED	((rate_t)25)
+
+/***************************************************************
+* ե
+***************************************************************/
 
 /* ϥե롦ݥ */
 #define	OUT_FP	stdout
@@ -60,64 +75,6 @@
 #define	WIN_MAP_WIDTH	20
 #define	WIN_MAP_HEIGHT	20
 
-/***************************************************************
-* VFX
-***************************************************************/
-
-#define	VFX_ARW_MAX_N	32
-
-/* ե졼ࡦ졼 */
-#define	ANIM_FRAME_N	((long)(1.0 * 60.0))
-
-#define	ANIM_LINE_LEN	32
-
-/***************************************************************
-* ʸVFX
-***************************************************************/
-
-#define	TYPHOON_DUST_MAX_N	24
-#define	TYPHOON_SPEED	10
-#define	ANIM_TYPHOON_SEC	(4.0)
-#define	ANIM_TYPHOON_FRAME_N	(ANIM_FRAME_N * 5 / 100)
-
-#define	ANIM_CONFLAGRATION_SEC	(4.0)
-#define	ANIM_CONFLAGRATION_FRAME_N	(ANIM_FRAME_N * 5 / 100)
-#define	ANIM_CONFLAGRATION_HEIGHT	(WIN_MAP_DRAW_HEIGHT / 2)
-
-#define	ANIM_EARTHQUAKE_SEC	(4.0)
-#define	ANIM_EARTHQUAKE_FRAME_N	(ANIM_FRAME_N * 1 / 10)
-
-#define	ANIM_THUNDER_FRAME_N	(ANIM_FRAME_N * 5 / 100)
-#define	ANIM_THUNDER_CLR_FRAME_N	(ANIM_FRAME_N * 20 / 10)
-#define	ANIM_THUNDER_HEIGHT	(WIN_MAP_DRAW_HEIGHT / 2)
-
-#define	ANIM_INUNDATION_FRAME_N	(ANIM_FRAME_N * 5 / 100)
-#define	ANIM_INUNDATION_CLR_FRAME_N	(ANIM_FRAME_N * 20 / 10)
-
-/***************************************************************
-* ¾VFX
-***************************************************************/
-
-#define	ANIM_ARW_FRAME_N	\
-		((ANIM_FRAME_N * 15 / 10) - ANIM_ARW_CLR_FRAME_N)
-#define	ANIM_ARW_CLR_FRAME_N	(ANIM_FRAME_N * 5 / 10)
-
-#define	ANIM_CRTCL_FRAME_N	\
-		((ANIM_FRAME_N * 4 / 10) - ANIM_CRTCL_CLR_FRAME_N)
-#define	ANIM_CRTCL_CLR_FRAME_N	(ANIM_FRAME_N * 2 / 10)
-#define	ANIM_CRTCL_R	2
-#define	ANIM_CRTCL_WAIT_CLOCK	(ANIM_FRAME_N * 4 / 10)
-#define	STR_ANIM_CRTCL_1	"/"
-#define	STR_ANIM_CRTCL_2	"\\"
-
-#define	ANIM_NUM_FRAME_N	(ANIM_FRAME_N * 10 / 10)
-#define	ANIM_LEV_UP_FRAME_N	(ANIM_FRAME_N * 30 / 10)
-
-#define	ANIM_SPELL_LEN	8
-#define	ANIM_SPELL_FRAME_N	\
-		((ANIM_FRAME_N * 15 / 10) - ANIM_SPELL_CLR_FRAME_N)
-#define	ANIM_SPELL_CLR_FRAME_N	(ANIM_FRAME_N * 5 / 10)
-
 /***************************************************************
 * ɥΥ
 ***************************************************************/
@@ -190,7 +147,17 @@ typedef unsigned long	flg_msg_t;
 #define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)
 
 /***************************************************************
-* VFXΥե륿
+* ե졼ࡦ졼
+***************************************************************/
+
+#define	ANIM_FRAME_N	((long)(1.0 * 60.0))
+
+#define	ANIM_FRAME_N_BLAST_STD	((long)(0.5 * 60.0))
+#define	ANIM_FRAME_N_BLAST_DESTRUCTION	((long)(2.0 * 60.0))
+#define	ANIM_FRAME_N_BLAST_NINJA_CRTCL	((long)(1.5 * 60.0))
+
+/***************************************************************
+* ӥ奢롦եȤΥե륿
 ***************************************************************/
 
 typedef unsigned long	flg_vfx_mbr_t;
@@ -206,7 +173,18 @@ typedef unsigned long	flg_vfx_mnstr_t;
 #define	FLG_VFX_MNSTR_ARW	(1 << 3)
 
 /***************************************************************
-* VFXԤ
+* Υӥ奢롦ե
+***************************************************************/
+
+#define	VFX_ARW_MAX_N	32
+
+#define	ANIM_LINE_LEN	32
+
+#define	ANIM_ARW_LEN	(ANIM_FRAME_N / 4)
+#define	MNSTR_THROW_MJR	'*'
+
+/***************************************************************
+* ӥ奢롦եȤԤ
 ***************************************************************/
 
 #define	VFX_WAIT_MIN_N	1
@@ -265,6 +243,7 @@ typedef enum {
 	DATA_N_STAT_VANISH,
 	DATA_N_STAT_IRON_BODY,
 	DATA_N_STAT_PASSWALL,
+	DATA_N_STAT_SENSE_INVISIBLE,
 
 	DATA_N_LEV_LEFT,
 	DATA_N_EXP_LEFT,
