@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,23 +25,29 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.h,v 1.28 2004/12/20 21:17:54 bowkenken Exp $
+* $Id: dun.h,v 1.35 2006/01/15 01:11:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DUN_H
 #define	DUN_H
 
-/* µ */
+/***************************************************************
+* µ
+***************************************************************/
 
 #include	"gmain.h"
 #include	"curs.h"
 
-/**/
+/***************************************************************
+* 糬
+***************************************************************/
 
 #define	DUN_MAX_LEV_FLOOR	10000	/* Ͼκ糬 */
 #define	DUN_MAX_LEV_BASE	10000	/* ϲκ糬 */
 
-/* ޥåפι */
+/***************************************************************
+* ޥåפι
+***************************************************************/
 
 #define	AREA_MAX_X	20
 #define	AREA_MAX_Y	20
@@ -52,7 +58,9 @@
 #define	MAP_DEL_X	-1
 #define	MAP_DEL_Y	-1
 
-/* ǥեȤΥ */
+/***************************************************************
+* ǥեȤΥ
+***************************************************************/
 
 #define	SECT_NULL	'a'
 #define	SECT_PATH_DFLT	' '
@@ -63,7 +71,9 @@
 #define	SECT_PATH_E	'E'
 #define	SECT_PATH_W	'W'
 
-/* ե饰 */
+/***************************************************************
+* ե饰
+***************************************************************/
 
 typedef unsigned long	flg_map_t;
 
@@ -90,7 +100,9 @@ typedef unsigned long	flg_map_t;
 #define	FLG_DOOR_GATE	(1 << 8)	/*  */
 #define	FLG_DOOR_SHOP	(1 << 9)	/* Źν */
 
-/*  */
+/***************************************************************
+* ʸ
+***************************************************************/
 
 #define	FACE_MJR_WALL	'#'
 #define	FACE_MNR_WALL	'#'
@@ -137,11 +149,16 @@ typedef unsigned long	flg_map_t;
 #define	FACE_MNR_TRAP_TELEPORT	't'
 #define	FACE_MNR_TRAP_PIT	'p'
 #define	FACE_MNR_TRAP_CHUTE	'c'
+#define	FACE_MNR_TRAP_SANCTUARY	'+'
 
 #define	FACE_MJR_MBR	'@'
 
 #define	FACE_MJR_SQUARE	'%'
 
+/***************************************************************
+* ¾
+***************************************************************/
+
 /* ɥκ */
 
 #define	DOOR_MAX_N	64
@@ -152,11 +169,15 @@ typedef unsigned long	flg_map_t;
 #define	CRSR_PTN_MAX_Y_LEN	16
 #define	CRSR_PTN_MAX_X_LEN	16
 
-/*  */
+/***************************************************************
+* 
+***************************************************************/
 
 typedef char	sect_t;
 
-/* Υѥ */
+/***************************************************************
+* Υѥ
+***************************************************************/
 
 typedef struct {
 	/*  */
@@ -164,12 +185,14 @@ typedef struct {
 	/* иΨ */
 	rate_t	rate;
 	/* ѥ */
-	char	ptn[AREA_MAX_Y][AREA_MAX_X * 2];
+	char	ptn[AREA_MAX_Y][AREA_MAX_X * 2 + 1];
 	/*  */
-	sect_t	sect[AREA_MAX_Y][AREA_MAX_X];
+	sect_t	sect[AREA_MAX_Y][AREA_MAX_X + 1];
 } room_ptn_t;
 
-/* ɥ */
+/***************************************************************
+* ɥ
+***************************************************************/
 
 typedef unsigned long	flg_door_t;
 
@@ -181,7 +204,9 @@ typedef struct {
 	flg_door_t	flg;	/* ե饰 */
 } door_t;
 
-/* ޥåפΥ쥤䡼 */
+/***************************************************************
+* ޥåפΥ쥤䡼
+***************************************************************/
 
 typedef struct {
 	char	mjr[MAP_MAX_Y][MAP_MAX_X];	/* major face */
@@ -189,7 +214,9 @@ typedef struct {
 	flg_map_t	flg[MAP_MAX_Y][MAP_MAX_X];
 } map_t;
 
-/* ޥåפΥ쥤䡼 */
+/***************************************************************
+* ޥå
+***************************************************************/
 
 typedef struct {
 	/* ֥ȤΥ쥤䡼 */
@@ -210,11 +237,15 @@ typedef struct {
 	curs_attr_t	attr[MAP_MAX_Y][MAP_MAX_X];
 } all_map_t;
 
-/* ꥢ */
+/***************************************************************
+* ꥢ
+***************************************************************/
 
 typedef short	area_t;
 
-/* µ */
+/***************************************************************
+* µ
+***************************************************************/
 
 typedef struct {
 	/* ޥå */
@@ -231,14 +262,18 @@ typedef struct {
 	long	lev;
 } dun_t;
 
+/***************************************************************
+* 롦ѥ
+***************************************************************/
+
 typedef struct {
 	/*  */
 	long	x, y;
 	/* ȹ⤵ */
 	long	x_len, y_len;
 
-	/* ޥ˻Ȥʸ */
-	long	mask_chr;
+	/* Ʃʸ */
+	long	transmit_chr;
 
 	/* ѥ */
 	char	face[CRSR_PTN_MAX_Y_LEN][CRSR_PTN_MAX_X_LEN * 2 + 1];
