@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,57 +25,20 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.100 2004/12/25 01:43:50 bowkenken Exp $
+* $Id: fight.c,v 1.113 2006/01/15 01:11:03 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-#include	"item.h"
-#include	"spell.h"
-/*#include	"chr.h"*/
-#include	"party.h"
-/*#include	"mnstr.h"*/
-/*#include	"pet.h"*/
-#include	"fight.h"
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-#include	"dun-prot.h"
-/*#include	"town-prot.h"*/
-#include	"item-prot.h"
-/*#include	"spell-prot.h"*/
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-/*#include	"pet-prot.h"*/
-#include	"fight-prot.h"
-#include	"fx-prot.h"
-#include	"trap-prot.h"
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* Ʈ
+***************************************************************/
 
-/**/
+#define	FIGHT_C
+#include	"inc.h"
+
+/***************************************************************
+* ٥ɶζ
+***************************************************************/
 
-/* ٥ɶζ */
 #if	1
 
 /* ٥뤬㤤ۤɶ */
@@ -89,6 +52,10 @@
 
 #endif
 
+/***************************************************************
+* ٥ɶζδ
+***************************************************************/
+
 #define	HIT_FIT_AVE_N	10
 #define	HIT_HNT_AVE_N	10
 #define	WPN_CRTCL_FIT_AVE_N	20
@@ -103,9 +70,13 @@
 #define	DEF_MON_MUL	10
 #define	DEF_MON_ADD	0
 
+/* դΥƥ롦ҥåΨ */
 #define	WPN_CRTCL_THF_LEV_RATE	30
 #define	WPN_CRTCL_THF_MAX_RATE	30
 
+/* ǦԤμڤΨ */
+#define	NINJA_CRTCL_RATE	150
+
 #define	DEF_MIN_RATE	30
 #define	DEF_AVE_N	10
 #define	ARMOR_CRTCL_AVE_N	10
@@ -115,24 +86,28 @@
 #define	DEF_DEF_RATE	150
 #define	DEF_AC_RATE	150
 
-#define	DAM_WAND_RATE	((rate_t)120)
-#define	DAM_WAND_ADD	2
+/* ˡξι */
+#define	DAM_STICK_RATE	((rate_t)120)
+#define	DAM_STICK_ADD	2
 
+/* ʸι */
 #define	DAM_SPELL_RATE	((rate_t)150)
 #define	DAM_SPELL_ADD	2
 
+/* ֥Ȥɸ */
 #define	DOOR_DEF	12
 #define	TRAP_DEF	8
 #define	ITEM_DEF	6
 
+/* ֹϤεΥˤäƸΨ */
 #define	RATE_PER_RANGE	((rate_t)200)
 
+/* СƱΤηи */
 #define	TRAINING_EXP	1
 
-#define	ANIM_ARW_LEN	(ANIM_FRAME_N / 4)
-#define	MNSTR_THROW_MJR	'*'
-
-/**/
+/***************************************************************
+* Ǽξιǡ
+***************************************************************/
 
 static attack_t	mbr_attack_bash[] = {
 	{ ATTACK_KIND_PUNCH, 1, FALSE, TRUE,
@@ -155,6 +130,10 @@ static attack_t	mbr_attack_bash[] = {
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
 
+/***************************************************************
+* ƥꤲιǡ
+***************************************************************/
+
 static attack_t	mbr_attack_throw[] = {
 	{ ATTACK_KIND_THROW, 1, TRUE, FALSE,
 		WPN_HIT_UNARMED, WPN_CRTCL_UNARMED, WPN_DAM_UNARMED,
@@ -170,6 +149,10 @@ static attack_t	mbr_attack_throw[] = {
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
 
+/***************************************************************
+* ꤲιǡ
+***************************************************************/
+
 static attack_t	mbr_attack_throw_light[] = {
 	{ ATTACK_KIND_THROW, 1, TRUE, FALSE,
 		WPN_HIT_UNARMED, WPN_CRTCL_UNARMED, WPN_DAM_UNARMED,
@@ -185,9 +168,15 @@ static attack_t	mbr_attack_throw_light[] = {
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
 
-/**/
+/***************************************************************
+* ܹ
+* chr_t *chr : ¦饯
+* chr_t *chr2 : ɸ¦饯
+* attack_t *dflt_attack : ǥեȤιǡ
+* return : ?
+***************************************************************/
 
-bool_t	bash( chr_t *chr, chr_t *chr2, attack_t *dflt_attack )
+bool_t	fight_bash( chr_t *chr, chr_t *chr2, attack_t *dflt_attack )
 {
 	attack_t	attack;
 	long	d;
@@ -209,7 +198,14 @@ bool_t	bash( chr_t *chr, chr_t *chr2, attack_t *dflt_attack )
 	return fight( chr, chr2, &attack, d );
 }
 
-/**/
+/***************************************************************
+* ܹǡ
+* chr_t *chr : ¦饯
+* attack_t *attack : ǡ֤
+* long range : Υ
+* bool_t flg_ave : ʿ֤ͤ?
+* return : 뤫?
+***************************************************************/
 
 bool_t	set_attack_chr_bash(
 	chr_t *chr, attack_t *attack, long range, bool_t flg_ave
@@ -223,7 +219,14 @@ bool_t	set_attack_chr_bash(
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* Сζܹǡ
+* mbr_t *mbr : ¦С
+* attack_t *attack : ǡ֤
+* long range : Υ
+* bool_t flg_ave : ʿ֤ͤ?
+* return : 뤫?
+***************************************************************/
 
 bool_t	set_attack_mbr_bash(
 	mbr_t *mbr, attack_t *attack, long range, bool_t flg_ave
@@ -269,12 +272,22 @@ bool_t	set_attack_mbr_bash(
 		attack->hit += add_hit( eq->dat.wpn.add_hit );
 		attack->crtcl += add_wpn_crtcl( eq->dat.wpn.add_crtcl );
 		attack->dam += add_dam( eq->dat.wpn.add_dam );
+		attack->dam += attack->dam
+				* add_dam_two_handed_wpn( mbr, eq )
+				/ _100_PERCENT;
 	}
 
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 󥹥ζܹǡ
+* mnstr_t *mnstr : ¦󥹥
+* attack_t *attack : ǡ֤
+* long range : Υ
+* bool_t flg_ave : ʿ֤ͤ?
+* return : 뤫?
+***************************************************************/
 
 bool_t	set_attack_mnstr_bash(
 	mnstr_t *mnstr, attack_t *attack, long range, bool_t flg_ave
@@ -302,9 +315,15 @@ bool_t	set_attack_mnstr_bash(
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ֹ
+* chr_t *chr : ¦饯
+* chr_t *chr2 : ɸ¦饯
+* attack_t *dflt_attack : ǥեȤιǡ
+* return : ?
+***************************************************************/
 
-bool_t	throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
+bool_t	fight_throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
 {
 	item_t	*eq;
 	attack_t	attack;
@@ -339,7 +358,14 @@ bool_t	throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
 	return fight( chr1, chr2, &attack, d );
 }
 
-/**/
+/***************************************************************
+* ֹǡ
+* chr_t *chr : ¦饯
+* attack_t *attack : ǡ֤
+* long range : Υ
+* bool_t flg_ave : ʿ֤ͤ?
+* return : 뤫?
+***************************************************************/
 
 bool_t	set_attack_chr_throw(
 	chr_t *chr, attack_t *attack, long range, bool_t flg_ave
@@ -353,7 +379,14 @@ bool_t	set_attack_chr_throw(
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* Сαֹǡ
+* mbr_t *mbr : ¦С
+* attack_t *attack : ǡ֤
+* long range : Υ
+* bool_t flg_ave : ʿ֤ͤ?
+* return : 뤫?
+***************************************************************/
 
 bool_t	set_attack_mbr_throw(
 	mbr_t *mbr, attack_t *attack, long range, bool_t flg_ave
@@ -460,7 +493,14 @@ bool_t	set_attack_mbr_throw(
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 󥹥αֹǡ
+* mnstr_t *mnstr : ¦󥹥
+* attack_t *attack : ǡ֤
+* long range : Υ
+* bool_t flg_ave : ʿ֤ͤ?
+* return : 뤫?
+***************************************************************/
 
 bool_t	set_attack_mnstr_throw(
 	mnstr_t *mnstr, attack_t *attack, long range, bool_t flg_ave
@@ -487,7 +527,17 @@ bool_t	set_attack_mnstr_throw(
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ǡμư
+* bool_t flg_ave : ʿͤ?
+* attack_t *ls : ǡΥơ֥
+* long range : Υ
+* bool_t flg_bash : ܹ˴ޤफ?
+* bool_t flg_monk : Ʈ˴ޤफ?
+* bool_t flg_throw : ֹ˴ޤफ?
+* bool_t flg_spell : ʸ˴ޤफ?
+* return : 򤵤줿ǡ
+***************************************************************/
 
 attack_t	*get_attack(
 	bool_t flg_ave, attack_t *ls, long range,
@@ -506,7 +556,16 @@ attack_t	*get_attack(
 	}
 }
 
-/**/
+/***************************************************************
+* ʿŪʹǡμư
+* attack_t *ls : ǡΥơ֥
+* long range : Υ
+* bool_t flg_bash : ܹ˴ޤफ?
+* bool_t flg_monk : Ʈ˴ޤफ?
+* bool_t flg_throw : ֹ˴ޤफ?
+* bool_t flg_spell : ʸ˴ޤफ?
+* return : 򤵤줿ǡ
+***************************************************************/
 
 attack_t	*get_attack_ave(
 	attack_t *ls, long range,
@@ -576,7 +635,16 @@ attack_t	*get_attack_ave(
 	return &ave;
 }
 
-/**/
+/***************************************************************
+* ʹǡμư
+* attack_t *ls : ǡΥơ֥
+* long range : Υ
+* bool_t flg_bash : ܹ˴ޤफ?
+* bool_t flg_monk : Ʈ˴ޤफ?
+* bool_t flg_throw : ֹ˴ޤफ?
+* bool_t flg_spell : ʸ˴ޤफ?
+* return : 򤵤줿ǡ
+***************************************************************/
 
 attack_t	*get_attack_randm(
 	attack_t *ls, long range,
@@ -659,7 +727,15 @@ attack_t	*get_attack_randm(
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* ϤιΨ׻
+* attack_t *ls : ǡΥơ֥
+* bool_t flg_bash : ܹ˴ޤफ?
+* bool_t flg_monk : Ʈ˴ޤफ?
+* bool_t flg_throw : ֹ˴ޤफ?
+* bool_t flg_spell : ʸ˴ޤफ?
+* return : ϤιΨ
+***************************************************************/
 
 ratio_t	calc_attack_sum(
 	attack_t *ls,
@@ -703,7 +779,14 @@ ratio_t	calc_attack_sum(
 	return sum;
 }
 
-/**/
+/***************************************************************
+* Ʈ
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* const attack_t *attack : ǡ
+* long range : Υ
+* return : ?
+***************************************************************/
 
 bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 {
@@ -752,6 +835,13 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 		if( ((mbr_t *)o_p)->trgt.kind == TRGT_KIND_MNSTR_NULL )
 			flg_d_null = TRUE;
 
+	/* ξǤƮϽʤ */
+
+	if( (o_p != NULL) && chk_map_sanctuary( o_p->x, o_p->y ) )
+		return FALSE;
+	if( (d_p != NULL) && chk_map_sanctuary( d_p->x, d_p->y ) )
+		return FALSE;
+
 	eq = NULL;
 	if( attack->flg_throw && (o_k == CHR_KIND_MBR) ){
 		eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
@@ -933,22 +1023,6 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	else
 		flg_ninja_crtcl = FALSE;
 
-	if( flg_ninja_crtcl ){
-		curs_attrset_chr( d_p, -1, TRUE );
-		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_NINJA, o_name );
-		curs_attrset_dflt();
-
-		vfx_ninja_crtcl( d_k, end.x, end.y );
-	} else if( flg_crtcl ){
-		o_dam *= 2;
-
-		curs_attrset_chr( d_p, -1, TRUE );
-		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_STD, o_name );
-		curs_attrset_dflt();
-
-		vfx_crtcl( d_k, end.x, end.y );
-	}
-
 	if( chk_slayer( o_p, d_p, attack->flg_throw ) ){
 		o_hit *= 2;
 		o_dam *= 2;
@@ -995,8 +1069,6 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 		return TRUE;
 	}
 
-	/* ⤬ä */
-
 	/* 񤹤 */
 
 	if( attack->flg_throw && (eq != NULL) && (o_k == CHR_KIND_MBR) ){
@@ -1021,25 +1093,6 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 		return FALSE;
 	}
 
-	/* Υե */
-
-	fight_fx( o_p, d_p, attack );
-
-	/* ݡä */
-
-	if( (eq != NULL) && (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_POTION) ){
-		o_dam = 0;
-
-		if( d_k == CHR_KIND_MBR ){
-			quaff_potion( (mbr_t *)d_p,
-					&(eq[EQUIP_KIND_ARW]), FALSE );
-		}
-		if( d_k == CHR_KIND_MNSTR ){
-			quaff_potion_mnstr( (mnstr_t *)d_p,
-					&(eq[EQUIP_KIND_ARW]), FALSE );
-		}
-	}
-
 	/* ø */
 
 	if( !flg_serious )
@@ -1051,12 +1104,53 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 		if( chk_magic_protect( o_p, d_p, attack->flg_throw ) )
 			o_dam = 0;
 
+	/* ݡä */
+
+	if( (eq != NULL) && (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_POTION) )
+		o_dam = 0;
+
+	/* ⤬ä */
+
 	/* ᡼ɽ */
 
-	if( !flg_ninja_crtcl ){
+	if( o_dam <= 0 ){
+		o_dam = 0;
+	} else if( flg_ninja_crtcl ){
+		curs_attrset_chr( d_p, -1, TRUE );
+		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_NINJA, o_name );
+		curs_attrset_dflt();
+
+		vfx_ninja_crtcl( d_k, end.x, end.y );
+	} else if( flg_crtcl ){
+		o_dam *= 2;
+
+		curs_attrset_chr( d_p, -1, TRUE );
+		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_STD, o_name );
+		curs_attrset_dflt();
+
+		vfx_crtcl( d_k, end.x, end.y );
+
 		curs_attrset_chr( d_p, -1, FALSE );
 		print_msg( FLG_NULL, MSG_FIGHT_HIT_STD, d_name, o_dam );
 		curs_attrset_dflt();
+	} else {
+		curs_attrset_chr( d_p, -1, FALSE );
+		print_msg( FLG_NULL, MSG_FIGHT_HIT_STD, d_name, o_dam );
+		curs_attrset_dflt();
+
+		vfx_hit( d_k, end.x, end.y );
+	}
+
+	/* Υե */
+
+	fight_fx( o_p, d_p, attack );
+
+	/* ݡä */
+
+	if( (eq != NULL) && (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_POTION) ){
+		o_dam = 0;
+
+		quaff_potion( (chr_t *)d_p, &(eq[EQUIP_KIND_ARW]), FALSE );
 	}
 
 	/*  */
@@ -1113,27 +1207,16 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	return TRUE;
 }
 
-/**/
-
-bool_t	zap_wand_mbr_attack( mbr_t *mbr, resi_kind_t resi )
-{
-	if( mbr == NULL )
-		return FALSE;
-
-	switch( mbr->trgt.kind ){
-	case TRGT_KIND_MBR:
-	case TRGT_KIND_MNSTR:
-	case TRGT_KIND_MNSTR_NULL:
-		break;
-	default:
-		return FALSE;
-	}
-
-	return( spell_attack( mbr, mbr->trgt.p,
-			resi, TRUE, ABL_KIND_MAX_N, _100_PERCENT ) );
-}
-
-/**/
+/***************************************************************
+* ʸ
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* resi_kind_t resi : ͤμ
+* bool_t flg_stick : ˡξ?
+* abl_kind_t abl : Ѥǽͤμ
+* rate_t rate : ᡼¿
+* return : ?
+***************************************************************/
 
 bool_t	spell_attack(
 	chr_t *o_p, chr_t *d_p,
@@ -1212,7 +1295,7 @@ bool_t	spell_attack(
 	/* ᡼ */
 
 	if( flg_stick )
-		dam = get_dam_wand( o_p );
+		dam = get_dam_stick( o_p );
 	else
 		dam = get_dam_spell( o_p, abl, get_sub_abl( abl ) );
 	dam = dam * rate / _100_PERCENT;
@@ -1245,9 +1328,12 @@ bool_t	spell_attack(
 	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_HIT_STD, d_name, dam );
 	curs_attrset_dflt();
 
-	/* HP򸺤餹 */
+	/* ɲø */
 
 	added_fx( d_p, resi );
+
+	/* HP򸺤餹 */
+
 	if( d_p->abl.hp.n <= dam ){
 		/*  */
 		curs_attrset_chr( d_p, -1, TRUE );
@@ -1259,7 +1345,11 @@ bool_t	spell_attack(
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ɲø
+* chr_t *chr : 饯
+* resi_kind_t resi : ͤμ
+***************************************************************/
 
 void	added_fx( chr_t *chr, resi_kind_t resi )
 {
@@ -1296,7 +1386,12 @@ void	added_fx( chr_t *chr, resi_kind_t resi )
 	}
 }
 
-/**/
+/***************************************************************
+* Υե
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* const attack_t *attack : ǡ
+***************************************************************/
 
 void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 {
@@ -1317,7 +1412,12 @@ void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 		set_fx( d_p, attack->fx_kind, attack->fx_turn );
 }
 
-/**/
+/***************************************************************
+* ɥ
+* chr_t *chr : 饯
+* long dr_n : ɥֹ
+* return : ?
+***************************************************************/
 
 bool_t	chr_break_door( chr_t *chr, long dr_n )
 {
@@ -1356,7 +1456,12 @@ bool_t	chr_break_door( chr_t *chr, long dr_n )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 櫤
+* chr_t *chr : 饯
+* trap_t *trap : 
+* return : ?
+***************************************************************/
 
 bool_t	chr_break_trap( chr_t *chr, trap_t *trap )
 {
@@ -1386,7 +1491,12 @@ bool_t	chr_break_trap( chr_t *chr, trap_t *trap )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ƥ
+* chr_t *chr : 饯
+* item_t *item : ƥ
+* return : ?
+***************************************************************/
 
 bool_t	chr_break_item( chr_t *chr, item_t *item )
 {
@@ -1430,7 +1540,13 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* м²̡֡פĴ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+* return : ?
+***************************************************************/
 
 bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 {
@@ -1469,7 +1585,13 @@ bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ˡʳʤŨĴ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+* return : ˡʳʤʤ TRUEʤ FALSE
+***************************************************************/
 
 bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 {
@@ -1493,9 +1615,11 @@ bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 		if( flg_throw ){
 			if( eq[EQUIP_KIND_ARW].kind != ITEM_KIND_WPN )
 				break;
-			if( eq[EQUIP_KIND_BOW].kind != ITEM_KIND_WPN )
-				break;
-			if( eq[EQUIP_KIND_ARW].dat.wpn.add_hit <= 0 )
+
+			if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN )
+				if( eq[EQUIP_KIND_ARW].dat.wpn.add_hit <= 0 )
+					break;
+			if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_WPN )
 				if( eq[EQUIP_KIND_BOW].dat.wpn.add_hit <= 0 )
 					break;
 		} else {
@@ -1512,7 +1636,12 @@ bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 饯ιϤ׻
+* chr_t *p : 饯
+* const attack_t *attack : ǡ
+* return : 
+***************************************************************/
 
 long	get_hit( chr_t *p, const attack_t *attack )
 {
@@ -1572,7 +1701,12 @@ long	get_hit( chr_t *p, const attack_t *attack )
 	return hit;
 }
 
-/**/
+/***************************************************************
+* 饯Υ᡼׻
+* chr_t *p : 饯
+* const attack_t *attack : ǡ
+* return : ᡼
+***************************************************************/
 
 long	get_dam( chr_t *p, const attack_t *attack )
 {
@@ -1636,7 +1770,11 @@ long	get_dam( chr_t *p, const attack_t *attack )
 	return dam;
 }
 
-/**/
+/***************************************************************
+* 饯ɸϤ׻
+* chr_t *p : 饯
+* return : ɸ
+***************************************************************/
 
 long	get_def( chr_t *p )
 {
@@ -1680,7 +1818,11 @@ long	get_def( chr_t *p )
 	return def;
 }
 
-/**/
+/***************************************************************
+* 饯ɸ˻Ȥǽͤμ֤
+* chr_t *p : 饯
+* return : ǽͤμ
+***************************************************************/
 
 abl_kind_t	get_def_abl( chr_t *p )
 {
@@ -1713,7 +1855,12 @@ abl_kind_t	get_def_abl( chr_t *p )
 	return ABL_KIND_FIG;
 }
 
-/**/
+/***************************************************************
+* 饯ɸϤ׻
+* chr_t *p : 饯
+* abl_kind_t abl : ǽͤμ
+* return : ɸ
+***************************************************************/
 
 long	get_armor_def( chr_t *p, abl_kind_t abl )
 {
@@ -1732,25 +1879,29 @@ long	get_armor_def( chr_t *p, abl_kind_t abl )
 
 	if( p->kind == CHR_KIND_MBR ){
 		item_t	*eq;
-		equip_kind_t	n;
+		long	i;
 
 		/* ɶΥơ֥ */
+
 		eq = get_mbr_item_asgn_equip( (mbr_t *)p );
 		if( eq == NULL )
 			return 1;
 
 		/* ɶͤä */
-		for( n = 0; n < EQUIP_KIND_MAX_N; n++ ){
-			if( eq[n].kind != ITEM_KIND_ARMOR )
+
+		for( i = 0; i < EQUIP_KIND_MAX_N; i++ ){
+			if( eq[i].kind != ITEM_KIND_ARMOR )
 				continue;
-			if( eq[n].tab.armor == NULL )
+			if( eq[i].tab.armor == NULL )
 				continue;
 
-			armor_def += eq[n].tab.armor->def;
-			armor_def += add_def( eq[n].dat.armor.add_def );
+			armor_def += eq[i].tab.armor->def;
+			armor_def += add_def(
+					eq[i].dat.armor.add_def );
 		}
 	} else if( p->kind == CHR_KIND_MNSTR ){
 		/* ɶͤä */
+
 		armor_def += p->mnstr_tab->def;
 		armor_def += add_def( p->add_def );
 	}
@@ -1762,7 +1913,11 @@ long	get_armor_def( chr_t *p, abl_kind_t abl )
 	return armor_def;
 }
 
-/**/
+/***************************************************************
+* 饯Υޡ饹׻
+* chr_t *p : 饯
+* return : ޡ饹
+***************************************************************/
 
 long	get_ac( chr_t *p )
 {
@@ -1777,25 +1932,29 @@ long	get_ac( chr_t *p )
 
 	if( p->kind == CHR_KIND_MBR ){
 		item_t	*eq;
-		equip_kind_t	n;
+		long	i;
 
 		/* ɶΥơ֥ */
+
 		eq = get_mbr_item_asgn_equip( (mbr_t *)p );
 		if( eq == NULL )
 			return 0;
 
 		/* ɶͤä */
-		for( n = 0; n < EQUIP_KIND_MAX_N; n++ ){
-			if( eq[n].kind != ITEM_KIND_ARMOR )
+
+		for( i = 0; i < EQUIP_KIND_MAX_N; i++ ){
+			if( eq[i].kind != ITEM_KIND_ARMOR )
 				continue;
-			if( eq[n].tab.armor == NULL )
+			if( eq[i].tab.armor == NULL )
 				continue;
 
-			armor_ac += eq[n].tab.armor->ac;
-			armor_ac += add_ac( eq[n].dat.armor.add_ac );
+			armor_ac += eq[i].tab.armor->ac;
+			armor_ac += add_ac(
+					eq[i].dat.armor.add_ac );
 		}
 	} else if( p->kind == CHR_KIND_MNSTR ){
 		/* ɶͤä */
+
 		armor_ac += p->mnstr_tab->ac;
 		armor_ac += add_ac( p->add_ac );
 	}
@@ -1812,7 +1971,13 @@ long	get_ac( chr_t *p )
 	return ac;
 }
 
-/**/
+/***************************************************************
+* ƥΨ򹶷¦ɸ¦ͤƷ׻
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* const attack_t *attack : ǡ
+* return : ƥΨ
+***************************************************************/
 
 rate_t	get_crtcl( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 {
@@ -1827,7 +1992,12 @@ rate_t	get_crtcl( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 	return rate;
 }
 
-/**/
+/***************************************************************
+* ¦ΥƥΨ׻
+* chr_t *p : 饯
+* const attack_t *attack : ǡ
+* return : ƥΨ
+***************************************************************/
 
 rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack )
 {
@@ -1875,7 +2045,11 @@ rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack )
 	return crtcl;
 }
 
-/**/
+/***************************************************************
+* ɸ¦ΥƥΨ׻
+* chr_t *p : 饯
+* return : ƥΨ
+***************************************************************/
 
 rate_t	get_armor_crtcl( chr_t *p )
 {
@@ -1889,7 +2063,7 @@ rate_t	get_armor_crtcl( chr_t *p )
 
 	if( p->kind == CHR_KIND_MBR ){
 		item_t	*eq;
-		equip_kind_t	n;
+		long	i;
 
 		/* ɶΥơ֥ */
 
@@ -1899,15 +2073,15 @@ rate_t	get_armor_crtcl( chr_t *p )
 
 		/* ɶͤä */
 
-		for( n = 0; n < EQUIP_KIND_MAX_N; n++ ){
-			if( eq[n].kind != ITEM_KIND_ARMOR )
+		for( i = 0; i < EQUIP_KIND_MAX_N; i++ ){
+			if( eq[i].kind != ITEM_KIND_ARMOR )
 				continue;
-			if( eq[n].tab.armor == NULL )
+			if( eq[i].tab.armor == NULL )
 				continue;
 
-			armor_crtcl += eq[n].tab.armor->crtcl;
+			armor_crtcl += eq[i].tab.armor->crtcl;
 			armor_crtcl += add_armor_crtcl(
-					eq[n].dat.armor.add_crtcl );
+					eq[i].dat.armor.add_crtcl );
 		}
 	} else if( p->kind == CHR_KIND_MNSTR ){
 		/* ɶͤä */
@@ -1928,7 +2102,12 @@ rate_t	get_armor_crtcl( chr_t *p )
 	return crtcl;
 }
 
-/**/
+/***************************************************************
+* ڤ꤬ȯĴ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* return : ڤ꤬ȯ?
+***************************************************************/
 
 bool_t	chk_ninja_crtcl( chr_t *o_p, chr_t *d_p )
 {
@@ -1962,7 +2141,7 @@ bool_t	chk_ninja_crtcl( chr_t *o_p, chr_t *d_p )
 	if( get_lev( o_p, ABL_KIND_NIN ) <= 0 )
 		return FALSE;
 
-	o_val = o_val * 150 / _100_PERCENT;
+	o_val = o_val * NINJA_CRTCL_RATE / _100_PERCENT;
 
 	o_dice = roll_dice( o_val, FALSE );
 	d_dice = roll_dice( d_val, FALSE );
@@ -1973,9 +2152,13 @@ bool_t	chk_ninja_crtcl( chr_t *o_p, chr_t *d_p )
 		return FALSE;
 }
 
-/**/
+/***************************************************************
+* ˤ᡼׻
+* chr_t *p : 饯
+* return : ˤ᡼
+***************************************************************/
 
-long	get_dam_wand( chr_t *p )
+long	get_dam_stick( chr_t *p )
 {
 	abl_kind_t	abl_main, abl_sub;
 
@@ -1984,16 +2167,16 @@ long	get_dam_wand( chr_t *p )
 	if( p == NULL )
 		return 1;
 
-	abl_main = get_specialist_lev( p );
-	abl_sub = get_specialist_lev( p );
+	abl_main = get_specialist_abl( p );
+	abl_sub = get_specialist_abl( p );
 
 	dam = 0;
 	dam += calc_lev_to_val( get_lev( p, abl_main ), abl_main );
 	dam += calc_lev_to_val( get_lev( p, abl_sub ), abl_sub );
 	dam /= 2;
 
-	dam = dam * DAM_WAND_RATE / _100_PERCENT;
-	dam += DAM_WAND_ADD;
+	dam = dam * DAM_STICK_RATE / _100_PERCENT;
+	dam += DAM_STICK_ADD;
 
 	if( dam < 1 )
 		dam = 1;
@@ -2001,7 +2184,13 @@ long	get_dam_wand( chr_t *p )
 	return dam;
 }
 
-/**/
+/***************************************************************
+* ʸˤ᡼׻
+* chr_t *p : 饯
+* abl_kind_t abl_main : ǽͤμ
+* abl_kind_t abl_sub : ǽͤμ
+* return : ʸˤ᡼
+***************************************************************/
 
 long	get_dam_spell( chr_t *p, abl_kind_t abl_main, abl_kind_t abl_sub )
 {
@@ -2024,7 +2213,12 @@ long	get_dam_spell( chr_t *p, abl_kind_t abl_main, abl_kind_t abl_sub )
 	return dam;
 }
 
-/**/
+/***************************************************************
+* 饯ͤ׻
+* chr_t *p : 饯
+* resi_kind_t resi : ͤμ
+* return : 饯
+***************************************************************/
 
 rate_t	get_resi_def( chr_t *p, resi_kind_t resi )
 {
@@ -2042,7 +2236,12 @@ rate_t	get_resi_def( chr_t *p, resi_kind_t resi )
 	return n;
 }
 
-/**/
+/***************************************************************
+* 饯ƱΤεΥ顢ƻιΨ׻
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* return : ƻιΨ
+***************************************************************/
 
 rate_t	get_chr_throw_range_rate( chr_t *o_p, chr_t *d_p )
 {
@@ -2060,7 +2259,14 @@ rate_t	get_chr_throw_range_rate( chr_t *o_p, chr_t *d_p )
 	return rate;
 }
 
-/**/
+/***************************************************************
+* ֤εΥ顢ƻιΨ׻
+* long x1 : Xɸ
+* long y1 : Yɸ
+* long x2 : Xɸ
+* long y2 : Yɸ
+* return : ƻιΨ
+***************************************************************/
 
 rate_t	get_throw_range_rate( long x1, long y1, long x2, long y2 )
 {
@@ -2085,7 +2291,11 @@ rate_t	get_throw_range_rate( long x1, long y1, long x2, long y2 )
 	return rate;
 }
 
-/**/
+/***************************************************************
+* μ̤Υå֤
+* const attack_t *attack : ǡ
+* return : μ̤Υå
+***************************************************************/
 
 char	*get_msg_attack( const attack_t *attack )
 {
@@ -2144,6 +2354,3 @@ char	*get_msg_attack( const attack_t *attack )
 
 	return MSG_NULL;
 }
-
-/**/
-
