@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,41 +25,51 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fx.h,v 1.40 2004/12/24 21:52:50 bowkenken Exp $
+* $Id: fx.h,v 1.47 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	FX_H
 #define	FX_H
 
-/* ե */
+/***************************************************************
+* ե
+***************************************************************/
 
 #include	"abl-kind.h"
 
-/**/
+/***************************************************************
+* եȤθ̤ζ
+***************************************************************/
 
 #define	RESURRECTION_MIN_RATE	30
 #define	RESURRECTION_MAX_RATE	90
 
 #define	MAGIC_SHIELD_ADD_DEF_RATE	50
 #define	MAGIC_SHIELD_MAX_N	1
+
 #define	MAGE_ARMOR_ADD_AC_RATE	20
 #define	MAGE_ARMOR_MAX_N	3
+
 #define	SUBSTITUTE_ADD_DEF_RATE	20
 #define	SUBSTITUTE_ADD_AC_RATE	20
 #define	SUBSTITUTE_MAX_N	2
+
 #define	BURNING_HANDS_ADD_HIT_RATE	20
 #define	BURNING_HANDS_ADD_DAM_RATE	20
 #define	BURNING_HANDS_MAX_N	2
+
 #define	MIND_READING_ADD_WPN_CRTCL_RATE	20
 #define	MIND_READING_ADD_ARMOR_CRTCL_RATE	20
 #define	MIND_READING_MAX_N	2
 
-#define	FX_FACE_TRAP	'X'
-
-/*  */
+/***************************************************************
+* եȤʿѻ³
+***************************************************************/
 
+/* Ⱦʵ */
 #define	FX_TURN_INFINITE_N	(-1)
 
+/* Ǥǲ HP 뤫? */
 #define	FX_AVE_TURN_POISON_DEC	20
 
 #define	FX_AVE_TURN_STONE	FX_TURN_INFINITE_N
@@ -76,6 +86,7 @@
 #define	FX_AVE_TURN_VANISH	128
 #define	FX_AVE_TURN_IRON_BODY	32
 #define	FX_AVE_TURN_PASSWALL	128
+#define	FX_AVE_TURN_SENSE_INVISIBLE	128
 
 #define	FX_AVE_TURN_MAGIC_SHIELD	64
 #define	FX_AVE_TURN_MAGE_ARMOR	64
@@ -98,7 +109,9 @@
 #define	FX_AVE_TURN_FAINT	16
 #define	FX_TURN_DRUNK	1024
 
-/* եȤμ */
+/***************************************************************
+* եȤμ
+***************************************************************/
 
 typedef enum {
 	FX_KIND_NULL,
@@ -118,6 +131,7 @@ typedef enum {
 	FX_KIND_VANISH,
 	FX_KIND_IRON_BODY,
 	FX_KIND_PASSWALL,
+	FX_KIND_SENSE_INVISIBLE,
 	FX_KIND_WEAK_HEAT,
 	FX_KIND_WEAK_COLD,
 	FX_KIND_WEAK_MIND,
@@ -145,7 +159,6 @@ typedef enum {
 	FX_KIND_FOOLISH,
 	FX_KIND_ATTRACTIVE,
 	FX_KIND_UNATTRACTIVE,
-	FX_KIND_SENSE_INVISIBLE,
 	FX_KIND_POW_UP_HP,
 	FX_KIND_MAGIC_SHIELD,
 	FX_KIND_MAGE_ARMOR,
@@ -158,7 +171,9 @@ typedef enum {
 	FX_KIND_MAX_N,
 } fx_kind_t;
 
-/*  */
+/***************************************************************
+* HP  MP β
+***************************************************************/
 
 typedef struct {
 	long	count;
@@ -167,7 +182,9 @@ typedef struct {
 	long	n;
 } cure_t;
 
-/* ʢ */
+/***************************************************************
+* ʢ
+***************************************************************/
 
 typedef struct {
 	/* ߤΨ */
@@ -180,11 +197,15 @@ typedef struct {
 	/* ò */
 	long	digest_n;
 
-	/* ʢˤʤΨ䤹Ψ */
-	rate_t	hungry_rate, starvation_rate;
+	/* ʢˤʤΨ */
+	rate_t	hungry_rate;
+	/* 䤹Ψ */
+	rate_t	starvation_rate;
 } stomach_t;
 
-/* ˥¸ */
+/***************************************************************
+* ˥¸
+***************************************************************/
 
 typedef struct {
 	/* ˥ηǻ */
@@ -195,7 +216,9 @@ typedef struct {
 	rate_t	lost_rate;
 } nicotine_t;
 
-/* ե */
+/***************************************************************
+* ե
+***************************************************************/
 
 typedef struct fx {
 	/*  */
@@ -217,7 +240,9 @@ typedef struct fx {
 	abl_kind_t	abl_kind;
 } fx_t;
 
-/* μ */
+/***************************************************************
+* μ
+***************************************************************/
 
 typedef enum {
 	LIQUOR_KIND_RED_WINE,
@@ -229,18 +254,36 @@ typedef enum {
 	LIQUOR_KIND_MAX_N
 } liquor_kind_t;
 
+/***************************************************************
+* 
+***************************************************************/
+
 /* κȾ */
 
-#define	BLAST_MAX_X	32
-#define	BLAST_MAX_Y	32
+#define	BLAST_MAX_X	64
+#define	BLAST_MAX_Y	64
 
-/*  */
+/* μ */
+
+typedef enum {
+	BLAST_KIND_STD,
+	BLAST_KIND_NINJA_CRTCL,
+	BLAST_KIND_WORD_OF_DESTRUCTION,
+	BLAST_KIND_MAX_N
+} blast_kind_t;
+
+/* ǡ */
 
 typedef struct {
 	/* ľ */
 	long	xl, yl;
+
 	/* Ⱦ */
 	long	xr, yr;
+
+	/* Ʃʸ */
+	long	transmit_chr;
+
 	/* ѥ */
 	char	ptn[BLAST_MAX_Y + 1][BLAST_MAX_X + 1];
 } blast_t;
