@@ -30,8 +30,11 @@ bool_t	load_game_conf_id_brace(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id
 );
+bool_t	load_game_conf_lang( char *id, char *str );
 bool_t	load_game_conf_clk_tck( char *id, long val );
 bool_t	load_game_conf_scroll( char *id, char *str );
+bool_t	load_game_conf_clr_key_buf_every( char *id, long val );
+bool_t	load_game_conf_clr_key_buf_menu( char *id, long val );
 bool_t	load_game_conf_space_select( char *id, long val );
 bool_t	load_game_conf_redraw_every_turn( char *id, long val );
 bool_t	load_game_conf_mul_line( char *id, long val );
@@ -81,14 +84,22 @@ bool_t	save_town_ptn( town_ptn_t *ptn );
 void	save_town_ptn_col_1byte( FILE *fp, town_ptn_t *ptn );
 void	save_town_ptn_col_2byte( FILE *fp );
 bool_t	load_game_data( bool_t flg_txt, long n );
+bool_t	load_game_data_cnf( long n );
 void	ver_up_game_data_1_0_4( void );
+void	ver_up_game_data_1_1_1( void );
 void	reset_load_game_data( void );
+void	reset_load_game_data_cnf( void );
 bool_t	chk_load_game_data( void );
+bool_t	chk_load_game_data_cnf( void );
 bool_t	load_game_data_head_ver_1( FILE *fp, ver_t *ver, bool_t flg_txt );
 bool_t	load_game_data_ver_1( FILE *fp, const ver_t *ver, bool_t flg_txt );
+bool_t	load_game_data_cnf_ver_1( FILE *fp, const ver_t *ver );
 bool_t	load_game_data_parse_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	load_game_data_cnf_parse_ver_1(
+	FILE *fp, const ver_t *ver
+);
 bool_t	load_game_data_id_eq_num_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	char *id, long n
@@ -97,6 +108,10 @@ bool_t	load_game_data_id_num_eq_str_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	char *id, long n, char *str
 );
+bool_t	load_game_data_cnf_id_num_eq_str_ver_1(
+	FILE *fp, const ver_t *ver,
+	char *id, long n, char *str
+);
 bool_t	load_game_data_auto_mark_ttl_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	long n, char *ttl
@@ -105,6 +120,10 @@ bool_t	load_game_data_block_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	char *id, long n
 );
+bool_t	load_game_data_cnf_block_ver_1(
+	FILE *fp, const ver_t *ver,
+	char *id, long n
+);
 bool_t	load_game_data_class_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	long n
@@ -223,6 +242,10 @@ bool_t	load_game_data_item_rare_goods_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	mbr_t *mbr, item_t *item
 );
+bool_t	load_game_data_item_bone_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	mbr_t *mbr, item_t *item
+);
 bool_t	load_game_data_item_coin_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	mbr_t *mbr, item_t *item
@@ -266,9 +289,11 @@ bool_t	load_game_data_request_ver_1(
 bool_t	load_game_data_n( FILE *fp, long *n );
 bool_t	load_game_data_s( FILE *fp, char *s, long len );
 bool_t	load_game_data_c( FILE *fp, char *c );
-bool_t	load_game_data_skip_c( FILE *fp, rc_token_t c, bool_t flg_draw );
+bool_t	load_game_data_skip_c( FILE *fp, char c, bool_t flg_draw );
+bool_t	load_game_data_skip_token( FILE *fp, rc_token_t c, bool_t flg_draw );
 bool_t	save_game_data( bool_t flg_txt, long n );
 bool_t	save_game_data_ver_1( const ver_t *ver, bool_t flg_txt, long n );
+bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
 bool_t	save_game_data_turn_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
@@ -373,6 +398,10 @@ bool_t	save_game_data_item_rare_goods_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	mbr_t *mbr, item_t *item
 );
+bool_t	save_game_data_item_bone_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt,
+	mbr_t *mbr, item_t *item
+);
 bool_t	save_game_data_item_coin_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	mbr_t *mbr, item_t *item
@@ -426,6 +455,7 @@ bool_t	save_game_data_request_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
 FILE	*open_game_data( char type, long n, bool_t flg_txt );
+FILE	*open_game_data_cnf( char type, long n );
 bool_t	get_save_load_ttl( char *msg, long n, bool_t flg_txt );
 bool_t	get_game_data_head_time( char *str, long n, bool_t flg_txt );
 long	load_char( FILE *fp, bool_t flg_chk_eof );
@@ -440,7 +470,7 @@ long	get_rc_lex_line( void );
 bool_t	set_rc_lex_err( bool_t flg );
 bool_t	get_rc_lex_err( void );
 rc_token_t	rc_lex( FILE *fp, rc_union_t *u, bool_t flg_err_exit );
-void	rc_unlex( FILE *fp, rc_union_t *u, rc_token_t t );
+void	rc_unlex( FILE *fp, const rc_union_t *u, rc_token_t t );
 rc_token_t	rc_lex_char( FILE *fp, rc_union_t *u, bool_t flg_err_exit );
 rc_token_t	rc_lex_str( FILE *fp, rc_union_t *u, bool_t flg_err_exit );
 long	rc_lex_oct( FILE *fp, long len, bool_t flg_err_exit );
@@ -453,6 +483,34 @@ void	rc_lex_ungetc( FILE *fp, long c );
 bool_t	rename_back_up_file( char *fname );
 char	*get_out_map_file_name( char *s );
 bool_t	out_map_file( void );
+chr_kind_t	trans_idx_to_chr_kind( long idx );
+long	trans_chr_kind_to_idx( chr_kind_t k );
+main_race_t	trans_idx_to_main_race_kind( long idx );
+long	trans_main_race_kind_to_idx( main_race_t k );
+sub_race_t	trans_idx_to_sub_race_kind( long idx );
+long	trans_sub_race_kind_to_idx( sub_race_t k );
+sex_t	trans_idx_to_sex_kind( long idx );
+long	trans_sex_kind_to_idx( sex_t k );
+move_kind_t	trans_idx_to_move_kind( long idx );
+long	trans_move_kind_to_idx( move_kind_t k );
+move_ls_kind_t	trans_idx_to_move_ls_kind( long idx );
+long	trans_move_ls_kind_to_idx( move_ls_kind_t k );
+act_kind_t	trans_idx_to_act_kind( long idx );
+long	trans_act_kind_to_idx( act_kind_t k );
+trgt_kind_t	trans_idx_to_trgt_kind( long idx );
+long	trans_trgt_kind_to_idx( trgt_kind_t k );
+dist_t	trans_idx_to_dist_kind( long idx );
+long	trans_dist_kind_to_idx( dist_t k );
+auto_mark_trgt_t	trans_idx_to_am_trgt( long idx );
+long	trans_am_trgt_to_idx( auto_mark_trgt_t k );
+auto_mark_dist_t	trans_idx_to_am_dist( long idx );
+long	trans_am_dist_to_idx( auto_mark_dist_t k );
+auto_mark_act_t	trans_idx_to_am_act( long idx );
+long	trans_am_act_to_idx( auto_mark_act_t k );
+auto_mark_cond_t	trans_idx_to_am_cond( long idx );
+long	trans_am_cond_to_idx( auto_mark_cond_t k );
+attitude_t	trans_idx_to_attitude_kind( long idx );
+long	trans_attitude_kind_to_idx( attitude_t k );
 item_kind_t	trans_idx_to_item_kind( long idx );
 long	trans_item_kind_to_idx( item_kind_t k );
 wpn_kind_t	trans_idx_to_wpn_kind( long idx );
@@ -507,6 +565,7 @@ char	*cat_path( char *path, char *file );
 bool_t	chk_exist_file( char *s );
 bool_t	chk_exist_dir( char *s );
 bool_t	make_dir( char *path );
+bool_t	make_dir_node( char *path );
 char	*cv_esc_c( const long c );
 char	*cv_esc_str( const char *str );
 long	srandm_crypt( long n );
