@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,15 +25,364 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.2 2004/12/13 14:14:23 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.13 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
 #define	GFILE_TAB_H
 
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+***************************************************************/
+
 #include	"item-kind.h"
 #include	"spell-kind.h"
 
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* 饯μɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* 饯μ CHR_KIND_NULL ǡ롣
+***************************************************************/
+
+chr_kind_t	g_chr_trans_tab[] = {
+	CHR_KIND_NULL,
+	CHR_KIND_MBR,	/* С(PC) */
+	CHR_KIND_MNSTR,	/* 󥹥 */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ²ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ² MAIN_RACE_HUMAN ǡ롣
+***************************************************************/
+
+main_race_t	g_main_race_trans_tab[] = {
+	MAIN_RACE_HUMAN,
+	MAIN_RACE_HALF_ELF,
+	MAIN_RACE_ELF,
+	MAIN_RACE_DWARF,
+	MAIN_RACE_VIVID,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ²ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ² SUB_RACE_NULL ǡ롣
+***************************************************************/
+
+sub_race_t	g_sub_race_trans_tab[] = {
+	SUB_RACE_NULL,
+	SUB_RACE_CAT,
+	SUB_RACE_DOG,
+	SUB_RACE_MOUSE,
+	SUB_RACE_RABBIT,
+	SUB_RACE_MONKEY,
+	SUB_RACE_PIG,
+	SUB_RACE_BIRD,
+	SUB_RACE_LIZARD,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ̤ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ̤ SEX_NULL ǡ롣
+***************************************************************/
+
+sex_t	g_sex_trans_tab[] = {
+	SEX_NULL,
+
+	/*  */
+	FEMALE,
+
+	/*  */
+	MALE,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ⤭ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ⤭ MOVE_KIND_NULL ǡ롣
+***************************************************************/
+
+move_kind_t	g_move_trans_tab[] = {
+	MOVE_KIND_NULL,
+	MOVE_KIND_STOP,	/*  */
+	MOVE_KIND_STD,	/* (STanDard) */
+	MOVE_KIND_STAGGER,	/* եĤ */
+	MOVE_KIND_WANDER,	/*  */
+	MOVE_KIND_TOWNER,	/* ν̱ */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+*  ACT_KIND_NULL ǡ롣
+***************************************************************/
+
+act_kind_t	g_act_trans_tab[] = {
+	ACT_KIND_NULL,
+	ACT_KIND_MNSTR_FIGHT,
+	ACT_KIND_MNSTR_THROW,
+	ACT_KIND_MNSTR_STEAL,
+	ACT_KIND_MNSTR_TAIL,
+	ACT_KIND_MBR_FIGHT,
+	ACT_KIND_MBR_THROW,
+	ACT_KIND_MBR_STEAL,
+	ACT_KIND_MBR_TAIL,
+	ACT_KIND_DOOR_OPEN,
+	ACT_KIND_DOOR_CLOSE,
+	ACT_KIND_DOOR_JAM,
+	ACT_KIND_DOOR_DISARM,
+	ACT_KIND_DOOR_BREAK,
+	ACT_KIND_DOOR_PEEP,
+	ACT_KIND_DOOR_CHK,
+	ACT_KIND_TRAP_DISARM,
+	ACT_KIND_TRAP_BREAK,
+	ACT_KIND_TRAP_CHK,
+	ACT_KIND_ITEM_PICK_UP,
+	ACT_KIND_ITEM_OPEN,
+	ACT_KIND_ITEM_DISARM,
+	ACT_KIND_ITEM_BREAK,
+	ACT_KIND_ITEM_CHK,
+	ACT_KIND_ITEM_SEND,
+	ACT_KIND_ITEM_DROP,
+	ACT_KIND_ITEM_RECEIVE,
+	ACT_KIND_EQUIP_SEL,
+	ACT_KIND_EQUIP,
+	ACT_KIND_TAKE_OFF,
+	ACT_KIND_EQUIP_MBR,
+	ACT_KIND_TAKE_OFF_MBR,
+	ACT_KIND_POTION_QUAFF,
+	ACT_KIND_POTION_FILL,
+	ACT_KIND_SCROLL_READ,
+	ACT_KIND_STICK_ZAP,
+	ACT_KIND_FOOD_EAT,
+	ACT_KIND_TOBACCO_DISPOSE,
+	ACT_KIND_SRCH,
+	ACT_KIND_SPELL,
+
+	/* ѡƥΥ*/
+	ACT_KIND_SHOP,
+	ACT_KIND_RECALL,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* åȤɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* åȤ TRGT_KIND_NULL ǡ롣
+***************************************************************/
+
+trgt_kind_t	g_trgt_trans_tab[] = {
+	TRGT_KIND_NULL,
+	TRGT_KIND_MBR,
+	TRGT_KIND_MNSTR,
+	TRGT_KIND_MNSTR_NULL,	/* 󥹥ΤʤޡȤ */
+	TRGT_KIND_ITEM,
+	TRGT_KIND_DOOR,
+	TRGT_KIND_TRAP,
+	TRGT_KIND_QUEUE,
+	TRGT_KIND_SQUARE,
+	TRGT_KIND_POS,
+	TRGT_KIND_AUTO,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ֹ礤ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ֹ礤 DIST_NEAR ǡ롣
+***************************************************************/
+
+dist_t	g_dist_trans_tab[] = {
+	DIST_NEAR,	/* ᤯ */
+	DIST_MEDIUM,	/*  */
+	DIST_FAR,	/*  */
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ֹ礤ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ֹ礤 AUTO_MARK_TRGT_CLEAR ǡ롣
+***************************************************************/
+
+auto_mark_trgt_t	g_am_trgt_trans_tab[] = {
+	AUTO_MARK_TRGT_MNSTR,
+	AUTO_MARK_TRGT_ITEM,
+	AUTO_MARK_TRGT_DOOR,
+	AUTO_MARK_TRGT_TRAP,
+	AUTO_MARK_TRGT_MBR,
+	AUTO_MARK_TRGT_UNCHANGE,
+	AUTO_MARK_TRGT_CLEAR,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ֹ礤ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ֹ礤 AUTO_MARK_DIST_NEAR ǡ롣
+***************************************************************/
+
+auto_mark_dist_t	g_am_dist_trans_tab[] = {
+	AUTO_MARK_DIST_NEAR,
+	AUTO_MARK_DIST_MEDIUM,
+	AUTO_MARK_DIST_FAR,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ֹ礤ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ֹ礤 AUTO_MARK_ACT_FIGHT ǡ롣
+***************************************************************/
+
+auto_mark_act_t	g_am_act_trans_tab[] = {
+	AUTO_MARK_ACT_FIGHT,
+	AUTO_MARK_ACT_THROW,
+	AUTO_MARK_ACT_STEAL,
+	AUTO_MARK_ACT_TAIL,
+	AUTO_MARK_ACT_PICK_UP,
+	AUTO_MARK_ACT_BREAK,
+	AUTO_MARK_ACT_OPEN,
+	AUTO_MARK_ACT_CLOSE,
+	AUTO_MARK_ACT_JAM,
+	AUTO_MARK_ACT_DISARM,
+	AUTO_MARK_ACT_PEEP,
+	AUTO_MARK_ACT_CHK,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ֹ礤ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ֹ礤 AUTO_MARK_COND_NEAREST ǡ롣
+***************************************************************/
+
+auto_mark_cond_t	g_am_cond_trans_tab[] = {
+	/* äȤᤤʪ */
+	AUTO_MARK_COND_NEAREST,
+
+	/* Ф餱 */
+	AUTO_MARK_COND_DISPERSE,
+
+	/* ƤС */
+	AUTO_MARK_COND_STAGGER,
+
+	/* ƱʪäƤ */
+	AUTO_MARK_COND_OWN,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ⤭ǡμɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ⤭ǡμ MOVE_LS_KIND_FIND ǡ롣
+***************************************************************/
+
+move_ls_kind_t	g_move_ls_trans_tab[] = {
+	/* Сȯ */
+	MOVE_LS_KIND_FIND,
+
+	/* Сȯ */
+	MOVE_LS_KIND_NOT_FIND,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+* Ф˽֤ѹʤͤ
+* 
+* ١ȿɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* ١ȿ ATTITUDE_MATE ǡ롣
+***************************************************************/
+
+attitude_t	g_attitude_trans_tab[] = {
+	/*  */
+	ATTITUDE_MATE,
+	/* ͧŪ */
+	ATTITUDE_FRIENDLY,
+	/* Ω */
+	ATTITUDE_NEUTRAL,
+	/* ŨŪ */
+	ATTITUDE_ENEMY,
+};
+
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
@@ -66,6 +415,7 @@ item_kind_t	g_item_trans_tab[] = {
 	ITEM_KIND_RARE_GOODS,
 	ITEM_KIND_COIN,
 	ITEM_KIND_JUNK,
+	ITEM_KIND_BONE,
 };
 
 /***************************************************************
@@ -127,8 +477,9 @@ wpn_kind_t	g_wpn_trans_tab[] = {
 /*  */
 	WPN_KIND_LANCE,
 	WPN_KIND_LANCE_OF_LONGINUS,
-/* ե쥤 */
+/* ᥤ */
 	WPN_KIND_QUARTER_STAFF,
+/* ե쥤 */
 	WPN_KIND_LIGHT_FLAIL,
 	WPN_KIND_HEAVY_FLAIL,
 	WPN_KIND_MORNINGSTAR,
@@ -175,6 +526,8 @@ wpn_kind_t	g_wpn_trans_tab[] = {
 	WPN_KIND_BOOMERANG,
 /* 󥰡(ƥե) */
 	WPN_KIND_EXCALIBUR,
+/* ᥤ */
+	WPN_KIND_NUNCHAKUS,
 };
 
 /***************************************************************
@@ -385,6 +738,8 @@ scroll_kind_t	g_scroll_trans_tab[] = {
 	SCROLL_KIND_SUBSTITUTE,
 	SCROLL_KIND_BURNING_HANDS,
 	SCROLL_KIND_MIND_READING,
+/* ɲ */
+	SCROLL_KIND_IDENTIFY_ALL_ITEM,
 };
 
 /***************************************************************
@@ -816,6 +1171,7 @@ rare_goods_kind_t	g_rare_goods_trans_tab[] = {
 	RARE_GOODS_KIND_TICKET_TO_PARADISE,
 	RARE_GOODS_KIND_CALL_OF_HADES,
 	RARE_GOODS_KIND_MEMORIES_OF_THE_GOLDEN_AGE,
+	RARE_GOODS_KIND_ISNT_REALIZED,
 };
 
 /***************************************************************
@@ -1048,6 +1404,9 @@ spell_kind_t	g_spell_trans_tab[] = {
 	SPELL_KIND_NOTHING,
 	SPELL_KIND_POLTERGEIST,
 	SPELL_KIND_ANC_MAX_N,
+/* ɲ */
+	SPELL_KIND_IDENTIFY_ALL_ITEM,
+	SPELL_KIND_SUMMON_BONE,
 };
 
 /***************************************************************
@@ -1241,6 +1600,7 @@ trap_kind_t	g_trap_trans_tab[] = {
 	TRAP_KIND_TELEPORT,
 	TRAP_KIND_PIT,
 	TRAP_KIND_CHUTE,
+	TRAP_KIND_SANCTUARY,
 };
 
 /***************************************************************
