@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,62 +25,21 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.60 2004/12/10 08:35:39 bowkenken Exp $
+* $Id: gmain.c,v 1.69 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
-#include	<signal.h>
+/***************************************************************
+* ᥤ
+***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-#include	"turn.h"
-#include	"town.h"
-#include	"item.h"
-#include	"spell.h"
-#include	"chr.h"
-#include	"party.h"
-#include	"mnstr.h"
-#include	"pet.h"
-#include	"fight.h"
-#include	"fx.h"
-#include	"trap.h"
-#include	"draw.h"
-#include	"curs.h"
-#include	"menu.h"
-#include	"amenu.h"
-#include	"request.h"
-#include	"gfile.h"
-#include	"msg.h"
-#include	"ver.h"
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-#include	"turn-prot.h"
-#include	"dun-prot.h"
-#include	"town-prot.h"
-#include	"item-prot.h"
-#include	"spell-prot.h"
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"pet-prot.h"
-#include	"fight-prot.h"
-#include	"fx-prot.h"
-#include	"trap-prot.h"
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-#include	"menu-prot.h"
-#include	"tmenu-prot.h"
-#include	"amenu-prot.h"
-#include	"request-prot.h"
-#include	"gfile-prot.h"
-#include	"msg-prot.h"
+#define	EXTERN
 
-#ifdef	D_DOS
-# include	"main-dos-prot.h"
-#else	/* D_DOS */
-# include	"main-unix-prot.h"
-#endif	/* D_DOS */
+#define	GMAIN_C
+#include	"inc.h"
 
-/**/
+/***************************************************************
+* ν
+***************************************************************/
 
 void	init_arg( void )
 {
@@ -92,16 +51,24 @@ void	init_arg( void )
 	g_flg_debug = FALSE;
 #endif	/* NDEBUG */
 
-	g_flg_gui = FALSE;
 	g_flg_cui = TRUE;
+	g_flg_gui = FALSE;
+	g_gui_key_kind = GUI_KEY_KIND_CONSOLE;
+
 	g_flg_clr_key_buf = TRUE;
+	g_flg_clr_key_buf_menu = TRUE;
+
 	g_flg_echo_key = FALSE;
+
 	g_flg_use_curs = TRUE;
 	g_flg_use_keypad = FALSE;
+
 	g_flg_measure_clk_tck = FALSE;
 }
 
-/**/
+/***************************************************************
+* Τν
+***************************************************************/
 
 void	init_game( void )
 {
@@ -122,6 +89,10 @@ void	init_game( void )
 
 	init_game_file();
 
+	init_var_menu();
+	if( !load_game_conf() )
+		g_flg_measure_clk_tck = TRUE;
+
 	init_dun();
 	init_item();
 	init_trap();
@@ -140,16 +111,20 @@ void	init_game( void )
 	if( g_flg_debug )
 		set_flg_no_save( TRUE );
 
-	if( !load_game_conf() )
-		g_flg_measure_clk_tck = TRUE;
-
 	if( g_flg_measure_clk_tck )
 		measure_clk_tck();
 
 	dun = get_dun();
 	dun->lev = 0;
 	up_dun( 0 );
+}
 
+/***************************************************************
+* ᥤ󡦥롼
+***************************************************************/
+
+void	game_main( void )
+{
 	if( !g_flg_debug ){
 		door_t	*dr;
 
@@ -164,18 +139,16 @@ void	init_game( void )
 			exec_all_phase();
 		}
 	}
-}
 
-/**/
-
-void	game_main( void )
-{
 	while( 1 ){
 		chk_key( TRUE, TRUE );
 	}
 }
 
-/**/
+/***************************************************************
+* νλ
+* long code : λ
+***************************************************************/
 
 void	exit_game( long code )
 {
@@ -195,7 +168,9 @@ void	exit_game( long code )
 	exit( code );
 }
 
-/**/
+/***************************************************************
+* ɽ
+***************************************************************/
 
 void	about_game( void )
 {
@@ -218,7 +193,10 @@ void	about_game( void )
 	ena_scrn( FALSE );
 }
 
-/**/
+/***************************************************************
+* ΥСɽ
+* FILE *fp : ե
+***************************************************************/
 
 void	version( FILE *fp )
 {
@@ -226,7 +204,9 @@ void	version( FILE *fp )
 	fflush( fp );
 }
 
-/**/
+/***************************************************************
+* ƤӽФ
+***************************************************************/
 
 void	child_ps( void )
 {
@@ -237,7 +217,9 @@ void	child_ps( void )
 #endif	/* D_DOS */
 }
 
-/**/
+/***************************************************************
+* ʥν
+***************************************************************/
 
 void	init_signal( void )
 {
@@ -261,7 +243,10 @@ void	init_signal( void )
 #endif	/* D_X68K */
 }
 
-/**/
+/***************************************************************
+* ʥνϥɥ
+* int sig : ʥ
+***************************************************************/
 
 void	signal_handler( int sig )
 {
@@ -270,7 +255,9 @@ void	signal_handler( int sig )
 	exit( EXIT_FAILURE );
 }
 
-/**/
+/***************************************************************
+* ̤ν
+***************************************************************/
 
 void	init_scrn( void )
 {
@@ -278,7 +265,9 @@ void	init_scrn( void )
 	init_term();
 }
 
-/**/
+/***************************************************************
+* ̤Υꥻå
+***************************************************************/
 
 void	reset_scrn( void )
 {
@@ -291,7 +280,10 @@ void	reset_scrn( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ̤ͭ
+* bool_t flg_initscr : curses 뤫?
+***************************************************************/
 
 void	ena_scrn( bool_t flg_initscr )
 {
@@ -306,7 +298,9 @@ void	ena_scrn( bool_t flg_initscr )
 	ena_term();
 }
 
-/**/
+/***************************************************************
+* ̵̤
+***************************************************************/
 
 void	dis_scrn( void )
 {
@@ -316,7 +310,9 @@ void	dis_scrn( void )
 	curs_endwin();
 }
 
-/**/
+/***************************************************************
+* üν
+***************************************************************/
 
 void	init_term( void )
 {
@@ -327,7 +323,10 @@ void	init_term( void )
 #endif	/* D_DOS */
 }
 
-/**/
+/***************************************************************
+* üͭĴ٤
+* return : üͭ?
+***************************************************************/
 
 bool_t	chk_term( void )
 {
@@ -338,7 +337,9 @@ bool_t	chk_term( void )
 #endif	/* D_DOS */
 }
 
-/**/
+/***************************************************************
+* üͭ
+***************************************************************/
 
 void	ena_term( void )
 {
@@ -349,7 +350,9 @@ void	ena_term( void )
 #endif	/* D_DOS */
 }
 
-/**/
+/***************************************************************
+* ü̵
+***************************************************************/
 
 void	dis_term( void )
 {
@@ -360,7 +363,9 @@ void	dis_term( void )
 #endif	/* D_DOS */
 }
 
-/**/
+/***************************************************************
+* Ԥ
+***************************************************************/
 
 void	set_key_wait( void )
 {
@@ -371,7 +376,9 @@ void	set_key_wait( void )
 #endif	/* D_DOS */
 }
 
-/**/
+/***************************************************************
+* Ԥ
+***************************************************************/
 
 void	clr_key_wait( void )
 {
@@ -382,5 +389,3 @@ void	clr_key_wait( void )
 #endif	/* D_DOS */
 }
 
-/**/
-
