@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,15 +25,21 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.33 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: gmain.h,v 1.45 2006/01/14 16:32:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
 #define	GMAIN_H
 
-#if	D_DOS
+/***************************************************************
+* ᥤ
+***************************************************************/
+
+#if	defined( D_WIN )
+# include	"config-win.h"
+#elif	defined( D_DOS )
 # include	"lnl-dos/config-dos.h"
-#endif	/* USE_DOS */
+#endif
 
 #if	HAVE_CONFIG_H
 # include	"config.h"
@@ -99,37 +105,62 @@
 #define	EXIT_FAILURE	1
 #endif	/* EXIT_FAILURE */
 
-/**/
+/***************************************************************/
 
 #include	"misc.h"
 #include	"turn.h"
 
 #include	"msg-t.h"
 
+/***************************************************************
+* 
+***************************************************************/
+
+/* Ϥɤɤफ? */
+
+typedef enum {
+	GUI_KEY_KIND_CONSOLE,
+	GUI_KEY_KIND_CLASS_KEY,
+	GUI_KEY_KIND_KEY_BUF_INTERRUPT,
+	GUI_KEY_KIND_MAX_N,
+} gui_key_kind_t;
+
+/***************************************************************
+* ѿ
+***************************************************************/
+
+#include	"extern.h"
+
 /* ե饰 */
 
-/* GUI ⡼ */
-bool_t	g_flg_gui;
-
 /* CUI ⡼ */
-bool_t	g_flg_cui;
+EXTERN bool_t	g_flg_cui;
+
+/* GUI ⡼ */
+EXTERN bool_t	g_flg_gui;
+
+/* Ϥɤɤफ? */
+EXTERN gui_key_kind_t	g_gui_key_kind;
 
 /* Хåե򥯥ꥢ */
-bool_t	g_flg_clr_key_buf;
+EXTERN bool_t	g_flg_clr_key_buf;
+
+/* Хåե򥯥ꥢʥ˥塼 */
+EXTERN bool_t	g_flg_clr_key_buf_menu;
 
 /* Ϥ줿ɽ */
-bool_t	g_flg_echo_key;
+EXTERN bool_t	g_flg_echo_key;
 
 /* ̤ curses 饤֥Ѥ */
-bool_t	g_flg_use_curs;
+EXTERN bool_t	g_flg_use_curs;
 
 /* 롦Ѥ */
-bool_t	g_flg_use_keypad;
+EXTERN bool_t	g_flg_use_keypad;
 
 /* ե졼ࡦ졼Ȥ¬ */
-bool_t	g_flg_measure_clk_tck;
+EXTERN bool_t	g_flg_measure_clk_tck;
 
 /* ǥХå⡼ */
-bool_t	g_flg_debug;
+EXTERN bool_t	g_flg_debug;
 
 #endif	/* GMAIN_H */
