@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,84 +25,42 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-unix.c,v 1.3 2004/12/10 11:18:55 bowkenken Exp $
+* $Id: main-unix.c,v 1.11 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"misc.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-/*#include	"item.h"*/
-/*#include	"spell.h"*/
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-/*#include	"pet.h"*/
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-#include	"msg.h"
-#include	"ver.h"
+/***************************************************************
+* UNIX ѤΥᥤ
+***************************************************************/
 
-#include	"gmain-prot.h"
-/*#include	"misc-prot.h"*/
-/*#include	"turn-prot.h"*/
-/*#include	"dun-prot.h"*/
-/*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
-/*#include	"spell-prot.h"*/
-/*#include	"chr-prot.h"*/
-/*#include	"party-prot.h"*/
-/*#include	"mnstr-prot.h"*/
-/*#include	"pet-prot.h"*/
-/*#include	"fight-prot.h"*/
-/*#include	"fx-prot.h"*/
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+#define	MAIN_UNIX_C
+#include	"inc.h"
 
-#include	"main-unix-prot.h"
-
-/**/
-
-#if	HAVE_GETOPT_H
-# include	<getopt.h>
-#endif	/* HAVE_GETOPT_H */
-
-#if	HAVE_TERMIOS_H
-# include	<termios.h>
-#elif	HAVE_TERMIO_H
-# include	<termio.h>
-#endif
+/***************************************************************/
 
 #if	HAVE_TERMIOS_H
 struct termios	pre_tbuf;
-#elif	HAVE_TERMIO_H
+# elif	HAVE_TERMIO_H
 struct termio	pre_tbuf;
 #endif
 
-/**/
+/***************************************************************
+* 
+***************************************************************/
 
 #define	STR_ENV_SHELL	"SHELL"
 #define	STR_DFLT_SHELL	"sh"
 
+/***************************************************************
+* Ԥ
+***************************************************************/
+
 #define	KEY_WAIT_VMIN	0
 #define	KEY_WAIT_VTIME	1
 
+/***************************************************************
+* 
+***************************************************************/
+
 #define	OPT_ARG_MAX_LEN	128
 #define	STR_OPT	"gcuk:e:s:p:m:d:Vh"
 
@@ -123,6 +81,10 @@ static struct option	long_opt[] = {
 };
 #endif	/* HAVE_GETOPT */
 
+/***************************************************************
+* 
+***************************************************************/
+
 char	str_usage[] = {
 	"Usage: %s [OPTION]...\n"
 	"OPTION:\n"
@@ -149,11 +111,18 @@ char	str_usage[] = {
 	"  -h, --help               display this help and exit\n"
 };
 
-/**/
+/***************************************************************
+* ѿ
+***************************************************************/
 
 long	flg_term;
 
-/**/
+/***************************************************************
+* ᥤ󡦥롼
+* int argc : ο
+* char **argv : Υꥹ
+* return : λ
+***************************************************************/
 
 int	main( int argc, char **argv )
 {
@@ -166,10 +135,17 @@ int	main( int argc, char **argv )
 	return EXIT_FAILURE;
 }
 
-/**/
+/***************************************************************
+* ν
+* int argc : ο
+* char **argv : Υꥹ
+***************************************************************/
 
 void	chk_arg( int argc, char **argv )
 {
+	if( argv == NULL )
+		return;
+
 #if	HAVE_GETOPT || HAVE_GETOPT_LONG
 	while( 1 ){
 		long	c;
@@ -185,19 +161,20 @@ void	chk_arg( int argc, char **argv )
 			break;
 		switch( c ){
 		case 'g':
-			g_flg_gui = TRUE;
 			g_flg_cui = FALSE;
+			g_flg_gui = TRUE;
 			break;
 		case 'c':
-			g_flg_gui = FALSE;
 			g_flg_cui = TRUE;
+			g_flg_gui = FALSE;
 			break;
 		case 'u':
-			g_flg_gui = TRUE;
 			g_flg_cui = TRUE;
+			g_flg_gui = TRUE;
 			break;
 		case 'k':
 			g_flg_clr_key_buf = chk_opt_flg( optarg );
+			g_flg_clr_key_buf_menu = g_flg_clr_key_buf;
 			break;
 		case 'e':
 			g_flg_echo_key = chk_opt_flg( optarg );
@@ -240,7 +217,11 @@ void	chk_arg( int argc, char **argv )
 #endif	/* HAVE_GETOPT || HAVE_GETOPT_LONG */
 }
 
-/**/
+/***************************************************************
+* Υ󡿥դΥե饰å
+* const char *optarg : ץʸ
+* return : ե饰?
+***************************************************************/
 
 bool_t	chk_opt_flg( const char *optarg )
 {
@@ -285,7 +266,10 @@ bool_t	chk_opt_flg( const char *optarg )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ɽ
+* FILE *fp : ե
+***************************************************************/
 
 void	usage( FILE *fp )
 {
@@ -296,7 +280,9 @@ void	usage( FILE *fp )
 	fflush( fp );
 }
 
-/**/
+/***************************************************************
+* θƤӽФ
+***************************************************************/
 
 void	child_ps_unix( void )
 {
@@ -318,21 +304,28 @@ void	child_ps_unix( void )
 	ena_scrn( FALSE );
 }
 
-/**/
+/***************************************************************
+* üν
+***************************************************************/
 
 void	init_term_unix( void )
 {
 	flg_term = 0;
 }
 
-/**/
+/***************************************************************
+* üͭĴ٤
+* return : üͭ?
+***************************************************************/
 
 bool_t	chk_term_unix( void )
 {
 	return( flg_term > 0 );
 }
 
-/**/
+/***************************************************************
+* üͭˤ
+***************************************************************/
 
 void	ena_term_unix( void )
 {
@@ -391,7 +384,9 @@ void	ena_term_unix( void )
 #endif	/* (HAVE_TERMIOS_H || HAVE_TERMIO_H) */
 }
 
-/**/
+/***************************************************************
+* ü̵ˤ
+***************************************************************/
 
 void	dis_term_unix( void )
 {
@@ -409,21 +404,28 @@ void	dis_term_unix( void )
 	flg_term--;
 }
 
-/**/
+/***************************************************************
+* Ԥ
+***************************************************************/
 
 void	set_key_wait_unix( void )
 {
 	set_key_wait_vtime( KEY_WAIT_VTIME );
 }
 
-/**/
+/***************************************************************
+* Ԥ
+***************************************************************/
 
 void	clr_key_wait_unix( void )
 {
 	set_key_wait_vtime( 0 );
 }
 
-/**/
+/***************************************************************
+* Ԥ֤
+* long wait_vtime : Ԥ
+***************************************************************/
 
 void	set_key_wait_vtime( long wait_vtime )
 {
@@ -463,5 +465,3 @@ void	set_key_wait_vtime( long wait_vtime )
 #endif	/* (HAVE_TERMIOS_H || HAVE_TERMIO_H) */
 }
 
-/**/
-
