@@ -4,9 +4,11 @@
 extern "C" {
 #endif
 
+void	init_var_menu( void );
 void	init_menu( void );
 void	init_ls_menu_macro( void );
 char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
+bool_t	chk_err_menu_kind( menu_t *ls );
 bool_t	set_menu_check_item( menu_t *p );
 bool_t	set_menu_radio_item( menu_t *ls, menu_t *p );
 ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel );
@@ -130,10 +132,14 @@ char	*menu_sel_mnstr_data( void );
 char	*cb_menu_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_divide_gold( menu_t **pp, menu_t **dflt );
+char	*cb_menu_give_gold( menu_t **pp, menu_t **dflt );
+char	*menu_mbr_give_gold( mbr_t *mbr_from );
 char	*cb_menu_formation( menu_t **pp, menu_t **dflt );
 void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n );
 char	*cb_menu_formation_sel_n( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
+void	move_crsr_abs( long x, long y );
+void	move_crsr_rel( long dx, long dy );
 char	*cb_menu_crsr_move(
 	menu_t **pp, menu_t **dflt
 );
@@ -143,7 +149,9 @@ char	*cb_menu_crsr_quick_move(
 char	*cb_menu_crsr_move_mbr(
 	menu_t **pp, menu_t **dflt
 );
-char	*cb_menu_crsr_scroll_center(
+char	*menu_crsr_move_mbr_n( long mbr_n );
+char	*menu_crsr_move_mbr( mbr_t *mbr );
+char	*cb_menu_crsr_center(
 	menu_t **pp, menu_t **dflt
 );
 char	*cb_menu_crsr_next_pos_mbr(
@@ -191,13 +199,18 @@ void	set_scroll_smooth( void );
 void	set_scroll_center( void );
 char	*cb_menu_actual_fighting( menu_t **pp, menu_t **dflt );
 char	*cb_menu_space_select( menu_t **pp, menu_t **dflt );
+char	*cb_menu_lang( menu_t **pp, menu_t **dflt );
+char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt );
+char	*cb_menu_lang_ls_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_lang_ls_priority( menu_t **pp, menu_t **dflt );
 char	*cb_menu_window( menu_t **pp, menu_t **dflt );
 char	*cb_menu_redraw_every_turn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
-char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx_mbr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx_mnstr( menu_t **pp, menu_t **dflt );
+char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt );
+char	*cb_menu_vfx_measure_clk_tck( menu_t **pp, menu_t **dflt );
 char	*cb_menu_color( menu_t **pp, menu_t **dflt );
 char	*cb_menu_color_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_fg_init( menu_t **pp, menu_t **dflt );
@@ -212,11 +225,18 @@ char	*cb_menu_attr( menu_t **pp, menu_t **dflt );
 void	set_color_attr( curs_attr_t *attr, bool_t flg_on, chtype_t ch );
 char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_key_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_clr_key_buf_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_clr_key_buf_every( menu_t **pp, menu_t **dflt );
+char	*cb_menu_clr_key_buf_menu( menu_t **pp, menu_t **dflt );
+char	*cb_menu_echo_key( menu_t **pp, menu_t **dflt );
 char	*cb_menu_set_key( menu_t **pp, menu_t **dflt );
 char	*cb_menu_unset_key( menu_t **pp, menu_t **dflt );
 char	*cb_menu_macro( menu_t **pp, menu_t **dflt );
 char	*cb_menu_macro_exec( menu_t **pp, menu_t **dflt );
 char	*cb_menu_macro_edit( menu_t **pp, menu_t **dflt );
+char	*cb_menu_system( menu_t **pp, menu_t **dflt );
+char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt );
@@ -274,16 +294,16 @@ bool_t	next_pos_all( long d );
 void	wait_key( bool_t flg_can_move_crsr );
 void	wait_key_ex( bool_t flg_exec_key, bool_t flg_can_move_crsr );
 long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu );
-void	chk_dup_accel_key( void );
-void	chk_dup_accel_key_init( void );
-bool_t	chk_dup_accel_key_main( menu_t *ls );
-bool_t	chk_dup_accel_key_sub( unsigned char c, menu_t *ls );
-bool_t	chk_accel_key( menu_t *ls, long c );
+void	chk_dup_short_key( void );
+void	chk_dup_short_key_init( void );
+bool_t	chk_dup_short_key_main( menu_t *ls );
+bool_t	chk_dup_short_key_sub( unsigned char c, menu_t *ls );
+bool_t	chk_short_key( menu_t *ls, long c );
 void	jump_crsr( long dx, long dy );
 void	scroll_smooth( void );
 void	scroll_center( void );
 void	scroll_half_page( void );
-void	chk_scroll( void );
+void	chk_scroll( bool_t flg_gui );
 void	move_crsr_mbr_trgt( mbr_t *mbr );
 char	*cb_menu_user( menu_t **pp, menu_t **dflt );
 void	clr_user_menu( void );
@@ -298,7 +318,9 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl );
 char	*cb_menu_user_arrange_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
 void	set_menu_dflt_main( menu_t *p );
+void	update_crsr( void );
 pos_t	*get_crsr( void );
+pos_t	*get_pre_crsr( void );
 pos_t	*get_sub_crsr( void );
 pos_t	*get_pre_sub_crsr( void );
 flg_scroll_t	get_flg_scroll( void );
