@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu-tab.h,v 1.3 2004/12/23 06:12:38 bowkenken Exp $
+* $Id: menu-tab.h,v 1.15 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_TAB_H
@@ -40,14 +40,33 @@
 /**/
 
 #if	0
-	"<Title>"	/* ȥ */
-	"<Item>"	/*  */
-	"<CheckItem>"	/* å */
-	"<RadioItem>"	/*  */
-	"<OpenWinItem>"	/* ̥ɥ򳫤 */
-	"<Separator>"	/* <RadioItem>ζڤ */
-	"<PageSeparator>"	/* ˥塼ʣڡͭζڤ */
-	"<Branch>"	/* ֥˥塼 */
+char	*menu_kind_ls[] = {
+	/* ȥ */
+	"<Title>",
+
+	/*  */
+	"<Item>",
+
+	/* å */
+	"<CheckItem>",
+
+	/*  */
+	"<RadioItem>",
+
+	/* ̥ɥ򳫤 */
+	"<OpenWinItem>",
+
+	/* <RadioItem>ζڤ */
+	"<Separator>",
+
+	/* ˥塼ʣڡͭζڤ */
+	"<PageSeparator>",
+
+	/* ֥˥塼 */
+	"<Branch>",
+
+	NULL,
+};
 #endif
 
 #if	0
@@ -80,7 +99,7 @@ typedef struct menu_t {
 
 menu_t	ls_menu_ask[] = {
 	{
-		"/Ask",
+		"/ask",
 		"<Branch>",
 		'\0',
 		"",
@@ -89,7 +108,7 @@ menu_t	ls_menu_ask[] = {
 		FLG_NULL,
 	},
 	{
-		"/Ask/Title",
+		"/ask/title",
 		"<Title>",
 		'\0',
 		"",
@@ -98,7 +117,7 @@ menu_t	ls_menu_ask[] = {
 		FLG_NULL,
 	},
 	{
-		"/Ask/Yes",
+		"/ask/yes",
 		"<Item>",
 		'Y',
 		"",
@@ -107,7 +126,7 @@ menu_t	ls_menu_ask[] = {
 		FLG_NULL,
 	},
 	{
-		"/Ask/No",
+		"/ask/no",
 		"<Item>",
 		'N',
 		"",
@@ -128,7 +147,7 @@ menu_t	ls_menu_ask[] = {
 
 menu_t	ls_menu_main_race[] = {
 	{
-		"/Main Race",
+		"/main race",
 		"<Branch>",
 		'\0',
 		"",
@@ -137,7 +156,7 @@ menu_t	ls_menu_main_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Main Race/Title",
+		"/main race/title",
 		"<Title>",
 		'\0',
 		"",
@@ -146,7 +165,7 @@ menu_t	ls_menu_main_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Main Race/Human",
+		"/main race/human",
 		"<Item>",
 		'H',
 		"",
@@ -155,7 +174,7 @@ menu_t	ls_menu_main_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Main Race/Half elf",
+		"/main race/half elf",
 		"<Item>",
 		'F',
 		"",
@@ -164,7 +183,7 @@ menu_t	ls_menu_main_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Main Race/Elf",
+		"/main race/elf",
 		"<Item>",
 		'E',
 		"",
@@ -173,7 +192,7 @@ menu_t	ls_menu_main_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Main Race/Dwarf",
+		"/main race/dwarf",
 		"<Item>",
 		'D',
 		"",
@@ -182,7 +201,7 @@ menu_t	ls_menu_main_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Main Race/Bibit",
+		"/main race/bibit",
 		"<Item>",
 		'B',
 		"",
@@ -203,7 +222,7 @@ menu_t	ls_menu_main_race[] = {
 
 menu_t	ls_menu_sub_race[] = {
 	{
-		"/Sub Race",
+		"/sub race",
 		"<Branch>",
 		'\0',
 		"",
@@ -212,7 +231,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Title",
+		"/sub race/title",
 		"<Title>",
 		'\0',
 		"",
@@ -221,7 +240,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Null",
+		"/sub race/null",
 		"<Item>",
 		'N',
 		"",
@@ -230,7 +249,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Cat",
+		"/sub race/cat",
 		"<Item>",
 		'C',
 		"",
@@ -239,7 +258,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Dog",
+		"/sub race/dog",
 		"<Item>",
 		'D',
 		"",
@@ -248,7 +267,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Mouse",
+		"/sub race/mouse",
 		"<Item>",
 		'U',
 		"",
@@ -257,7 +276,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Rabbit",
+		"/sub race/rabbit",
 		"<Item>",
 		'R',
 		"",
@@ -266,7 +285,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Monkey",
+		"/sub race/monkey",
 		"<Item>",
 		'K',
 		"",
@@ -275,7 +294,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Pig",
+		"/sub race/pig",
 		"<Item>",
 		'P',
 		"",
@@ -284,7 +303,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Bird",
+		"/sub race/bird",
 		"<Item>",
 		'B',
 		"",
@@ -293,7 +312,7 @@ menu_t	ls_menu_sub_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sub Race/Lizard",
+		"/sub race/lizard",
 		"<Item>",
 		'L',
 		"",
@@ -314,7 +333,7 @@ menu_t	ls_menu_sub_race[] = {
 
 menu_t	ls_menu_sex[] = {
 	{
-		"/Sex",
+		"/sex",
 		"<Branch>",
 		'\0',
 		"",
@@ -323,7 +342,7 @@ menu_t	ls_menu_sex[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sex/Title",
+		"/sex/title",
 		"<Title>",
 		'\0',
 		"",
@@ -332,7 +351,7 @@ menu_t	ls_menu_sex[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sex/male",
+		"/sex/male",
 		"<Item>",
 		'M',
 		"",
@@ -341,7 +360,7 @@ menu_t	ls_menu_sex[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sex/Female",
+		"/sex/female",
 		"<Item>",
 		'F',
 		"",
@@ -374,16 +393,16 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark",
+		"/mark",
 		"<OpenWinItem>",
-		'K',
+		'M',
 		"",
 		N_MSG_MENU_MARK, "",
 		cb_menu_mark, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Move",
+		"/move",
 		"<Item>",
 		'V',
 		"v",
@@ -392,7 +411,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Exec",
+		"/exec",
 		"<Item>",
 		'X',
 		". 5",
@@ -401,7 +420,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Item",
+		"/item",
 		"<Branch>",
 		'I',
 		"i",
@@ -410,7 +429,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Equip",
+		"/equip",
 		"<Branch>",
 		'E',
 		"e",
@@ -419,7 +438,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Fight",
+		"/fight",
 		"<OpenWinItem>",
 		'F',
 		"f",
@@ -428,7 +447,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Spell",
+		"/spell",
 		"<Branch>",
 		'C',
 		"c",
@@ -438,16 +457,16 @@ menu_t	ls_menu_main[] = {
 	},
 /* misc begin */
 	{
-		"/Misc",
+		"/misc",
 		"<Branch>",
-		'M',
+		'S',
 		"",
 		N_MSG_MENU_MISC, "",
 		cb_menu_misc, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/Stairs",
+		"/misc/stairs",
 		"<Branch>",
 		'T',
 		"",
@@ -456,7 +475,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Stairs/Up",
+		"/misc/stairs/up",
 		"<Item>",
 		'U',
 		"<",
@@ -465,7 +484,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Stairs/Down",
+		"/misc/stairs/down",
 		"<Item>",
 		'D',
 		">",
@@ -474,7 +493,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Search",
+		"/misc/search",
 		"<Branch>",
 		'S',
 		"# ^S s",
@@ -483,7 +502,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Hint",
+		"/misc/hint",
 		"<Item>",
 		'I',
 		"?",
@@ -492,7 +511,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Char Data",
+		"/misc/char data",
 		"<OpenWinItem>",
 		'D',
 		"d",
@@ -501,7 +520,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Gold",
+		"/misc/gold",
 		"<Branch>",
 		'G',
 		"",
@@ -510,7 +529,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Gold/Collect",
+		"/misc/gold/collect",
 		"<Item>",
 		'C',
 		"",
@@ -519,7 +538,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Gold/Divide",
+		"/misc/gold/divide",
 		"<Item>",
 		'D',
 		"",
@@ -528,7 +547,16 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Formation",
+		"/misc/gold/give",
+		"<Item>",
+		'G',
+		"",
+		N_MSG_MENU_GIVE_GOLD, "",
+		cb_menu_give_gold, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/formation",
 		"<Branch>",
 		'F',
 		"",
@@ -537,7 +565,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Cursor",
+		"/misc/cursor",
 		"<Branch>",
 		'V',
 		"",
@@ -546,7 +574,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/List Message",
+		"/misc/list message",
 		"<OpenWinItem>",
 		'M',
 		"g",
@@ -555,7 +583,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/List Monster",
+		"/misc/list monster",
 		"<Item>",
 		'L',
 		"",
@@ -564,7 +592,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/List Request",
+		"/misc/list request",
 		"<Branch>",
 		'R',
 		"r",
@@ -574,7 +602,7 @@ menu_t	ls_menu_main[] = {
 	},
 /* config begin */
 	{
-		"/Misc/Config",
+		"/misc/config",
 		"<Branch>",
 		'C',
 		"",
@@ -583,7 +611,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Auto fight",
+		"/misc/config/auto fight",
 		"<Branch>",
 		'F',
 		"",
@@ -592,7 +620,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Auto open door",
+		"/misc/config/auto open door",
 		"<Branch>",
 		'D',
 		"",
@@ -601,7 +629,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Avoid trap",
+		"/misc/config/avoid trap",
 		"<Branch>",
 		'T',
 		"",
@@ -610,7 +638,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Reload arrow",
+		"/misc/config/reload arrow",
 		"<Branch>",
 		'A',
 		"",
@@ -619,43 +647,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Scroll",
-		"<Branch>",
-		'R',
-		"",
-		N_MSG_MENU_SCROLL_MODE, "",
-		cb_menu_scroll_init, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Misc/Config/Scroll/Page",
-		"<RadioItem>",
-		'P',
-		"",
-		N_MSG_MENU_SCROLL_PAGE, "",
-		cb_menu_scroll_page, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Misc/Config/Scroll/Smooth",
-		"<RadioItem>",
-		'S',
-		"",
-		N_MSG_MENU_SCROLL_SMOOTH, "",
-		cb_menu_scroll_smooth, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Misc/Config/Scroll/Center",
-		"<RadioItem>",
-		'C',
-		"",
-		N_MSG_MENU_SCROLL_CENTER, "",
-		cb_menu_scroll_center, NULL,
-		FLG_NULL,
-	},
-	{
-		"/Misc/Config/Actual Fighting",
+		"/misc/config/actual fighting",
 		"<CheckItem>",
 		'I',
 		"",
@@ -664,7 +656,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Space Select",
+		"/misc/config/space select",
 		"<CheckItem>",
 		'S',
 		"",
@@ -673,7 +665,43 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Window",
+		"/misc/config/lang",
+		"<Branch>",
+		'L',
+		"",
+		N_MSG_MENU_LANG, "",
+		cb_menu_lang, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/lang/title",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MENU_LANG, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/lang/list",
+		"<Branch>",
+		'L',
+		"",
+		N_MSG_MENU_LANG_LS, "",
+		cb_menu_lang_ls, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/lang/list priority",
+		"<CheckItem>",
+		'P',
+		"",
+		N_MSG_MENU_LANG_LS_PRIORITY, "",
+		cb_menu_lang_ls_priority, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/window",
 		"<Branch>",
 		'W',
 		"",
@@ -682,7 +710,52 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Window/Redraw Every Turn",
+		"/misc/config/window/title",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MENU_WINDOW, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/window/scroll",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_SCROLL_MODE, "",
+		cb_menu_scroll_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/window/scroll/page",
+		"<RadioItem>",
+		'P',
+		"",
+		N_MSG_MENU_SCROLL_PAGE, "",
+		cb_menu_scroll_page, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/window/scroll/smooth",
+		"<RadioItem>",
+		'S',
+		"",
+		N_MSG_MENU_SCROLL_SMOOTH, "",
+		cb_menu_scroll_smooth, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/window/scroll/center",
+		"<RadioItem>",
+		'C',
+		"",
+		N_MSG_MENU_SCROLL_CENTER, "",
+		cb_menu_scroll_center, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/window/redraw every turn",
 		"<CheckItem>",
 		'D',
 		"",
@@ -691,7 +764,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Window/Multi Message",
+		"/misc/config/window/multi message",
 		"<CheckItem>",
 		'M',
 		"",
@@ -701,7 +774,7 @@ menu_t	ls_menu_main[] = {
 	},
 /* VFX begin */
 	{
-		"/Misc/Config/VFX",
+		"/misc/config/vfx",
 		"<Branch>",
 		'X',
 		"",
@@ -710,7 +783,16 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Member cure",
+		"/misc/config/vfx/title",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MENU_VFX, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/vfx/member cure",
 		"<CheckItem>",
 		'A',
 		"",
@@ -719,7 +801,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Member dam",
+		"/misc/config/vfx/member dam",
 		"<CheckItem>",
 		'B',
 		"",
@@ -728,7 +810,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Member critical",
+		"/misc/config/vfx/member critical",
 		"<CheckItem>",
 		'C',
 		"",
@@ -737,7 +819,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Member arrow",
+		"/misc/config/vfx/member arrow",
 		"<CheckItem>",
 		'D',
 		"",
@@ -746,7 +828,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Monster cure",
+		"/misc/config/vfx/monster cure",
 		"<CheckItem>",
 		'E',
 		"",
@@ -755,7 +837,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Monster dam",
+		"/misc/config/vfx/monster dam",
 		"<CheckItem>",
 		'F',
 		"",
@@ -764,7 +846,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Monster critical",
+		"/misc/config/vfx/monster critical",
 		"<CheckItem>",
 		'G',
 		"",
@@ -773,7 +855,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Monster arrow",
+		"/misc/config/vfx/monster arrow",
 		"<CheckItem>",
 		'H',
 		"",
@@ -782,17 +864,26 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/VFX/Wait",
-		"<Item>",
-		'Z',
+		"/misc/config/vfx/wait",
+		"<OpenWinItem>",
+		'W',
 		"",
 		N_MSG_MENU_VFX_WAIT, "",
 		cb_menu_vfx_wait, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/vfx/measure clock",
+		"<Item>",
+		'X',
+		"",
+		N_MSG_MENU_VFX_MEASURE_CLK_TCK, "",
+		cb_menu_vfx_measure_clk_tck, NULL,
+		FLG_NULL,
+	},
 /* VFX end */
 	{
-		"/Misc/Config/Color",
+		"/misc/config/color",
 		"<Branch>",
 		'C',
 		"",
@@ -801,7 +892,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Cursor Pattern",
+		"/misc/config/cursor pattern",
 		"<Branch>",
 		'V',
 		"",
@@ -810,43 +901,115 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Key Bind",
+		"/misc/config/key",
 		"<Branch>",
 		'K',
 		"",
+		N_MSG_MENU_KEY, "",
+		cb_menu_key_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/title",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MENU_KEY, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/clear key buffer",
+		"<Branch>",
+		'C',
+		"",
+		N_MSG_MENU_CLR_KEY_BUF, "",
+		cb_menu_clr_key_buf_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/clear key buffer/title",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MENU_CLR_KEY_BUF, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/clear key buffer/every",
+		"<CheckItem>",
+		'E',
+		"",
+		N_MSG_MENU_CLR_KEY_BUF_EVERY, "",
+		cb_menu_clr_key_buf_every, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/clear key buffer/menu",
+		"<CheckItem>",
+		'M',
+		"",
+		N_MSG_MENU_CLR_KEY_BUF_MENU, "",
+		cb_menu_clr_key_buf_menu, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/echo key",
+		"<CheckItem>",
+		'E',
+		"",
+		N_MSG_MENU_ECHO_KEY, "",
+		cb_menu_echo_key, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/key bind",
+		"<Branch>",
+		'B',
+		"",
 		N_MSG_MENU_KEY_BIND, "",
 		NULL, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Key Bind/Set Key",
+		"/misc/config/key/key bind/title",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MENU_KEY_BIND, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/key/key bind/set key",
 		"<OpenWinItem>",
-		'S',
+		'A',
 		"",
 		N_MSG_MENU_SET_KEY, "",
 		cb_menu_set_key, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Key Bind/Unset Key",
+		"/misc/config/key/key bind/unset key",
 		"<OpenWinItem>",
-		'U',
+		'F',
 		"",
 		N_MSG_MENU_UNSET_KEY, "",
 		cb_menu_unset_key, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/Macro",
+		"/misc/config/key/macro",
 		"<Branch>",
-		'N',
+		'F',
 		"",
 		N_MSG_MENU_MACRO, "",
 		cb_menu_macro, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/Config/User Menu Select",
+		"/misc/config/user menu select",
 		"<Branch>",
 		'M',
 		"x",
@@ -857,26 +1020,26 @@ menu_t	ls_menu_main[] = {
 /* config end */
 /* system begin */
 	{
-		"/Misc/System",
+		"/misc/system",
 		"<Branch>",
 		'Y',
 		"",
 		N_MSG_MENU_SYS, "",
-		NULL, NULL,
+		cb_menu_system, NULL,
 		FLG_NULL,
 	},
 /* wizard begin */
 	{
-		"/Misc/System/Wizard",
+		"/misc/system/wizard",
 		"<Branch>",
 		'W',
 		"^W",
 		N_MSG_MENU_WIZARD, "",
-		NULL, NULL,
+		cb_menu_wizard, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Wizard/Title",
+		"/misc/system/wizard/title",
 		"<Title>",
 		'\0',
 		"",
@@ -885,7 +1048,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Wizard/On Light",
+		"/misc/system/wizard/on light",
 		"<Item>",
 		'O',
 		"",
@@ -894,7 +1057,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Wizard/Off Light",
+		"/misc/system/wizard/off light",
 		"<Item>",
 		'F',
 		"",
@@ -903,7 +1066,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Wizard/Add Turn",
+		"/misc/system/wizard/add turn",
 		"<OpenWinItem>",
 		'T',
 		"",
@@ -912,7 +1075,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Wizard/Level Up",
+		"/misc/system/wizard/level up",
 		"<OpenWinItem>",
 		'V',
 		"",
@@ -921,7 +1084,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Wizard/Text Load",
+		"/misc/system/wizard/text load",
 		"<Branch>",
 		'L',
 		"",
@@ -930,7 +1093,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Wizard/Text Save",
+		"/misc/system/wizard/text save",
 		"<Branch>",
 		'S',
 		"",
@@ -940,7 +1103,7 @@ menu_t	ls_menu_main[] = {
 	},
 /* wizard end */
 	{
-		"/Misc/System/Output map file",
+		"/misc/system/output map file",
 		"<OpenWinItem>",
 		'O',
 		"",
@@ -949,7 +1112,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Shell",
+		"/misc/system/shell",
 		"<OpenWinItem>",
 		'H',
 		"!",
@@ -958,7 +1121,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/About",
+		"/misc/system/about",
 		"<OpenWinItem>",
 		'A',
 		"",
@@ -967,7 +1130,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/Misc/System/Exit",
+		"/misc/system/exit",
 		"<Branch>",
 		'Q',
 		"^C ^Q Q",
@@ -990,7 +1153,7 @@ menu_t	ls_menu_main[] = {
 
 menu_t	ls_menu_sel_obj[] = {
 	{
-		"/Sel Obj",
+		"/sel obj",
 		"<Branch>",
 		'\0',
 		"",
@@ -999,7 +1162,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Member",
+		"/sel obj/member",
 		"<OpenWinItem>",
 		'P',
 		"",
@@ -1008,7 +1171,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Monster",
+		"/sel obj/monster",
 		"<OpenWinItem>",
 		'X',
 		"",
@@ -1017,7 +1180,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Item",
+		"/sel obj/item",
 		"<OpenWinItem>",
 		'I',
 		"",
@@ -1026,7 +1189,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Door",
+		"/sel obj/door",
 		"<OpenWinItem>",
 		'D',
 		"",
@@ -1035,7 +1198,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Trap",
+		"/sel obj/trap",
 		"<OpenWinItem>",
 		'T',
 		"",
@@ -1044,7 +1207,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Square",
+		"/sel obj/square",
 		"<OpenWinItem>",
 		'V',
 		"",
@@ -1053,7 +1216,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Position",
+		"/sel obj/position",
 		"<OpenWinItem>",
 		'N',
 		"",
@@ -1062,7 +1225,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Auto",
+		"/sel obj/auto",
 		"<Branch>",
 		'A',
 		"a",
@@ -1071,7 +1234,7 @@ menu_t	ls_menu_sel_obj[] = {
 		FLG_NULL,
 	},
 	{
-		"/Sel Obj/Clear",
+		"/sel obj/clear",
 		"<Item>",
 		'C',
 		"",
@@ -1094,7 +1257,7 @@ menu_t	ls_menu_mbr[1 + MBR_MAX_N + PET_MAX_N + 1];
 
 menu_t	ls_menu_dist[] = {
 	{
-		"/Dist",
+		"/dist",
 		"<Branch>",
 		'\0',
 		"",
@@ -1104,140 +1267,140 @@ menu_t	ls_menu_dist[] = {
 	},
 /* Near */
 	{
-		"/Dist/Near",
+		"/dist/near",
 		"<Branch>",
 		'N',
 		"",
 		N_MSG_MENU_DIST_NEAR, "",
-		cb_menu_dist, (void *)"Near",
+		cb_menu_dist, (void *)"near",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Near/Fight",
+		"/dist/near/fight",
 		"<Item>",
 		'F',
 		"",
 		N_MSG_MENU_MARK_FIGHT, "",
-		cb_menu_dist_act, (void *)"Fight",
+		cb_menu_dist_act, (void *)"fight",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Near/Throw",
+		"/dist/near/throw",
 		"<Item>",
 		'T',
 		"",
 		N_MSG_MENU_MARK_THROW, "",
-		cb_menu_dist_act, (void *)"Throw",
+		cb_menu_dist_act, (void *)"throw",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Near/Steal",
+		"/dist/near/steal",
 		"<Item>",
 		'S',
 		"",
 		N_MSG_MENU_MARK_STEAL, "",
-		cb_menu_dist_act, (void *)"Steal",
+		cb_menu_dist_act, (void *)"steal",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Near/Tail",
+		"/dist/near/tail",
 		"<Item>",
 		'L',
 		"",
 		N_MSG_MENU_MARK_TAIL, "",
-		cb_menu_dist_act, (void *)"Tail",
+		cb_menu_dist_act, (void *)"tail",
 		FLG_NULL,
 	},
 /* Medium */
 	{
-		"/Dist/Medium",
+		"/dist/medium",
 		"<Branch>",
 		'M',
 		"",
 		N_MSG_MENU_DIST_MEDIUM, "",
-		cb_menu_dist, (void *)"Medium",
+		cb_menu_dist, (void *)"medium",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Medium/Fight",
+		"/dist/medium/fight",
 		"<Item>",
 		'F',
 		"",
 		N_MSG_MENU_MARK_FIGHT, "",
-		cb_menu_dist_act, (void *)"Fight",
+		cb_menu_dist_act, (void *)"fight",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Medium/Throw",
+		"/dist/medium/throw",
 		"<Item>",
 		'T',
 		"",
 		N_MSG_MENU_MARK_THROW, "",
-		cb_menu_dist_act, (void *)"Throw",
+		cb_menu_dist_act, (void *)"throw",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Medium/Steal",
+		"/dist/medium/steal",
 		"<Item>",
 		'S',
 		"",
 		N_MSG_MENU_MARK_STEAL, "",
-		cb_menu_dist_act, (void *)"Steal",
+		cb_menu_dist_act, (void *)"steal",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Medium/Tail",
+		"/dist/medium/tail",
 		"<Item>",
 		'L',
 		"",
 		N_MSG_MENU_MARK_TAIL, "",
-		cb_menu_dist_act, (void *)"Tail",
+		cb_menu_dist_act, (void *)"tail",
 		FLG_NULL,
 	},
 /* Far */
 	{
-		"/Dist/Far",
+		"/dist/far",
 		"<Branch>",
 		'F',
 		"",
 		N_MSG_MENU_DIST_FAR, "",
-		cb_menu_dist, (void *)"Far",
+		cb_menu_dist, (void *)"far",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Far/Fight",
+		"/dist/far/fight",
 		"<Item>",
 		'F',
 		"",
 		N_MSG_MENU_MARK_FIGHT, "",
-		cb_menu_dist_act, (void *)"Fight",
+		cb_menu_dist_act, (void *)"fight",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Far/Throw",
+		"/dist/far/throw",
 		"<Item>",
 		'T',
 		"",
 		N_MSG_MENU_MARK_THROW, "",
-		cb_menu_dist_act, (void *)"Throw",
+		cb_menu_dist_act, (void *)"throw",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Far/Steal",
+		"/dist/far/steal",
 		"<Item>",
 		'S',
 		"",
 		N_MSG_MENU_MARK_STEAL, "",
-		cb_menu_dist_act, (void *)"Steal",
+		cb_menu_dist_act, (void *)"steal",
 		FLG_NULL,
 	},
 	{
-		"/Dist/Far/Tail",
+		"/dist/far/tail",
 		"<Item>",
 		'L',
 		"",
 		N_MSG_MENU_MARK_TAIL, "",
-		cb_menu_dist_act, (void *)"Tail",
+		cb_menu_dist_act, (void *)"tail",
 		FLG_NULL,
 	},
 	{
@@ -1253,7 +1416,7 @@ menu_t	ls_menu_dist[] = {
 
 menu_t	ls_menu_mark_item[] = {
 	{
-		"/Mark Item",
+		"/mark item",
 		"<Branch>",
 		'\0',
 		"",
@@ -1262,7 +1425,7 @@ menu_t	ls_menu_mark_item[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Item/Pick Up",
+		"/mark item/pick up",
 		"<Item>",
 		'P',
 		"",
@@ -1271,7 +1434,7 @@ menu_t	ls_menu_mark_item[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Item/Open",
+		"/mark item/open",
 		"<Item>",
 		'O',
 		"",
@@ -1280,7 +1443,7 @@ menu_t	ls_menu_mark_item[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Item/Disarm",
+		"/mark item/disarm",
 		"<Item>",
 		'D',
 		"",
@@ -1289,7 +1452,7 @@ menu_t	ls_menu_mark_item[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Item/Break",
+		"/mark item/break",
 		"<Item>",
 		'B',
 		"",
@@ -1298,7 +1461,7 @@ menu_t	ls_menu_mark_item[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Item/Search",
+		"/mark item/search",
 		"<Item>",
 		'S',
 		"",
@@ -1319,7 +1482,7 @@ menu_t	ls_menu_mark_item[] = {
 
 menu_t	ls_menu_mark_door[] = {
 	{
-		"/Mark Door",
+		"/mark door",
 		"<Branch>",
 		'\0',
 		"",
@@ -1328,7 +1491,7 @@ menu_t	ls_menu_mark_door[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Door/Open",
+		"/mark door/open",
 		"<Item>",
 		'O',
 		"",
@@ -1337,7 +1500,7 @@ menu_t	ls_menu_mark_door[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Door/Close",
+		"/mark door/close",
 		"<Item>",
 		'C',
 		"",
@@ -1346,7 +1509,7 @@ menu_t	ls_menu_mark_door[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Door/Jamming",
+		"/mark door/jamming",
 		"<Item>",
 		'J',
 		"",
@@ -1355,7 +1518,7 @@ menu_t	ls_menu_mark_door[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Door/Disarm",
+		"/mark door/disarm",
 		"<Item>",
 		'D',
 		"",
@@ -1364,7 +1527,7 @@ menu_t	ls_menu_mark_door[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Door/Break",
+		"/mark door/break",
 		"<Item>",
 		'B',
 		"",
@@ -1373,7 +1536,7 @@ menu_t	ls_menu_mark_door[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Door/Peep",
+		"/mark door/peep",
 		"<Item>",
 		'P',
 		"",
@@ -1382,7 +1545,7 @@ menu_t	ls_menu_mark_door[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Door/Search",
+		"/mark door/search",
 		"<Item>",
 		'S',
 		"",
@@ -1403,7 +1566,7 @@ menu_t	ls_menu_mark_door[] = {
 
 menu_t	ls_menu_mark_trap[] = {
 	{
-		"/Mark Trap",
+		"/mark trap",
 		"<Branch>",
 		'\0',
 		"",
@@ -1412,7 +1575,7 @@ menu_t	ls_menu_mark_trap[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Trap/Disarm",
+		"/mark trap/disarm",
 		"<Item>",
 		'D',
 		"",
@@ -1421,7 +1584,7 @@ menu_t	ls_menu_mark_trap[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Trap/Break",
+		"/mark trap/break",
 		"<Item>",
 		'B',
 		"",
@@ -1430,7 +1593,7 @@ menu_t	ls_menu_mark_trap[] = {
 		FLG_NULL,
 	},
 	{
-		"/Mark Trap/Search",
+		"/mark trap/search",
 		"<Item>",
 		'S',
 		"",
@@ -1453,7 +1616,7 @@ menu_t	ls_menu_item[MBR_ITEM_MAX_N * 2 * MBR_MAX_N];
 
 menu_t	ls_menu_item_self[] = {
 	{
-		"/Self",
+		"/self",
 		"<Branch>",
 		'\0',
 		"",
@@ -1462,7 +1625,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Quaff",
+		"/self/quaff",
 		"<Item>",
 		'Q',
 		"",
@@ -1471,7 +1634,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Read",
+		"/self/read",
 		"<Item>",
 		'R',
 		"",
@@ -1480,7 +1643,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Zap",
+		"/self/zap",
 		"<Item>",
 		'Z',
 		"",
@@ -1489,7 +1652,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Eat",
+		"/self/eat",
 		"<Item>",
 		'A',
 		"",
@@ -1498,7 +1661,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Smoke",
+		"/self/smoke",
 		"<Item>",
 		'K',
 		"",
@@ -1507,7 +1670,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Dispose",
+		"/self/dispose",
 		"<Item>",
 		'P',
 		"",
@@ -1516,7 +1679,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Fill Lamp",
+		"/self/fill lamp",
 		"<Item>",
 		'F',
 		"",
@@ -1525,7 +1688,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Equip",
+		"/self/equip",
 		"<Item>",
 		'E',
 		"",
@@ -1534,7 +1697,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Ready Throw",
+		"/self/ready throw",
 		"<Item>",
 		'T',
 		"",
@@ -1543,7 +1706,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Send",
+		"/self/send",
 		"<OpenWinItem>",
 		'S',
 		"",
@@ -1552,7 +1715,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Drop",
+		"/self/drop",
 		"<OpenWinItem>",
 		'D',
 		"",
@@ -1561,7 +1724,7 @@ menu_t	ls_menu_item_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Check",
+		"/self/check",
 		"<Item>",
 		'C',
 		"",
@@ -1582,7 +1745,7 @@ menu_t	ls_menu_item_self[] = {
 
 menu_t	ls_menu_item_other[] = {
 	{
-		"/Other",
+		"/other",
 		"<Branch>",
 		'\0',
 		"",
@@ -1591,7 +1754,7 @@ menu_t	ls_menu_item_other[] = {
 		FLG_NULL,
 	},
 	{
-		"/Other/Recieve",
+		"/other/recieve",
 		"<Item>",
 		'R',
 		"",
@@ -1600,7 +1763,7 @@ menu_t	ls_menu_item_other[] = {
 		FLG_NULL,
 	},
 	{
-		"/Other/Check",
+		"/other/check",
 		"<Item>",
 		'C',
 		"",
@@ -1623,7 +1786,7 @@ menu_t	ls_menu_equip[EQUIP_KIND_MAX_N * 2 * MBR_MAX_N];
 
 menu_t	ls_menu_equip_self[] = {
 	{
-		"/Self",
+		"/self",
 		"<Branch>",
 		'\0',
 		"",
@@ -1632,7 +1795,7 @@ menu_t	ls_menu_equip_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Wear",
+		"/self/wear",
 		"<Branch>",
 		'W',
 		"",
@@ -1641,7 +1804,7 @@ menu_t	ls_menu_equip_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Take Off",
+		"/self/take off",
 		"<Item>",
 		'T',
 		"",
@@ -1650,7 +1813,7 @@ menu_t	ls_menu_equip_self[] = {
 		FLG_NULL,
 	},
 	{
-		"/Self/Check",
+		"/self/check",
 		"<Item>",
 		'C',
 		"",
@@ -1671,7 +1834,7 @@ menu_t	ls_menu_equip_self[] = {
 
 menu_t	ls_menu_equip_other[] = {
 	{
-		"/Other",
+		"/other",
 		"<Branch>",
 		'\0',
 		"",
@@ -1680,7 +1843,7 @@ menu_t	ls_menu_equip_other[] = {
 		FLG_NULL,
 	},
 	{
-		"/Other/Wear",
+		"/other/wear",
 		"<Item>",
 		'W',
 		"",
@@ -1689,7 +1852,7 @@ menu_t	ls_menu_equip_other[] = {
 		FLG_NULL,
 	},
 	{
-		"/Other/Take Off",
+		"/other/take off",
 		"<Item>",
 		'T',
 		"",
@@ -1698,7 +1861,7 @@ menu_t	ls_menu_equip_other[] = {
 		FLG_NULL,
 	},
 	{
-		"/Other/Check",
+		"/other/check",
 		"<Item>",
 		'C',
 		"",
@@ -1725,7 +1888,7 @@ menu_t	ls_menu_formation[1 + 1 + MBR_MAX_N + 1];
 
 menu_t	ls_menu_move_crsr[] = {
 	{
-		"/Cursor",
+		"/cursor",
 		"<Branch>",
 		'\0',
 		"",
@@ -1735,7 +1898,7 @@ menu_t	ls_menu_move_crsr[] = {
 	},
 /* cursor move begin */
 	{
-		"/Cursor/Move",
+		"/cursor/move",
 		"<Branch>",
 		'M',
 		"",
@@ -1744,7 +1907,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Down left",
+		"/cursor/move/down left",
 		"<Item>",
 		'B',
 		"1 b",
@@ -1753,7 +1916,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Down",
+		"/cursor/move/down",
 		"<Item>",
 		'J',
 		"^N 2 j",
@@ -1762,7 +1925,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Down right",
+		"/cursor/move/down right",
 		"<Item>",
 		'N',
 		"3 n",
@@ -1771,7 +1934,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Left",
+		"/cursor/move/left",
 		"<Item>",
 		'H',
 		"^B 4 h",
@@ -1780,7 +1943,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Right",
+		"/cursor/move/right",
 		"<Item>",
 		'L',
 		"^F 6 l",
@@ -1789,7 +1952,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Up left",
+		"/cursor/move/up left",
 		"<Item>",
 		'Y',
 		"7 y",
@@ -1798,7 +1961,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Up",
+		"/cursor/move/up",
 		"<Item>",
 		'K',
 		"^P 8 k",
@@ -1807,7 +1970,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Move/Up right",
+		"/cursor/move/up right",
 		"<Item>",
 		'U',
 		"9 u",
@@ -1818,7 +1981,7 @@ menu_t	ls_menu_move_crsr[] = {
 /* cursor move end */
 /* cursor quick move begin */
 	{
-		"/Cursor/Quick move",
+		"/cursor/quick move",
 		"<Branch>",
 		'Q',
 		"",
@@ -1827,7 +1990,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Down left",
+		"/cursor/quick move/down left",
 		"<Item>",
 		'B',
 		"B",
@@ -1836,7 +1999,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Down",
+		"/cursor/quick move/down",
 		"<Item>",
 		'J',
 		"J",
@@ -1845,7 +2008,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Down right",
+		"/cursor/quick move/down right",
 		"<Item>",
 		'N',
 		"N",
@@ -1854,7 +2017,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Left",
+		"/cursor/quick move/left",
 		"<Item>",
 		'H',
 		"H",
@@ -1863,7 +2026,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Right",
+		"/cursor/quick move/right",
 		"<Item>",
 		'L',
 		"L",
@@ -1872,7 +2035,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Up left",
+		"/cursor/quick move/up left",
 		"<Item>",
 		'Y',
 		"Y",
@@ -1881,7 +2044,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Up",
+		"/cursor/quick move/up",
 		"<Item>",
 		'K',
 		"K",
@@ -1890,7 +2053,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Quick move/Up right",
+		"/cursor/quick move/up right",
 		"<Item>",
 		'U',
 		"U",
@@ -1900,7 +2063,7 @@ menu_t	ls_menu_move_crsr[] = {
 	},
 /* cursor quick move end */
 	{
-		"/Cursor/Move member",
+		"/cursor/move member",
 		"<Branch>",
 		'B',
 		"@",
@@ -1909,16 +2072,16 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Scroll center",
+		"/cursor/center",
 		"<Item>",
 		'C',
 		"^R ^L",
-		N_MSG_MENU_CRSR_SCROLL_CENTER, "",
-		cb_menu_crsr_scroll_center, NULL,
+		N_MSG_MENU_CRSR_CENTER, "",
+		cb_menu_crsr_center, NULL,
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Next position member",
+		"/cursor/next position member",
 		"<Item>",
 		'P',
 		"P",
@@ -1927,7 +2090,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Next position monster",
+		"/cursor/next position monster",
 		"<Item>",
 		'X',
 		"^I X",
@@ -1936,7 +2099,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Next position item",
+		"/cursor/next position item",
 		"<Item>",
 		'I',
 		"I",
@@ -1945,7 +2108,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Next position door",
+		"/cursor/next position door",
 		"<Item>",
 		'D',
 		"D",
@@ -1954,7 +2117,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Next position object",
+		"/cursor/next position object",
 		"<Item>",
 		'O',
 		"O",
@@ -1963,7 +2126,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Next position square",
+		"/cursor/next position square",
 		"<Item>",
 		'V',
 		"V",
@@ -1972,7 +2135,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Next position all",
+		"/cursor/next position all",
 		"<Item>",
 		'A',
 		"A",
@@ -1981,7 +2144,7 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 	{
-		"/Cursor/Prev position",
+		"/cursor/prev position",
 		"<Item>",
 		'R',
 		"R",
@@ -2002,10 +2165,12 @@ menu_t	ls_menu_move_crsr[] = {
 
 menu_t	ls_menu_mbr_flg[MBR_ITEM_MAX_N + 4];
 
+menu_t	ls_menu_lang_ls[LANG_KIND_MAX_N * 2];
+
 menu_t	ls_menu_color[2 + 1 + CURS_ATTR_MAX_N + 1];
 menu_t	ls_menu_color_sel[] = {
 	{
-		"/Color",
+		"/color",
 		"<Branch>",
 		'\0',
 		"",
@@ -2015,7 +2180,7 @@ menu_t	ls_menu_color_sel[] = {
 	},
 /* FG */
 	{
-		"/Color/Fg",
+		"/color/fg",
 		"<Branch>",
 		'F',
 		"",
@@ -2024,7 +2189,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/Black",
+		"/color/fg/black",
 		"<Item>",
 		'K',
 		"",
@@ -2033,7 +2198,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/Red",
+		"/color/fg/red",
 		"<Item>",
 		'R',
 		"",
@@ -2042,7 +2207,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/Green",
+		"/color/fg/green",
 		"<Item>",
 		'G',
 		"",
@@ -2051,7 +2216,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/Yellow",
+		"/color/fg/yellow",
 		"<Item>",
 		'Y',
 		"",
@@ -2060,7 +2225,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/Blue",
+		"/color/fg/blue",
 		"<Item>",
 		'B',
 		"",
@@ -2069,7 +2234,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/Magenta",
+		"/color/fg/magenta",
 		"<Item>",
 		'M',
 		"",
@@ -2078,7 +2243,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/Cyan",
+		"/color/fg/cyan",
 		"<Item>",
 		'C',
 		"",
@@ -2087,7 +2252,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Fg/White",
+		"/color/fg/white",
 		"<Item>",
 		'W',
 		"",
@@ -2097,7 +2262,7 @@ menu_t	ls_menu_color_sel[] = {
 	},
 /* BG */
 	{
-		"/Color/Bg",
+		"/color/bg",
 		"<Branch>",
 		'B',
 		"",
@@ -2106,7 +2271,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/Black",
+		"/color/bg/black",
 		"<Item>",
 		'K',
 		"",
@@ -2115,7 +2280,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/Red",
+		"/color/bg/red",
 		"<Item>",
 		'R',
 		"",
@@ -2124,7 +2289,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/Green",
+		"/color/bg/green",
 		"<Item>",
 		'G',
 		"",
@@ -2133,7 +2298,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/Yellow",
+		"/color/bg/yellow",
 		"<Item>",
 		'Y',
 		"",
@@ -2142,7 +2307,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/Blue",
+		"/color/bg/blue",
 		"<Item>",
 		'B',
 		"",
@@ -2151,7 +2316,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/Magenta",
+		"/color/bg/magenta",
 		"<Item>",
 		'M',
 		"",
@@ -2160,7 +2325,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/Cyan",
+		"/color/bg/cyan",
 		"<Item>",
 		'C',
 		"",
@@ -2169,7 +2334,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Bg/White",
+		"/color/bg/white",
 		"<Item>",
 		'W',
 		"",
@@ -2179,7 +2344,7 @@ menu_t	ls_menu_color_sel[] = {
 	},
 /* Attr */
 	{
-		"/Color/Attribute",
+		"/color/attribute",
 		"<Branch>",
 		'A',
 		"",
@@ -2188,7 +2353,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Attribute/Underline",
+		"/color/attribute/underline",
 		"<CheckItem>",
 		'U',
 		"",
@@ -2197,7 +2362,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Attribute/Reverse",
+		"/color/attribute/reverse",
 		"<CheckItem>",
 		'R',
 		"",
@@ -2206,7 +2371,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Attribute/Blink",
+		"/color/attribute/blink",
 		"<CheckItem>",
 		'L',
 		"",
@@ -2215,7 +2380,7 @@ menu_t	ls_menu_color_sel[] = {
 		FLG_NULL,
 	},
 	{
-		"/Color/Attribute/Bold",
+		"/color/attribute/bold",
 		"<CheckItem>",
 		'B',
 		"",
