@@ -19,7 +19,7 @@ mnstr_t	*make_mnstr_alloc(
 	long dun_lev,
 	mnstr_kind_t mnstr_kind
 );
-bool_t	make_mnstr_special( long dun_lev, mnstr_t *p );
+bool_t	make_mnstr_special( mnstr_t *p, long dun_lev );
 mnstr_t	*make_npc_rand( long x, long y, long dun_lev );
 void	move_phase_all_mnstr( void );
 void	act_phase_all_mnstr( void );
@@ -39,10 +39,13 @@ bool_t	chk_auto_door_mnstr_break( mnstr_t *p, long x, long y );
 void	set_flg_find_all_mnstr( void );
 bool_t	set_flg_find_mnstr( mnstr_t *p );
 void	chk_trap_all_mnstr( void );
+void	die_mnstr_drop_item( mnstr_t *p );
 void	die_mnstr( mnstr_t *p );
 bool_t	chk_die_boss( mnstr_t *p );
 void	die_boss( mnstr_t *m );
+void	garbage_collection_all_mnstr( void );
 void	mnstr_drop_gold( mnstr_t *p );
+void	mnstr_drop_bone( mnstr_t *p );
 void	mnstr_drop_item( mnstr_t *p );
 void	set_find_all_mnstr( void );
 void	print_ls_mnstr( void );
@@ -56,7 +59,8 @@ mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev );
 void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p );
 void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev );
 long	calc_mnstr_exp( mnstr_t *p, long dun_lev );
-long	calc_mnstr_abl_lev( long dun_lev, rate_t rate );
+long	calc_mnstr_abl_lev( long dun_lev, abl_kind_t k, mnstr_tab_t *tab );
+rate_t	calc_mnstr_group_rate( long group_n );
 gold_t	calc_mnstr_gold( long dun_lev, rate_t rate );
 bool_t	can_move_mnstr_tab( mnstr_tab_t *tab, long x, long y );
 mnstr_t	*get_mnstr( long x, long y );
