@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,76 +25,58 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.154 2004/12/25 23:35:24 bowkenken Exp $
+* $Id: mnstr.c,v 1.166 2006/01/15 14:05:51 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-#include	"item.h"
-#include	"spell.h"
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-#include	"pet.h"
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-#include	"trap.h"
-#include	"draw.h"
-#include	"curs.h"
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-#include	"dun-prot.h"
-/*#include	"town-prot.h"*/
-#include	"item-prot.h"
-#include	"spell-prot.h"
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"pet-prot.h"
-#include	"fight-prot.h"
-#include	"fx-prot.h"
-#include	"trap-prot.h"
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* 󥹥
+***************************************************************/
 
-/**/
+#define	MNSTR_C
+#include	"inc.h"
 
+/***************************************************************/
+
+/* μդˤߡο */
 #define	GARGOYLE_STATUE_N	3
 
+/* 󥹥λäƤη׻˻Ȥ */
 #define	MNSTR_GOLD_MUL_N	12
 #define	MNSTR_GOLD_ADD_N	0
 
+/* 󥹥ιΨ */
+#define	MNSTR_DROP_BONE_RATE	((rate_t)20)
+
+/* ν̱ʿѥ󥸥󡦥٥ */
 #define	TOWNER_AVE_DUN_LEV	48
 
+/* 󥹥ηζ */
+
+/* ʬ */
 #define	GROUP_RATE_DENOMINATOR	10
+/*  */
 #define	GROUP_RATE_BASE	50
 
-/**/
+/***************************************************************
+* 󥹥Υǡ
+***************************************************************/
 
+/* ס */
 static mnstr_t	mnstr_buf[MNSTR_MAX_N];
-static mnstr_t	mnstr_used, mnstr_free;
+/* ƺ */
+static mnstr_t	mnstr_used;
+/* ̤ */
+static mnstr_t	mnstr_free;
 
-/**/
+/***************************************************************
+* 󥹥Υǡơ֥
+***************************************************************/
 
 #include	"mnstr-tab.h"
 
-/**/
+/***************************************************************
+* 󥹥ν
+***************************************************************/
 
 void	init_mnstr( void )
 {
@@ -129,7 +111,9 @@ void	init_mnstr( void )
 	reset_mnstr();
 }
 
-/**/
+/***************************************************************
+* եưȤΥ󥹥Υꥻå
+***************************************************************/
 
 void	reset_mnstr( void )
 {
@@ -150,7 +134,10 @@ void	reset_mnstr( void )
 	mnstr_free.prev = &mnstr_buf[i];
 }
 
-/**/
+/***************************************************************
+* 󥹥κΥǥեͤ
+* mnstr_t *mnstr : 󥹥
+***************************************************************/
 
 void	new_mnstr( mnstr_t *mnstr )
 {
@@ -218,7 +205,8 @@ void	new_mnstr( mnstr_t *mnstr )
 		lev = 1;
 
 		mnstr->abl.lev[i].max = lev;
-		mnstr->abl.exp[i].max = calc_lev_to_exp( lev, i );
+		mnstr->abl.exp[i].max = calc_lev_to_exp(
+				lev, (abl_kind_t)i );
 
 		mnstr->abl.lev[i].n = mnstr->abl.lev[i].max;
 		mnstr->abl.lev[i].add = 0;
@@ -290,7 +278,14 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->work.dismissal_turn = 0;
 }
 
-/**/
+/***************************************************************
+* ʼΥ󥹥Ϥ
+* long x : X ɸ
+* long y : Y ɸ
+* bool_t flg_fix_pos : κɸϤʤä饭󥻥뤹뤫?
+* long dun_lev : 󥸥γ
+* return : Ϥä󥹥
+***************************************************************/
 
 mnstr_t	*make_mnstr_rand( long x, long y, bool_t flg_fix_pos, long dun_lev )
 {
@@ -329,7 +324,15 @@ mnstr_t	*make_mnstr_rand( long x, long y, bool_t flg_fix_pos, long dun_lev )
 	return p;
 }
 
-/**/
+/***************************************************************
+* 󥹥Ϥ
+* long x : X ɸ
+* long y : Y ɸ
+* bool_t flg_fix_pos : κɸϤʤä饭󥻥뤹뤫?
+* long dun_lev : 󥸥γ
+* mnstr_kind_t mnstr_kind : 󥹥μ
+* return : Ϥä󥹥
+***************************************************************/
 
 mnstr_t	*make_mnstr(
 	long x, long y, bool_t flg_fix_pos,
@@ -355,7 +358,16 @@ mnstr_t	*make_mnstr(
 	return p;
 }
 
-/**/
+/***************************************************************
+* ݺѤΥ꡼˥󥹥Ϥ
+* mnstr_t *p : 󥹥
+* long x : X ɸ
+* long y : Y ɸ
+* bool_t flg_fix_pos : κɸϤʤä饭󥻥뤹뤫?
+* long dun_lev : 󥸥γ
+* mnstr_kind_t mnstr_kind : 󥹥μ
+* return : Ϥä󥹥
+***************************************************************/
 
 mnstr_t	*make_mnstr_alloc(
 	mnstr_t *p,
@@ -404,25 +416,14 @@ mnstr_t	*make_mnstr_alloc(
 	p->move = tab->move;
 	for( i = 0; i < ABL_KIND_MAX_N; i++ ){
 		long	lev;
-		long	group_denomi;
-		rate_t	group_rate;
 
-		lev = calc_mnstr_abl_lev( dun_lev,
-				tab->abl_lev_rate[i] );
-
-		/* οǥ٥ */
-
-		group_denomi = (tab->group + GROUP_RATE_DENOMINATOR - 1)
-				/ GROUP_RATE_DENOMINATOR;
-		group_rate = (_100_PERCENT - GROUP_RATE_BASE) / group_denomi
-				+ GROUP_RATE_BASE;
-		lev = lev * group_rate / _100_PERCENT;
+		lev = calc_mnstr_abl_lev( dun_lev, (abl_kind_t)i, tab );
 
 		p->abl.lev[i].n = lev;
 		p->abl.lev[i].max = lev;
 		p->abl.lev[i].add = 0;
 
-		p->abl.exp[i].n = calc_need_exp( lev, i );
+		p->abl.exp[i].n = calc_need_exp( lev, (abl_kind_t)i );
 		p->abl.exp[i].max = p->abl.exp[i].n;
 	}
 	p->abl.hp.max = calc_max_hp( p );
@@ -476,7 +477,7 @@ mnstr_t	*make_mnstr_alloc(
 	else
 		p->flg_map |= FLG_MAP_CHR_NPC;
 
-	if( !make_mnstr_special( dun_lev, p ) )
+	if( !make_mnstr_special( p, dun_lev ) )
 		return NULL;
 
 	put_chr( p, x, y );
@@ -484,9 +485,14 @@ mnstr_t	*make_mnstr_alloc(
 	return p;
 }
 
-/**/
+/***************************************************************
+* 󥹥̤ʽ
+* mnstr_t *p : 󥹥
+* long dun_lev : 󥸥γ
+* return : 顼̵ä?
+***************************************************************/
 
-bool_t	make_mnstr_special( long dun_lev, mnstr_t *p )
+bool_t	make_mnstr_special( mnstr_t *p, long dun_lev )
 {
 	bool_t	ret = TRUE;
 	static long	link_n = 0;
@@ -563,7 +569,13 @@ bool_t	make_mnstr_special( long dun_lev, mnstr_t *p )
 	return ret;
 }
 
-/**/
+/***************************************************************
+* ʼ NPC Ϥ
+* long x : X ɸ
+* long y : Y ɸ
+* long dun_lev : 󥸥γ
+* return : Ϥä NPC
+***************************************************************/
 
 mnstr_t	*make_npc_rand( long x, long y, long dun_lev )
 {
@@ -580,7 +592,9 @@ mnstr_t	*make_npc_rand( long x, long y, long dun_lev )
 	return make_mnstr( x, y, FALSE, dun_lev, kind );
 }
 
-/**/
+/***************************************************************
+* ƤΥ󥹥ΰưե¹
+***************************************************************/
 
 void	move_phase_all_mnstr( void )
 {
@@ -597,7 +611,9 @@ void	move_phase_all_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ƤΥ󥹥ιưե¹
+***************************************************************/
 
 void	act_phase_all_mnstr( void )
 {
@@ -614,7 +630,11 @@ void	act_phase_all_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* 󥹥ιư¹ԽΥޤǰưĴ٤
+* mnstr_t *p : 󥹥
+* return : ¹Խ뤫?
+***************************************************************/
 
 bool_t	chk_can_act_mnstr( mnstr_t *p )
 {
@@ -642,11 +662,13 @@ bool_t	chk_can_act_mnstr( mnstr_t *p )
 
 		break;
 	}
-	if( i >= MBR_MAX_N ){	/* СΥƤ */
+	if( i >= MBR_MAX_N ){
 		long	bx, by;
 		long	ex, ey;
 		long	x, y;
 
+		/* СΥƤ */
+
 		p->flg_map &= ~FLG_MAP_CHR_FIND;
 
 		bx = get_chr_left( p->x, p->dx );
@@ -662,6 +684,7 @@ bool_t	chk_can_act_mnstr( mnstr_t *p )
 			}
 		}
 
+		/* ̤õ */
 		draw_mnstr( p );
 
 		return FALSE;
@@ -679,7 +702,10 @@ bool_t	chk_can_act_mnstr( mnstr_t *p )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 󥹥ιư
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	set_act_mnstr( mnstr_t *p )
 {
@@ -694,21 +720,35 @@ void	set_act_mnstr( mnstr_t *p )
 		p->mnstr_tab->func( p );
 }
 
-/**/
+/***************************************************************
+* 󥹥ΥåȤɸŪ
+* mnstr_t *p : 󥹥
+* return : åȤС
+***************************************************************/
 
 mbr_t	*mnstr_mark_mbr_std( mnstr_t *p )
 {
 	return mnstr_mark_mbr_common( p, SEX_NULL );
 }
 
-/**/
+/***************************************************************
+* 󥹥ΥåȤ̤ꤷɸŪ
+* mnstr_t *p : 󥹥
+* sex_t sex : åȤ
+* return : åȤС
+***************************************************************/
 
 mbr_t	*mnstr_mark_mbr_cubus( mnstr_t *p, sex_t sex )
 {
 	return mnstr_mark_mbr_common( p, sex );
 }
 
-/**/
+/***************************************************************
+* 󥹥ΥåȤɸŪꤹ붦̽
+* mnstr_t *p : 󥹥
+* sex_t sex : åȤ
+* return : åȤС
+***************************************************************/
 
 mbr_t	*mnstr_mark_mbr_common( mnstr_t *p, sex_t sex )
 {
@@ -803,10 +843,14 @@ mbr_t	*mnstr_mark_mbr_common( mnstr_t *p, sex_t sex )
 	p->trgt.true_x = p->trgt.x;
 	p->trgt.true_y = p->trgt.y;
 
-	return p->trgt.p;
+	return( (mbr_t *)(p->trgt.p) );
 }
 
-/**/
+/***************************************************************
+* ܤС˥󥹥ΥåȤꤹ
+* mnstr_t *p : 󥹥
+* return : åȤС
+***************************************************************/
 
 mbr_t	*mnstr_mark_mbr_adjoin( mnstr_t *p )
 {
@@ -897,10 +941,14 @@ mbr_t	*mnstr_mark_mbr_adjoin( mnstr_t *p )
 	p->trgt.true_x = p->trgt.x;
 	p->trgt.true_y = p->trgt.y;
 
-	return p->trgt.p;
+	return( (mbr_t *)(p->trgt.p) );
 }
 
-/**/
+/***************************************************************
+* 󥹥ΰưɸŪʹư
+* mnstr_t *p : 󥹥
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 {
@@ -937,7 +985,7 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 	} else {
 		attack_t	*atk;
 		long	d;
-		chr_t	*friend;
+		chr_t	*friend_chr;
 
 		d = max_l( labs( p->x - trgt->x ), labs( p->y - trgt->y ) );
 		atk = get_attack( FALSE, ls, d,
@@ -946,20 +994,20 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 			return FALSE;
 
 		if( atk->kind == ATTACK_KIND_SPELL_SELF )
-			friend = p;
+			friend_chr = p;
 		else if( atk->kind == ATTACK_KIND_SPELL_FRIEND )
-			friend = get_mnstr_randm( p->x, p->y );
+			friend_chr = get_mnstr_randm( p->x, p->y );
 		else
-			friend = NULL;
+			friend_chr = NULL;
 
-		if( friend != NULL ){
+		if( friend_chr != NULL ){
 			rate_t	rate;
 
-			trgt = friend;
-			rate = friend->abl.hp.n * _100_PERCENT
-					/ friend->abl.hp.max;
+			trgt = friend_chr;
+			rate = friend_chr->abl.hp.n * _100_PERCENT
+					/ friend_chr->abl.hp.max;
 			if( rate < 70 ){
-				mark_mnstr( p, friend, DIST_FAR );
+				mark_mnstr( p, friend_chr, DIST_FAR );
 			} else {
 				set_chr_act( p, ACT_KIND_MBR_FIGHT,
 						trgt, NULL, 0, 0 );
@@ -981,7 +1029,11 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 󥹥ηŨˤޤ魯
+* chr_t *o_p : ˹ųݤΥ饯
+* chr_t *d_p : ܤΥ饯
+***************************************************************/
 
 void	set_enemy_mnstr_group( chr_t *o_p, chr_t *d_p )
 {
@@ -1014,7 +1066,9 @@ void	set_enemy_mnstr_group( chr_t *o_p, chr_t *d_p )
 	}
 }
 
-/**/
+/***************************************************************
+* ƤΥ󥹥Υ 1 Ŀʤ
+***************************************************************/
 
 void	inc_turn_all_mnstr( void )
 {
@@ -1032,7 +1086,11 @@ void	inc_turn_all_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* 󥹥ʬ󤷤ƿ򿣤䤹
+* mnstr_t *p : 󥹥
+* return : ʬ󤷤?
+***************************************************************/
 
 bool_t	increase_mnstr( mnstr_t *p )
 {
@@ -1057,7 +1115,15 @@ bool_t	increase_mnstr( mnstr_t *p )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 󥹥ɥ򳫤뤫ͤ˹ư
+* mnstr_t *p : 󥹥
+* long x1 : 1 ܤ X ɸ
+* long y1 : 1 ܤ Y ɸ
+* long x2 : 2 ܤ X ɸ
+* long y2 : 2 ܤ Y ɸ
+* return : ưꤷ?
+***************************************************************/
 
 bool_t	chk_auto_door_mnstr( mnstr_t *p, long x1, long y1, long x2, long y2 )
 {
@@ -1081,7 +1147,13 @@ bool_t	chk_auto_door_mnstr( mnstr_t *p, long x1, long y1, long x2, long y2 )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* 󥹥ɥ򳫤ͤ˹ư
+* mnstr_t *p : 󥹥
+* long x : X ɸ
+* long y : Y ɸ
+* return : ưꤷ?
+***************************************************************/
 
 bool_t	chk_auto_door_mnstr_open( mnstr_t *p, long x, long y )
 {
@@ -1103,7 +1175,13 @@ bool_t	chk_auto_door_mnstr_open( mnstr_t *p, long x, long y )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* 󥹥ɥͤ˹ư
+* mnstr_t *p : 󥹥
+* long x : X ɸ
+* long y : Y ɸ
+* return : ưꤷ?
+***************************************************************/
 
 bool_t	chk_auto_door_mnstr_break( mnstr_t *p, long x, long y )
 {
@@ -1127,7 +1205,9 @@ bool_t	chk_auto_door_mnstr_break( mnstr_t *p, long x, long y )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ƤΥ󥹥ȯ֤ˤ
+***************************************************************/
 
 void	set_flg_find_all_mnstr( void )
 {
@@ -1143,7 +1223,11 @@ void	set_flg_find_all_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* 󥹥ȯ֤ˤ
+* mnstr_t *p : 󥹥
+* return : ȯ֤ꤷ?
+***************************************************************/
 
 bool_t	set_flg_find_mnstr( mnstr_t *p )
 {
@@ -1186,7 +1270,9 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	return( chk_flg( p->flg_map, FLG_MAP_CHR_FIND ) );
 }
 
-/**/
+/***************************************************************
+* ƤΥ󥹥ˤĤ櫤˳ݤäå
+***************************************************************/
 
 void	chk_trap_all_mnstr( void )
 {
@@ -1202,7 +1288,29 @@ void	chk_trap_all_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* 󥹥˥ƥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	die_mnstr_drop_item( mnstr_t *p )
+{
+	if( p == NULL )
+		return;
+	if( p->kind != CHR_KIND_MNSTR )
+		return;
+	if( is_pet( p ) )
+		return;
+
+	mnstr_drop_bone( p );
+	mnstr_drop_gold( p );
+	mnstr_drop_item( p );
+}
+
+/***************************************************************
+* 󥹥ν
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	die_mnstr( mnstr_t *p )
 {
@@ -1213,14 +1321,13 @@ void	die_mnstr( mnstr_t *p )
 		die_pet( p );
 		return;
 	}
-
-	mnstr_drop_gold( p );
-	mnstr_drop_item( p );
-
-	ins_ls_mnstr( &mnstr_free, p );
 }
 
-/**/
+/***************************************************************
+* 󥹥ܥåƽ򤹤
+* mnstr_t *p : 󥹥
+* return : ܥä?
+***************************************************************/
 
 bool_t	chk_die_boss( mnstr_t *p )
 {
@@ -1238,7 +1345,10 @@ bool_t	chk_die_boss( mnstr_t *p )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ܥ󥹥ν
+* mnstr_t *m : 󥹥
+***************************************************************/
 
 void	die_boss( mnstr_t *m )
 {
@@ -1256,6 +1366,11 @@ void	die_boss( mnstr_t *m )
 		if( pp == head )
 			break;
 
+		if( chk_flg_or( pp->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			continue;
+		}
+
 		if( pp->mnstr_tab != NULL ){
 			if( pp->mnstr_tab->flg_boss ){
 				boss_n++;
@@ -1264,11 +1379,37 @@ void	die_boss( mnstr_t *m )
 	}
 
 	if( boss_n <= 1 ){
+		/* ܥݤ鳬ʤ */
+
 		make_stairs( m->x, m->y, FACE_MJR_STAIRS_DOWN );
 	}
 }
 
-/**/
+/***************************************************************
+* 󥹥Υ꡼
+***************************************************************/
+
+void	garbage_collection_all_mnstr( void )
+{
+	mnstr_t	*head, *p, *pp;
+
+	head = &mnstr_used;
+	for( p = head->next->next; p != NULL; p = p->next ){
+		pp = p->prev;
+		if( pp == head )
+			break;
+
+		if( chk_flg_or( pp->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			ins_ls_mnstr( &mnstr_free, pp );
+		}
+	}
+}
+
+/***************************************************************
+* 󥹥˶
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	mnstr_drop_gold( mnstr_t *p )
 {
@@ -1295,7 +1436,46 @@ void	mnstr_drop_gold( mnstr_t *p )
 		del_item( coin );
 }
 
-/**/
+/***************************************************************
+* 󥹥˹
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	mnstr_drop_bone( mnstr_t *p )
+{
+	dun_t	*dun = get_dun();
+	long	max_n;
+	long	i;
+
+	if( p == NULL )
+		return;
+	if( p->mnstr_tab == NULL )
+		return;
+
+	if( !rate_randm( MNSTR_DROP_BONE_RATE ) )
+		return;
+
+	if( p->mnstr_tab->bone_ave_n <= 0 )
+		max_n = 0;
+	else
+		max_n = roll_dice( p->mnstr_tab->bone_ave_n, FALSE );
+
+	for( i = 0; i < max_n; i++ ){
+		item_t	*bone;
+
+		bone = make_item_bone( dun->lev, p->mnstr_tab );
+		if( bone == NULL )
+			continue;
+
+		if( !put_item( bone, p->x, p->y, PUT_ITEM_R, FALSE ) )
+			del_item( bone );
+	}
+}
+
+/***************************************************************
+* 󥹥˥ƥ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	mnstr_drop_item( mnstr_t *p )
 {
@@ -1331,7 +1511,9 @@ void	mnstr_drop_item( mnstr_t *p )
 	}
 }
 
-/**/
+/***************************************************************
+* ƤΥ󥹥ȯȲĻξ֤ˤ
+***************************************************************/
 
 void	set_find_all_mnstr( void )
 {
@@ -1367,7 +1549,9 @@ void	set_find_all_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* 󥹥ؤΥꥹȤɽ
+***************************************************************/
 
 void	print_ls_mnstr( void )
 {
@@ -1423,7 +1607,10 @@ void	print_ls_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* NPC μ֤
+* return : NPC μ
+***************************************************************/
 
 mnstr_kind_t	get_npc_kind_randm( void )
 {
@@ -1443,7 +1630,11 @@ mnstr_kind_t	get_npc_kind_randm( void )
 	return g_ls_npc_kind[n];
 }
 
-/**/
+/***************************************************************
+* 󥹥̾ǡơ֥뤫鸡
+* mnstr_kind_t mnstr_kind : 󥹥μ
+* return : 󥹥̾
+***************************************************************/
 
 char	*get_mnstr_name( mnstr_kind_t mnstr_kind )
 {
@@ -1456,7 +1647,12 @@ char	*get_mnstr_name( mnstr_kind_t mnstr_kind )
 	return tab->name;
 }
 
-/**/
+/***************************************************************
+* 󥹥Υǡơ֥򸡺
+* mnstr_kind_t mnstr_kind : 󥹥μ
+* long dun_lev : 󥸥γ
+* return : 󥹥Υǡơ֥
+***************************************************************/
 
 mnstr_tab_t	*get_mnstr_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 {
@@ -1477,7 +1673,11 @@ mnstr_tab_t	*get_mnstr_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 	return tab;
 }
 
-/**/
+/***************************************************************
+* 󥹥Υǡơ֥˸
+* long dun_lev : 󥸥γ
+* return : 󥹥Υǡơ֥
+***************************************************************/
 
 mnstr_tab_t	*get_mnstr_tab_rand( long dun_lev )
 {
@@ -1508,7 +1708,10 @@ mnstr_tab_t	*get_mnstr_tab_rand( long dun_lev )
 	return get_mnstr_tab( kind, dun_lev );
 }
 
-/**/
+/***************************************************************
+* ͧŪʥ󥹥Υǡơ֥˸
+* return : 󥹥Υǡơ֥
+***************************************************************/
 
 mnstr_tab_t	*get_mnstr_tab_friendly( void )
 {
@@ -1529,7 +1732,10 @@ mnstr_tab_t	*get_mnstr_tab_friendly( void )
 	return tab;
 }
 
-/**/
+/***************************************************************
+* ν̱Υǡơ֥˸
+* return : ν̱Υǡơ֥
+***************************************************************/
 
 mnstr_tab_t	*get_towner_tab_rand( void )
 {
@@ -1564,7 +1770,12 @@ mnstr_tab_t	*get_towner_tab_rand( void )
 	return get_mnstr_tab( towner_tab[i].kind, 0 );
 }
 
-/**/
+/***************************************************************
+* 󥹥νиơ֥򸡺
+* mnstr_kind_t mnstr_kind : 󥹥μ
+* long dun_lev : 󥸥γ
+* return : 󥹥νиơ֥
+***************************************************************/
 
 mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 {
@@ -1602,7 +1813,11 @@ mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 	return tab;
 }
 
-/**/
+/***************************************************************
+* 󥹥ΥꥹȤ
+* mnstr_t *ls : 󥹥Υꥹ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p )
 {
@@ -1629,13 +1844,18 @@ void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p )
 	ls->prev = p;
 }
 
-/**/
+/***************************************************************
+* 󥹥˷иͤͿ
+* chr_t *chr : 󥹥
+* long exp : и
+* bool_t flg_print_lev : ٥Υåɽ뤫
+***************************************************************/
 
 void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev )
 {
 	long	left_exp;
 	rate_t	abl_sum;
-	abl_kind_t	k, left_k;
+	long	left_k, k;
 	long	left_n;
 
 	if( chr == NULL )
@@ -1671,41 +1891,84 @@ void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev )
 	}
 
 	chr->abl.exp[left_k].n += left_exp;
+	if( chr->abl.exp[left_k].n > EXP_MAX )
+		chr->abl.exp[left_k].n = EXP_MAX;
 
 	chk_lev_up( chr, FALSE, flg_print_lev );
 }
 
-/**/
+/***************************************************************
+* 󥹥ݤηиͤ׻
+* mnstr_t *p : 󥹥
+* long dun_lev : 󥸥γ
+* return : и
+***************************************************************/
 
 long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
 {
 	long	lev;
 	long	exp;
 
+	if( p == NULL )
+		return 1;
+	if( p->mnstr_tab == NULL )
+		return 1;
+
+	/* µܤγؤ׻ */
+
 	lev = labs( dun_lev ) * RATE_LEV_PER_DUN_LEV / _100_PERCENT;
 
 	exp = calc_need_exp( lev, ABL_KIND_HP );
 	exp -= calc_need_exp( lev - 1, ABL_KIND_HP );
 
+	/* 󥹥ɤݤȥСΥ٥뤬夬뤫ܰ */
+
 	exp /= EXP_NEED_KILL_MNSTR_N;
 
+	/*  */
+
+	exp += exp * p->mnstr_tab->exp / _100_PERCENT;
+
+	/* ο */
+
+	exp *= calc_mnstr_group_rate( p->mnstr_tab->group );
+	exp /= _100_PERCENT;
+
+	/**/
+
 	if( exp < 1 )
 		exp = 1;
+
 	exp *= MBR_MAX_N;
 	exp = exp * _100_PERCENT / ABL_RATE_MAX_N;
 
 	return exp;
 }
 
-/**/
+/***************************************************************
+* 󥹥ơ֥뤫ºݤΥ󥹥Υ٥׻
+* long dun_lev : 󥸥γ
+* abl_kind_t k : ǽͤμ
+* mnstr_tab_t *tab : 󥹥ơ֥
+* return : ٥
+***************************************************************/
 
-long	calc_mnstr_abl_lev( long dun_lev, rate_t rate )
+long	calc_mnstr_abl_lev( long dun_lev, abl_kind_t k, mnstr_tab_t *tab )
 {
+	rate_t	rate;
 	long	lev;
 
+	if( tab == NULL )
+		return 0;
+
+	rate = tab->abl_lev_rate[k];
+
 	lev = labs( dun_lev ) * RATE_LEV_PER_DUN_LEV / _100_PERCENT;
 	lev = lev * rate / _100_PERCENT;
 
+	/* οǥ٥ */
+	lev = lev * calc_mnstr_group_rate( tab->group ) / _100_PERCENT;
+
 	if( lev < 0 )
 		lev = 0;
 	if( lev < 1 )
@@ -1715,7 +1978,34 @@ long	calc_mnstr_abl_lev( long dun_lev, rate_t rate )
 	return lev;
 }
 
-/**/
+/***************************************************************
+* 󥹥ηζ׻
+* long group_n : ο
+* return : ζΨ
+***************************************************************/
+
+rate_t	calc_mnstr_group_rate( long group_n )
+{
+	long	group_denomi;
+	rate_t	group_rate;
+
+	if( group_n < 1 )
+		group_n = 1;
+
+	group_denomi = (group_n + GROUP_RATE_DENOMINATOR - 1)
+			/ GROUP_RATE_DENOMINATOR;
+	group_rate = (_100_PERCENT - GROUP_RATE_BASE) / group_denomi
+			+ GROUP_RATE_BASE;
+
+	return group_rate;
+}
+
+/***************************************************************
+* 󥹥ν׻
+* long dun_lev : 󥸥γ
+* rate_t rate : äƤΨ
+* return : 󥹥ν
+***************************************************************/
 
 gold_t	calc_mnstr_gold( long dun_lev, rate_t rate )
 {
@@ -1729,7 +2019,13 @@ gold_t	calc_mnstr_gold( long dun_lev, rate_t rate )
 	return gold;
 }
 
-/**/
+/***************************************************************
+* 󥹥κɸذưǽĴ٤
+* mnstr_tab_t *tab : 󥹥ơ֥
+* long x : X ɸ
+* long y : Y ɸ
+* return : ưǽ?
+***************************************************************/
 
 bool_t	can_move_mnstr_tab( mnstr_tab_t *tab, long x, long y )
 {
@@ -1739,7 +2035,12 @@ bool_t	can_move_mnstr_tab( mnstr_tab_t *tab, long x, long y )
 	return can_move_chr_pos( NULL, x, y, tab->dx, tab->dy );
 }
 
-/**/
+/***************************************************************
+* κɸΥ󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
 
 mnstr_t	*get_mnstr( long x, long y )
 {
@@ -1776,7 +2077,12 @@ mnstr_t	*get_mnstr( long x, long y )
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* κɸ˰ֶᤤ󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
 
 mnstr_t	*get_mnstr_nearest( long x, long y )
 {
@@ -1821,7 +2127,12 @@ mnstr_t	*get_mnstr_nearest( long x, long y )
 	return ret_p;
 }
 
-/**/
+/***************************************************************
+* κɸŪᤤ󥹥򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
 
 mnstr_t	*get_mnstr_near( long x, long y )
 {
@@ -1865,7 +2176,11 @@ mnstr_t	*get_mnstr_near( long x, long y )
 	return ret_p;
 }
 
-/**/
+/***************************************************************
+* С˶ᤤ󥹥ѡƥʬŪˤʤͤ˸
+* mbr_t *mbr : С
+* return : 󥹥
+***************************************************************/
 
 mnstr_t	*get_mnstr_disperse( mbr_t *mbr )
 {
@@ -1917,7 +2232,12 @@ mnstr_t	*get_mnstr_disperse( mbr_t *mbr )
 	return ret_p;
 }
 
-/**/
+/***************************************************************
+* ȯƤ󥹥˸
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
 
 mnstr_t	*get_mnstr_randm( long x, long y )
 {
@@ -1949,7 +2269,12 @@ mnstr_t	*get_mnstr_randm( long x, long y )
 	return ret_p;
 }
 
-/**/
+/***************************************************************
+* Сʳ󥹥򥿡åȤƤ뤫Ĵ٤
+* mnstr_t *mnstr : 󥹥
+* mbr_t *mbr : С
+* return : åȤƤ뤫?
+***************************************************************/
 
 bool_t	already_mark_mnstr( mnstr_t *mnstr, mbr_t *mbr )
 {
@@ -1969,7 +2294,13 @@ bool_t	already_mark_mnstr( mnstr_t *mnstr, mbr_t *mbr )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ȯƤ󥹥˸
+* ̥С(̤)
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
 
 mnstr_t	*get_mnstr_randm2( long x, long y )
 {
@@ -2047,7 +2378,12 @@ mnstr_t	*get_mnstr_randm2( long x, long y )
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* 󥹥δʸ򸡺
+* char mjr : ᥸㡼δʸ
+* char mnr : ޥʡδʸ
+* return : 󥹥μ
+***************************************************************/
 
 mnstr_kind_t	get_mnstr_kind_from_face( char mjr, char mnr )
 {
@@ -2071,12 +2407,13 @@ mnstr_kind_t	get_mnstr_kind_from_face( char mjr, char mnr )
 	return k;
 }
 
-/**/
+/***************************************************************
+* 󥹥γƺѥ꡼ꥹȤ֤
+* return : 󥹥Υ꡼ꥹ
+***************************************************************/
 
 mnstr_t	*get_mnstr_used( void )
 {
 	return &mnstr_used;
 }
 
-/**/
-
