@@ -20,6 +20,7 @@ void	new_mbr(
 bool_t	reset_mbr_resi( mbr_t *mbr );
 void	set_mbr_dir( void );
 void	appear_party( void );
+void	scroll_center_appear_party( void );
 void	clr_map_all_mbr( void );
 void	set_map_all_mbr( void );
 void	move_all_mbr_trgt( void );
@@ -37,6 +38,7 @@ void	join_mbr( long ls_mbr_n, long mbr_n );
 void	not_join_mbr( long ls_mbr_n, long mbr_n );
 void	collect_gold( mbr_t *mbr );
 void	divide_gold( void );
+void	give_gold( mbr_t *mbr_from, mbr_t *mbr_to, gold_t gold );
 gold_t	get_party_gold( void );
 void	add_party_gold( gold_t gold );
 gold_t	sub_party_gold( gold_t gold );
