@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,63 +25,30 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.46 2004/12/08 04:56:17 bowkenken Exp $
+* $Id: pet.c,v 1.51 2006/01/15 14:05:51 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-#include	"item.h"
-/*#include	"spell.h"*/
-#include	"chr.h"
-#include	"party.h"
-#include	"mnstr.h"
-#include	"pet.h"
-/*#include	"fight.h"*/
-#include	"fx.h"
-#include	"trap.h"
-#include	"draw.h"
-/*#include	"curs.h"*/
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-/*#include	"dun-prot.h"*/
-/*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
-/*#include	"spell-prot.h"*/
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"pet-prot.h"
-#include	"pet-prot.h"
-/*#include	"fight-prot.h"*/
-#include	"fx-prot.h"
-#include	"trap-prot.h"
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* ڥåȡȤ⡦
+***************************************************************/
 
-/**/
+#define	PET_C
+#include	"inc.h"
 
+/***************************************************************/
+
+/* ѡƥΤĤƤڥåȤΥꥹ */
 static pet_t	*party_pet[PET_MAX_N];
 
+/* ƤΥڥåȤΥꥹ */
 static pet_t	*ls_pet[LS_PET_MAX_N + 1];
+
+/* ڥåȤΥ꡼ס */
 static pet_t	ls_pet_buf[LS_PET_MAX_N + 1];
 
-/**/
+/***************************************************************
+* ڥåȤν
+***************************************************************/
 
 void	init_pet( void )
 {
@@ -102,7 +69,9 @@ void	init_pet( void )
 		init_pet_debug();
 }
 
-/**/
+/***************************************************************
+* ǥХåΥڥåȤν
+***************************************************************/
 
 void	init_pet_debug( void )
 {
@@ -116,7 +85,13 @@ void	init_pet_debug( void )
 		join_pet( p );
 }
 
-/**/
+/***************************************************************
+* ڥåȤϤ
+* long dun_lev : 󥸥󡦥٥
+* pet_kind_t pet_kind : ڥåȤμ
+* chr_t *owner : ڥåȤλ
+* return : ڥå
+***************************************************************/
 
 pet_t	*make_pet( long dun_lev, pet_kind_t pet_kind, chr_t *owner )
 {
@@ -146,7 +121,13 @@ pet_t	*make_pet( long dun_lev, pet_kind_t pet_kind, chr_t *owner )
 	return p;
 }
 
-/**/
+/***************************************************************
+* Ƥ꡼˥ڥåȤϤ
+* pet_t *p : ڥå
+* long dun_lev : 󥸥󡦥٥
+* pet_kind_t pet_kind : ڥåȤμ
+* return : ڥå
+***************************************************************/
 
 pet_t	*make_pet_alloc( pet_t *p, long dun_lev, pet_kind_t pet_kind )
 {
@@ -172,7 +153,10 @@ pet_t	*make_pet_alloc( pet_t *p, long dun_lev, pet_kind_t pet_kind )
 	return p;
 }
 
-/**/
+/***************************************************************
+* ڥåȤκΥǥեͤ
+* pet_t *p : ڥå
+***************************************************************/
 
 void	new_pet( pet_t *pet )
 {
@@ -182,11 +166,15 @@ void	new_pet( pet_t *pet )
 	new_mnstr( pet );
 }
 
-/**/
+/***************************************************************
+* ڥåȤͤꥻå
+* pet_t *p : ڥå
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	reset_pet_resi( pet_t *pet )
 {
-	resi_kind_t	k;
+	long	k;
 
 	if( pet == NULL )
 		return FALSE;
@@ -202,7 +190,9 @@ bool_t	reset_pet_resi( pet_t *pet )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ƤΥڥåȤޥåפä
+***************************************************************/
 
 void	clr_map_all_pet( void )
 {
@@ -212,7 +202,9 @@ void	clr_map_all_pet( void )
 		clr_map_chr( party_pet[i] );
 }
 
-/**/
+/***************************************************************
+* ƤΥڥåȤޥåפ˽Ф
+***************************************************************/
 
 void	set_map_all_pet( void )
 {
@@ -222,7 +214,9 @@ void	set_map_all_pet( void )
 		set_map_chr( party_pet[i] );
 }
 
-/**/
+/***************************************************************
+* ƤΥڥåȤޥåפ˽и
+***************************************************************/
 
 void	appear_all_pet( void )
 {
@@ -236,32 +230,37 @@ void	appear_all_pet( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ڥåȤޥåפ˽и
+* pet_t *p : ڥå
+***************************************************************/
 
-void	appear_pet( pet_t *pet )
+void	appear_pet( pet_t *p )
 {
 	long	x, y;
 
-	if( pet == NULL )
+	if( p == NULL )
 		return;
-	if( chk_flg_or( pet->stat,
+	if( chk_flg_or( p->stat,
 			FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 		return;
 	}
 
-	if( pet->owner == NULL ){
+	if( p->owner == NULL ){
 		x = MAP_MAX_X / 2;
 		y = MAP_MAX_Y / 2;
 	} else {
-		x = pet->owner->x;
-		y = pet->owner->y;
+		x = p->owner->x;
+		y = p->owner->y;
 	}
 
-	put_chr( pet, x, y );
-	draw_pet( pet );
+	put_chr( p, x, y );
+	draw_pet( p );
 }
 
-/**/
+/***************************************************************
+* ƤΥڥåȤΰưե¹
+***************************************************************/
 
 void	move_phase_all_pet( void )
 {
@@ -279,7 +278,9 @@ void	move_phase_all_pet( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ƤΥڥåȤιưե¹
+***************************************************************/
 
 void	act_phase_all_pet( void )
 {
@@ -297,7 +298,10 @@ void	act_phase_all_pet( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ڥåȤɸŪʹư
+* pet_t *p : ڥå
+***************************************************************/
 
 void	set_act_pet_std( pet_t *p )
 {
@@ -312,7 +316,10 @@ void	set_act_pet_std( pet_t *p )
 	}
 }
 
-/**/
+/***************************************************************
+* ڥåȤΥåȤɸŪ
+* pet_t *p : ڥå
+***************************************************************/
 
 void	pet_mark_std( pet_t *p )
 {
@@ -365,7 +372,9 @@ void	pet_mark_std( pet_t *p )
 	}
 }
 
-/**/
+/***************************************************************
+* ƤΥڥåȤˤĤ櫤˳ݤäå
+***************************************************************/
 
 void	chk_trap_all_pet( void )
 {
@@ -382,21 +391,32 @@ void	chk_trap_all_pet( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ѡƥΤĤƤڥåȤΥꥹȤ֤
+* return : ڥåȤΥꥹ
+***************************************************************/
 
 pet_t	**get_party_pet( void )
 {
 	return party_pet;
 }
 
-/**/
+/***************************************************************
+* ƤΥڥåȤΥꥹȤ֤
+* return : ƤΥڥåȤΥꥹ
+***************************************************************/
 
 pet_t	**get_ls_pet( void )
 {
 	return ls_pet;
 }
 
-/**/
+/***************************************************************
+* κɸΥڥåȤ򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : ڥå
+***************************************************************/
 
 pet_t	*get_pet( long x, long y )
 {
@@ -428,7 +448,11 @@ pet_t	*get_pet( long x, long y )
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* ΰ˴ط NPC (ڥå)򸡺
+* request_t *req : 
+* return : NPC (ڥå)
+***************************************************************/
 
 pet_t	*get_npc_request( request_t *req )
 {
@@ -450,7 +474,10 @@ pet_t	*get_npc_request( request_t *req )
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* ڥåȤλ
+* pet_t *p : ڥå
+***************************************************************/
 
 void	clr_pet_owner( pet_t *p )
 {
@@ -471,51 +498,63 @@ void	clr_pet_owner( pet_t *p )
 	}
 }
 
-/**/
+/***************************************************************
+* ڥåȤѡƥ˲ä뤫Ĵ٤
+* pet_t *p : ڥå
+* return : ä뤫?
+***************************************************************/
 
-bool_t	chk_can_join_pet( pet_t *pet )
+bool_t	chk_can_join_pet( pet_t *p )
 {
 	long	i;
 
 	for( i = 0; i < PET_MAX_N; i++ ){
-		if( party_pet[i] == pet )
+		if( party_pet[i] == p )
 			return FALSE;
 	}
 
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ڥåȤѡƥ鳰뤫Ĵ٤
+* pet_t *p : ڥå
+* return : 뤫?
+***************************************************************/
 
-bool_t	chk_can_not_join_pet( pet_t *pet )
+bool_t	chk_can_not_join_pet( pet_t *p )
 {
 	long	i;
 
 	for( i = 0; i < PET_MAX_N; i++ ){
-		if( party_pet[i] == pet )
+		if( party_pet[i] == p )
 			return TRUE;
 	}
 
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ڥåȤѡƥ˲ä
+* pet_t *p : ڥå
+* return : ä줿?
+***************************************************************/
 
-bool_t	join_pet( pet_t *pet )
+bool_t	join_pet( pet_t *p )
 {
 	long	i;
 
-	if( pet == NULL )
+	if( p == NULL )
 		return FALSE;
-	if( !chk_can_join_pet( pet ) )
+	if( !chk_can_join_pet( p ) )
 		return FALSE;
 
 	for( i = 0; i < PET_MAX_N; i++ ){
 		if( party_pet[i] != NULL )
 			continue;
 
-		party_pet[i] = pet;
-		appear_pet( pet );
+		party_pet[i] = p;
+		appear_pet( p );
 
 		return TRUE;
 	}
@@ -523,28 +562,32 @@ bool_t	join_pet( pet_t *pet )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ڥåȤѡƥ鳰
+* pet_t *p : ڥå
+* return : 줿?
+***************************************************************/
 
-bool_t	not_join_pet( pet_t *pet )
+bool_t	not_join_pet( pet_t *p )
 {
 	long	i;
 
-	if( pet == NULL )
+	if( p == NULL )
 		return FALSE;
-	if( !chk_can_not_join_pet( pet ) )
+	if( !chk_can_not_join_pet( p ) )
 		return FALSE;
 
 	for( i = 0; i < PET_MAX_N; i++ ){
-		if( party_pet[i] != pet )
+		if( party_pet[i] != p )
 			continue;
 
-		clr_map_chr( pet );
-		draw_pet( pet );
+		clr_map_chr( p );
+		draw_pet( p );
 
-		pet->pre_x = pet->x;
-		pet->pre_y = pet->y;
-		pet->x = MAP_DEL_X;
-		pet->y = MAP_DEL_Y;
+		p->pre_x = p->x;
+		p->pre_y = p->y;
+		p->x = MAP_DEL_X;
+		p->y = MAP_DEL_Y;
 		party_pet[i] = NULL;
 
 		return TRUE;
@@ -553,72 +596,84 @@ bool_t	not_join_pet( pet_t *pet )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ڥåȤν
+* pet_t *p : ڥå
+***************************************************************/
 
-void	die_pet( pet_t *pet )
+void	die_pet( pet_t *p )
 {
 }
 
-/**/
+/***************************************************************
+* ڥåȤŪԤ
+* pet_t *p : ڥå
+***************************************************************/
 
-void	remove_pet( pet_t *pet )
+void	remove_pet( pet_t *p )
 {
-	if( pet == NULL )
+	if( p == NULL )
 		return;
-	if( !is_pet( pet ) )
+	if( !is_pet( p ) )
 		return;
 
-	pet->flg_chr |= FLG_CHR_CAN_DISMISSAL;
-	dismissal( pet );
+	p->flg_chr |= FLG_CHR_CAN_DISMISSAL;
+	dismissal( p );
 }
 
-/**/
+/***************************************************************
+* ڥåȤԤ
+* pet_t *p : ڥå
+* return : Խ褿?
+***************************************************************/
 
-bool_t	dismissal( pet_t *pet )
+bool_t	dismissal( pet_t *p )
 {
 	long	i;
 
-	if( pet == NULL )
+	if( p == NULL )
 		return FALSE;
-	if( pet->kind != CHR_KIND_MNSTR )
+	if( p->kind != CHR_KIND_MNSTR )
 		return FALSE;
-	if( !chk_flg( pet->flg_chr, FLG_CHR_CAN_DISMISSAL ) )
+	if( !chk_flg( p->flg_chr, FLG_CHR_CAN_DISMISSAL ) )
 		return FALSE;
 
-	not_join_pet( pet );
+	not_join_pet( p );
 
 	for( i = 0; i < PET_MAX_N; i++ ){
-		if( party_pet[i] == pet ){
+		if( party_pet[i] == p ){
 			party_pet[i] = NULL;
 			break;
 		}
 	}
-	die_chr( pet, FALSE, FALSE, FALSE );
+	die_chr( p, FALSE, FALSE, FALSE );
 
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 饯ڥåȤĴ٤
+* pet_t *p : ڥå
+* return : ڥåȤ?
+***************************************************************/
 
-bool_t	is_pet( pet_t *pet )
+bool_t	is_pet( pet_t *p )
 {
 	long	i;
 
-	if( pet == NULL )
+	if( p == NULL )
 		return FALSE;
-	if( pet->kind != CHR_KIND_MNSTR )
+	if( p->kind != CHR_KIND_MNSTR )
 		return FALSE;
 
 	for( i = 0; i < LS_PET_MAX_N; i++ ){
 		if( ls_pet[i] == NULL )
 			continue;
 
-		if( ls_pet[i] == pet )
+		if( ls_pet[i] == p )
 			return TRUE;
 	}
 
 	return FALSE;
 }
 
-/**/
-
