@@ -5,6 +5,7 @@ extern "C" {
 #endif
 
 void	init_request( void );
+void	make_request_all( void );
 request_t	*make_request_randm( void );
 request_t	*make_request_rare_goods( request_t *req );
 request_t	*make_request_tame_mnstr( request_t *req );
@@ -26,9 +27,9 @@ long	get_request_n( void );
 char	*get_request_kind_name( request_kind_t kind );
 void	chk_request_limit( void );
 bool_t	chk_request_limit_client( request_t *req );
-void	chk_request_contract( void );
-void	chk_clr_request_contract( void );
-void	chk_set_request_contract( void );
+void	chk_request_npc_contract( void );
+void	chk_clr_request_npc_contract( void );
+void	chk_set_request_npc_contract( void );
 bool_t	set_request_msg( request_t *req );
 void	set_request_msg_var(
 	request_t *req,
@@ -107,10 +108,12 @@ void	put_request_mnstr( void );
 char	*cb_menu_request_mbr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_request_bar( menu_t **pp, menu_t **dflt );
 char	*set_menu_request(
-	menu_t **pp, menu_t **dflt, menu_call_back_t cb, bool_t flg_mbr
+	menu_t **pp, menu_t **dflt,
+	menu_call_back_t cb, bool_t flg_mbr
 );
 char	*cb_menu_sel_request_mbr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_sel_request_bar( menu_t **pp, menu_t **dflt );
+char	*cb_menu_request_refresh( menu_t **pp, menu_t **dflt );
 bool_t	ask_contract_request( request_t *req );
 bool_t	ask_cancel_request( request_t *req );
 char	*cv_idx_to_request_fmt( request_t *req );
