@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,58 +25,29 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.78 2004/12/23 20:54:09 bowkenken Exp $
+* $Id: request.c,v 1.86 2006/01/12 11:22:46 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-#include	"turn.h"
-#include	"dun.h"
-/*#include	"town.h"*/
-#include	"item.h"
-/*#include	"spell.h"*/
-#include	"chr.h"
-#include	"party.h"
-#include	"mnstr.h"
-#include	"pet.h"
-/*#include	"fight.h"*/
-#include	"fx.h"
-/*#include	"trap.h"*/
-#include	"draw.h"
-#include	"curs.h"
-#include	"menu.h"
-/*#include	"amenu.h"*/
-#include	"request.h"
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-/*#include	"gmain-prot.h"*/
-#include	"misc-prot.h"
-#include	"turn-prot.h"
-#include	"dun-prot.h"
-/*#include	"town-prot.h"*/
-#include	"item-prot.h"
-/*#include	"spell-prot.h"*/
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"pet-prot.h"
-/*#include	"fight-prot.h"*/
-#include	"fx-prot.h"
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-#include	"menu-prot.h"
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-#include	"request-prot.h"
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* ΰ
+***************************************************************/
 
-/**/
+#define	REQUEST_C
+#include	"inc.h"
 
-#define	FLG_DEBUG_REQUEST	1
+/***************************************************************/
 
+/* ǥХå뤫? */
+#if	0
+# define	FLG_DEBUG_REQUEST	1
+#else
+# define	FLG_DEBUG_REQUEST	0
+#endif
+
+/* Υ˥塼ꥹȤΥڡιܿ */
+#define	MENU_REQUEST_N_PER_PAGE	10
+
+/* ʿѴ */
 #define	REQUEST_RARE_GOODS_AVE_LIMIT	7
 #define	REQUEST_TAME_MNSTR_AVE_LIMIT	7
 #define	REQUEST_RESCUE_AVE_LIMIT	7
@@ -85,20 +56,34 @@
 #define	REQUEST_REVENGE_AVE_LIMIT	12
 #define	REQUEST_WANTED_CRIMINAL_AVE_LIMIT	12
 
+/* ñʰγ */
 #define	REQUEST_DUN_MIN_LEV_EASY	1
 #define	REQUEST_DUN_MAX_LEV_EASY	50
+/* ̤ΰγ */
 #define	REQUEST_DUN_MIN_LEV_NORMAL	10
 #define	REQUEST_DUN_MAX_LEV_NORMAL	50
-#define	REQUEST_DUN_RANGE_LEV	1
+/* γϰ */
+#define	REQUEST_DUN_RANGE_LEV	2
 
-#define	REQUEST_CONTRACT_RATE	20
+/* NPC Ψ */
+#define	REQUEST_NPC_CONTRACT_RATE	20
 
+/* õ륢ƥ󥹥Ψ */
 #define	REQUEST_RARE_GOODS_DROP_RATE	((rate_t)30)
+
+/* ץΰΥ󥹥ʿѿ */
 #define	REQUEST_TAME_MNSTR_MNSTR_AVE_N	4
+/* Ѹΰݤ٤󥹥ʿѿ */
 #define	REQUEST_TOUR_GUIDE_MNSTR_AVE_N	4
+/* 󥹥༣ΰݤ٤󥹥ʿѿ */
 #define	REQUEST_EXTERMINATE_MNSTR_AVE_N	4
 
-/**/
+/* ¾ΰꥹȤ򸫤μ */
+#define	REQUEST_REFRESH_PRIZE	((gold_t)(2 * MBR_MAX_N))
+
+/***************************************************************
+* 󽷤ζȷиͤΨ
+***************************************************************/
 
 #define	REQUEST_RARE_GOODS_GOLD_RATE	((rate_t)2000)
 #define	REQUEST_RARE_GOODS_EXP_RATE	((rate_t)1000)
@@ -123,16 +108,24 @@
 
 #define	REQUEST_PENALTY_RATE	((rate_t)10)
 
-/**/
+/***************************************************************
+* Хѿ
+***************************************************************/
 
+/* Υǡꥹ */
 static request_t	g_request[REQUEST_MAX_N];
+/* Υ˥塼 */
 static menu_t	ls_menu_request[1 + REQUEST_MAX_N * 2];
 
-/**/
+/***************************************************************
+* Υơ֥
+***************************************************************/
 
 #include	"request-tab.h"
 
-/**/
+/***************************************************************
+* ν
+***************************************************************/
 
 void	init_request( void )
 {
@@ -142,7 +135,28 @@ void	init_request( void )
 		g_request[i].kind = REQUEST_KIND_NULL;
 }
 
-/**/
+/***************************************************************
+* Ϥ
+***************************************************************/
+
+void	make_request_all( void )
+{
+	long	request_n, request_max_n;
+	long	i;
+
+	request_n = get_request_n();
+	request_max_n = roll_dice( REQUEST_AVE_N, TRUE );
+	for( i = request_n; i < request_max_n; i++ )
+		make_request_randm();
+
+	chk_request_limit();
+	chk_request_npc_contract();
+}
+
+/***************************************************************
+* Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_randm( void )
 {
@@ -177,7 +191,11 @@ request_t	*make_request_randm( void )
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* ƥõΰϤ
+* request_t *req : Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_rare_goods( request_t *req )
 {
@@ -233,7 +251,11 @@ request_t	*make_request_rare_goods( request_t *req )
 	return req;
 }
 
-/**/
+/***************************************************************
+* ץΰϤ
+* request_t *req : Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_tame_mnstr( request_t *req )
 {
@@ -282,7 +304,11 @@ request_t	*make_request_tame_mnstr( request_t *req )
 	return req;
 }
 
-/**/
+/***************************************************************
+* ߽ΰϤ
+* request_t *req : Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_rescue( request_t *req )
 {
@@ -326,7 +352,11 @@ request_t	*make_request_rescue( request_t *req )
 	return req;
 }
 
-/**/
+/***************************************************************
+* ѸΰϤ
+* request_t *req : Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_tour_guide( request_t *req )
 {
@@ -385,7 +415,11 @@ request_t	*make_request_tour_guide( request_t *req )
 	return req;
 }
 
-/**/
+/***************************************************************
+* 󥹥༣ΰϤ
+* request_t *req : Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_exterminate( request_t *req )
 {
@@ -444,7 +478,11 @@ request_t	*make_request_exterminate( request_t *req )
 	return req;
 }
 
-/**/
+/***************************************************************
+* ƤΰϤ
+* request_t *req : Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_revenge( request_t *req )
 {
@@ -493,7 +531,11 @@ request_t	*make_request_revenge( request_t *req )
 	return req;
 }
 
-/**/
+/***************************************************************
+* ޶ΰϤ
+* request_t *req : Ϥ
+* return : 
+***************************************************************/
 
 request_t	*make_request_wanted_criminal( request_t *req )
 {
@@ -542,7 +584,13 @@ request_t	*make_request_wanted_criminal( request_t *req )
 	return req;
 }
 
-/**/
+/***************************************************************
+*  NPC Ϥ
+* request_t *req : Ϥ
+* mnstr_kind_t kind : μ
+* bool_t flg_now : Ϥ뤫?(µϤ)
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 {
@@ -659,7 +707,13 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* γؤ
+* request_t *req : 
+* long min_lev : Ǿ
+* long max_lev : 糬
+* long range_lev : ؤϰ
+***************************************************************/
 
 void	set_request_dun_lev(
 	request_t *req,
@@ -689,7 +743,11 @@ void	set_request_dun_lev(
 	req->dun_true_lev = -(lev + randm( true_range_lev ));
 }
 
-/**/
+/***************************************************************
+* ꥹȤå
+* n_msg_t ls[] : ꥹ
+* return : å
+***************************************************************/
 
 n_msg_idx_t	get_ls_n_msg_idx_randm( n_msg_t ls[] )
 {
@@ -707,7 +765,10 @@ n_msg_idx_t	get_ls_n_msg_idx_randm( n_msg_t ls[] )
 	return( randm( i ) );
 }
 
-/**/
+/***************************************************************
+* Υ꡼Ƥ(ǥեͤꤹ)
+* return : 
+***************************************************************/
 
 request_t	*alloc_request( void )
 {
@@ -783,7 +844,10 @@ request_t	*alloc_request( void )
 	return( &(g_request[i]) );
 }
 
-/**/
+/***************************************************************
+* Υ꡼
+* request_t *req : 
+***************************************************************/
 
 void	free_request( request_t *req )
 {
@@ -793,14 +857,20 @@ void	free_request( request_t *req )
 	req->kind = REQUEST_KIND_NULL;
 }
 
-/**/
+/***************************************************************
+* ΥꥹȤ֤
+* return : Υꥹ
+***************************************************************/
 
 request_t	*get_request_ls( void )
 {
 	return g_request;
 }
 
-/**/
+/***************************************************************
+* ꥹȤͭʰο
+* return : ο
+***************************************************************/
 
 long	get_request_n( void )
 {
@@ -815,7 +885,11 @@ long	get_request_n( void )
 	return n;
 }
 
-/**/
+/***************************************************************
+* μ֤̾
+* request_kind_t kind : μ
+* return : μ̾
+***************************************************************/
 
 char	*get_request_kind_name( request_kind_t kind )
 {
@@ -843,7 +917,9 @@ char	*get_request_kind_name( request_kind_t kind )
 	return MSG_NULL;
 }
 
-/**/
+/***************************************************************
+* δڤå
+***************************************************************/
 
 void	chk_request_limit( void )
 {
@@ -878,7 +954,11 @@ void	chk_request_limit( void )
 	}
 }
 
-/**/
+/***************************************************************
+* δڤ NPC ̤
+* request_t *req : 
+* return : ̤줿?
+***************************************************************/
 
 bool_t	chk_request_limit_client( request_t *req )
 {
@@ -970,17 +1050,21 @@ bool_t	chk_request_limit_client( request_t *req )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+*  NPC å
+***************************************************************/
 
-void	chk_request_contract( void )
+void	chk_request_npc_contract( void )
 {
-	chk_clr_request_contract();
-	chk_set_request_contract();
+	chk_clr_request_npc_contract();
+	chk_set_request_npc_contract();
 }
 
-/**/
+/***************************************************************
+* NPC 
+***************************************************************/
 
-void	chk_clr_request_contract( void )
+void	chk_clr_request_npc_contract( void )
 {
 	long	i;
 
@@ -998,9 +1082,11 @@ void	chk_clr_request_contract( void )
 	}
 }
 
-/**/
+/***************************************************************
+* NPC ˰
+***************************************************************/
 
-void	chk_set_request_contract( void )
+void	chk_set_request_npc_contract( void )
 {
 	long	i;
 
@@ -1012,7 +1098,7 @@ void	chk_set_request_contract( void )
 			continue;
 		if( g_request[i].flg_contract )
 			continue;
-		if( !rate_randm( REQUEST_CONTRACT_RATE ) )
+		if( !rate_randm( REQUEST_NPC_CONTRACT_RATE ) )
 			continue;
 
 		/**/
@@ -1030,7 +1116,11 @@ void	chk_set_request_contract( void )
 	}
 }
 
-/**/
+/***************************************************************
+* Υå
+* request_t *req : 
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	set_request_msg( request_t *req )
 {
@@ -1096,7 +1186,14 @@ bool_t	set_request_msg( request_t *req )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ
+* request_t *req : 
+* char *buf : Ÿ
+* long *buf_idx : Ÿʸ
+* char *fmt : ѿƬ
+* long *fmt_idx : ѿʸ
+***************************************************************/
 
 void	set_request_msg_var(
 	request_t *req,
@@ -1153,7 +1250,12 @@ void	set_request_msg_var(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(Ǿ)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_dun_min_lev(
 	request_t *req, char *buf, char *arg
@@ -1168,7 +1270,12 @@ void	set_request_msg_var_dun_min_lev(
 	sprintf( buf, "%ld", req->dun_min_lev );
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(糬)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_dun_max_lev(
 	request_t *req, char *buf, char *arg
@@ -1183,7 +1290,12 @@ void	set_request_msg_var_dun_max_lev(
 	sprintf( buf, "%ld", req->dun_max_lev );
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(ؤϰ)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_dun_lev_range(
 	request_t *req, char *buf, char *arg
@@ -1225,7 +1337,12 @@ void	set_request_msg_var_dun_lev_range(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ()
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_client(
 	request_t *req, char *buf, char *arg
@@ -1248,7 +1365,12 @@ void	set_request_msg_var_client(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(õ륢ƥ)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_rare_goods(
 	request_t *req, char *buf, char *arg
@@ -1272,7 +1394,12 @@ void	set_request_msg_var_rare_goods(
 	sprintf( buf, MSG_REQUEST_VAR_QUOTE, tab->name );
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(󥹥)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_mnstr(
 	request_t *req, char *buf, char *arg
@@ -1308,7 +1435,12 @@ void	set_request_msg_var_mnstr(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(󥹥ο)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_mnstr_n(
 	request_t *req, char *buf, char *arg
@@ -1323,7 +1455,12 @@ void	set_request_msg_var_mnstr_n(
 	sprintf( buf, MSG_REQUEST_MNSTR_N, req->mnstr_n );
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(߽ NPC)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_rescue_trgt(
 	request_t *req, char *buf, char *arg
@@ -1346,7 +1483,12 @@ void	set_request_msg_var_rescue_trgt(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(β²)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_client_family(
 	request_t *req, char *buf, char *arg
@@ -1377,7 +1519,12 @@ void	set_request_msg_var_client_family(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ()
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_client_mate(
 	request_t *req, char *buf, char *arg
@@ -1400,7 +1547,12 @@ void	set_request_msg_var_client_mate(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(֥롼 A)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_when_1(
 	request_t *req, char *buf, char *arg
@@ -1431,7 +1583,12 @@ void	set_request_msg_var_when_1(
 			ls_msg, FALSE );
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ(֥롼 B)
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_when_2(
 	request_t *req, char *buf, char *arg
@@ -1462,7 +1619,12 @@ void	set_request_msg_var_when_2(
 			ls_msg, FALSE );
 }
 
-/**/
+/***************************************************************
+* ΥåѿŸ()
+* request_t *req : 
+* char *buf : Ÿ
+* char *arg : ѿΰ
+***************************************************************/
 
 void	set_request_msg_var_weapon(
 	request_t *req, char *buf, char *arg
@@ -1479,7 +1641,14 @@ void	set_request_msg_var_weapon(
 			g_ls_weapon, FALSE );
 }
 
-/**/
+/***************************************************************
+* ΥåѿꥹȤŸ
+* request_t *req : 
+* char *buf : Ÿ
+* n_msg_idx_t *n_msg_idx : ꥹȤΥǥå
+* n_msg_t ls_msg[] : ꥹ
+* bool_t flg_quote : ƥ󥰤뤫?
+***************************************************************/
 
 void	set_request_msg_var_ls(
 	request_t *req, char *buf,
@@ -1509,7 +1678,11 @@ void	set_request_msg_var_ls(
 	}
 }
 
-/**/
+/***************************************************************
+* ΥꥹȾθФ
+* request_t *req : 
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	set_request_heading( request_t *req )
 {
@@ -1535,12 +1708,19 @@ bool_t	set_request_heading( request_t *req )
 			get_request_kind_name( req->kind ),
 			req->dun_max_lev,
 			req->limit - get_game_day(),
-			req->prize );
+			fmt_gold( req->prize ) );
 
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 饯
+* request_t *req : 
+* chr_kind_t kind : 饯μ
+* n_msg_idx_t n_idx_name : NPC ̾ꥹȤΥǥå
+* sex_t sex : 
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	chr_contract_request(
 	request_t *req,
@@ -1577,7 +1757,11 @@ bool_t	chr_contract_request(
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 
+* request_t *req : 
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	finish_request( request_t *req )
 {
@@ -1600,7 +1784,11 @@ bool_t	finish_request( request_t *req )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* Ԥ
+* request_t *req : 
+* return : 顼̵ä?
+***************************************************************/
 
 bool_t	dont_finish_request( request_t *req )
 {
@@ -1617,7 +1805,10 @@ bool_t	dont_finish_request( request_t *req )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 饯ΰؤαƶå
+* chr_t *chr : 饯
+***************************************************************/
 
 void	chk_finish_request_chr_dead( chr_t *chr )
 {
@@ -1655,7 +1846,9 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	put_request_rare_goods( chr );
 }
 
-/**/
+/***************************************************************
+* 饯ΰؤαƶå(ƥõ)
+***************************************************************/
 
 void	chk_finish_request_rare_goods( void )
 {
@@ -1687,7 +1880,12 @@ void	chk_finish_request_rare_goods( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ã NPC ѡƥ˲ä
+* request_t *req : 
+* mnstr_t *npc : NPC
+* return : NPC ѡƥ˲ää?
+***************************************************************/
 
 bool_t	chk_finish_request_join( request_t *req, mnstr_t *npc )
 {
@@ -1724,7 +1922,15 @@ bool_t	chk_finish_request_join( request_t *req, mnstr_t *npc )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 󥹥ΰؤαƶå(󥹥༣)
+* mnstr_kind_t mnstr_kind : 󥹥μ
+* long add : ݤΥ󥿤­
+* request_kind_t req_kind : μ
+* bool_t flg_dec_add : 
+*   TRUE  : ƥ󥿤­­򸺤餹
+*   FALSE : ƤΥ󥿤Ʊ­
+***************************************************************/
 
 void	chk_finish_request_exterminate(
 	mnstr_kind_t mnstr_kind,
@@ -1756,12 +1962,18 @@ void	chk_finish_request_exterminate(
 		req->mnstr_exterminate_n += add;
 		if( flg_dec_add )
 			add = req->mnstr_exterminate_n - req->mnstr_n;
-		if( req->mnstr_exterminate_n >= req->mnstr_n )
+		if( req->mnstr_exterminate_n >= req->mnstr_n ){
+			req->mnstr_exterminate_n = req->mnstr_n;
 			finish_request( req );
+		}
 	}
 }
 
-/**/
+/***************************************************************
+* 饯ΰؤαƶå(Ƥ)
+* request_t *req : 
+* return : ꤬?
+***************************************************************/
 
 bool_t	chk_finish_request_revenge( request_t *req )
 {
@@ -1787,7 +1999,11 @@ bool_t	chk_finish_request_revenge( request_t *req )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 饯ΰؤαƶå(޶)
+* request_t *req : 
+* return : ꤬?
+***************************************************************/
 
 bool_t	chk_finish_request_wanted_criminal( request_t *req )
 {
@@ -1805,7 +2021,10 @@ bool_t	chk_finish_request_wanted_criminal( request_t *req )
 	}
 }
 
-/**/
+/***************************************************************
+* ƤΰĤ
+* chr_kind_t chr_kind : PC  NPC ?
+***************************************************************/
 
 void	close_all_request( chr_kind_t chr_kind )
 {
@@ -1823,7 +2042,12 @@ void	close_all_request( chr_kind_t chr_kind )
 	}
 }
 
-/**/
+/***************************************************************
+* Ĥ
+* request_t *req : 
+* chr_kind_t chr_kind : PC  NPC ?
+* return : ꤬?
+***************************************************************/
 
 bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 {
@@ -1884,7 +2108,10 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ̤
+* request_t *req : 
+***************************************************************/
 
 void	not_join_client( request_t *req )
 {
@@ -1902,6 +2129,7 @@ void	not_join_client( request_t *req )
 	case REQUEST_KIND_RARE_GOODS:
 		return;
 	case REQUEST_KIND_TAME_MNSTR:
+		/* ưʪʤ */
 		break;	/* return ǤϤʤ */
 	case REQUEST_KIND_RESCUE:
 		print_words( npc->name, npc->sex.cur,
@@ -1930,7 +2158,9 @@ void	not_join_client( request_t *req )
 	remove_pet( npc );
 }
 
-/**/
+/***************************************************************
+* Υ֥Ȥµܤ֤
+***************************************************************/
 
 void	put_request_all_obj( void )
 {
@@ -1938,7 +2168,10 @@ void	put_request_all_obj( void )
 	put_request_mnstr();
 }
 
-/**/
+/***************************************************************
+* Υ쥢åµܤ֤
+* chr_t *chr : 쥢åäƤ󥹥
+***************************************************************/
 
 void	put_request_rare_goods( chr_t *chr )
 {
@@ -1987,13 +2220,17 @@ void	put_request_rare_goods( chr_t *chr )
 	}
 }
 
-/**/
+/***************************************************************
+* Υƥµܤ֤
+***************************************************************/
 
 void	put_request_item( void )
 {
 }
 
-/**/
+/***************************************************************
+* Υ󥹥µܤ֤
+***************************************************************/
 
 void	put_request_mnstr( void )
 {
@@ -2091,7 +2328,12 @@ void	put_request_mnstr( void )
 	}
 }
 
-/**/
+/***************************************************************
+* ѡƥƤꥹȤΥ˥塼
+* menu_t **pp : ˥塼ꥹ
+* menu_t **dflt : ˥塼Υǥեȹ
+* return : ˥塼ΰư
+***************************************************************/
 
 char	*cb_menu_request_mbr( menu_t **pp, menu_t **dflt )
 {
@@ -2099,7 +2341,12 @@ char	*cb_menu_request_mbr( menu_t **pp, menu_t **dflt )
 			cb_menu_sel_request_mbr, TRUE ) );
 }
 
-/**/
+/***************************************************************
+* ΰꥹȤΥ˥塼
+* menu_t **pp : ˥塼ꥹ
+* menu_t **dflt : ˥塼Υǥեȹ
+* return : ˥塼ΰư
+***************************************************************/
 
 char	*cb_menu_request_bar( menu_t **pp, menu_t **dflt )
 {
@@ -2110,10 +2357,18 @@ char	*cb_menu_request_bar( menu_t **pp, menu_t **dflt )
 			cb_menu_sel_request_bar, FALSE ) );
 }
 
-/**/
+/***************************************************************
+* ꥹȤΥ˥塼
+* menu_t **pp : ˥塼ꥹ
+* menu_t **dflt : ˥塼Υǥեȹ
+* menu_call_back_t cb : Υ롦Хåؿ
+* bool_t flg_mbr : СƤʳåפ뤫?
+* return : ˥塼ΰư
+***************************************************************/
 
 char	*set_menu_request(
-	menu_t **pp, menu_t **dflt, menu_call_back_t cb, bool_t flg_mbr
+	menu_t **pp, menu_t **dflt,
+	menu_call_back_t cb, bool_t flg_mbr
 )
 {
 	menu_t	*ls;
@@ -2123,10 +2378,10 @@ char	*set_menu_request(
 	ls = ls_menu_request;
 	k = 0;
 
-	strncpy( ls[k].path, "/Request", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/request", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
@@ -2134,10 +2389,10 @@ char	*set_menu_request(
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/Request/--", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/request/--", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	strncpy( ls[k].msg, MSG_MENU_BAR_REQUEST, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
@@ -2149,17 +2404,19 @@ char	*set_menu_request(
 	for( i = 0; i < REQUEST_MAX_N; i++ ){
 		if( g_request[i].kind == REQUEST_KIND_NULL )
 			continue;
+
+		/* СƤʳåפ */
 		if( !g_request[i].flg_contract_mbr )
 			if( flg_mbr )
 				continue;
 
 		set_request_heading( &(g_request[i]) );
 
-		sprintf( ls[k].path, "/Request/%ld", i );
+		sprintf( ls[k].path, "/request/%ld", i );
 		strncpy( ls[k].kind, "<OpenWinItem>",
 				MENU_KIND_MAX_LEN );
-		ls[k].key = (char)('A' + (n % MENU_MAX_N_PER_PAGE));
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = (char)('A' + (n % MENU_REQUEST_N_PER_PAGE));
+		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
 		strncpy( ls[k].msg, g_request[i].heading, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb;
@@ -2168,13 +2425,28 @@ char	*set_menu_request(
 		k++;
 		n++;
 
-		if( (n % MENU_MAX_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path, "/Request/--",
+		if( ((n % MENU_REQUEST_N_PER_PAGE) == 0) && !flg_mbr ){
+			strncpy( ls[k].path, "/request/Refresh",
+					MENU_PATH_MAX_LEN );
+			strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+			ls[k].accel_key = 'Z';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			sprintf( ls[k].msg, MSG_MENU_REQUEST_REFRESH,
+					fmt_gold( REQUEST_REFRESH_PRIZE ) );
+			ls[k].call_back = cb_menu_request_refresh;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+
+		if( (n % MENU_REQUEST_N_PER_PAGE) == 0 ){
+			strncpy( ls[k].path, "/request/--",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
-			ls[k].key = '\0';
-			ls[k].accel_key[0] = '\0';
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			ls[k].msg[0] = '\0';
 			ls[k].call_back = NULL;
@@ -2183,6 +2455,20 @@ char	*set_menu_request(
 			k++;
 		}
 	}
+	if( !flg_mbr ){
+		strncpy( ls[k].path, "/request/Refresh",
+				MENU_PATH_MAX_LEN );
+		strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = 'Z';
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL;
+		sprintf( ls[k].msg, MSG_MENU_REQUEST_REFRESH,
+				fmt_gold( REQUEST_REFRESH_PRIZE ) );
+		ls[k].call_back = cb_menu_request_refresh;
+		ls[k].arg = NULL;
+		ls[k].flg = FLG_NULL;
+		k++;
+	}
 	ls[k].path[0] = '\0';
 
 	*pp = ls;
@@ -2196,7 +2482,12 @@ char	*set_menu_request(
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* ѡƥƤɽ
+* menu_t **pp : ˥塼ꥹ
+* menu_t **dflt : ˥塼Υǥեȹ
+* return : ˥塼ΰư
+***************************************************************/
 
 char	*cb_menu_sel_request_mbr( menu_t **pp, menu_t **dflt )
 {
@@ -2213,7 +2504,12 @@ char	*cb_menu_sel_request_mbr( menu_t **pp, menu_t **dflt )
 	return STR_MENU_CANCEL;
 }
 
-/**/
+/***************************************************************
+* ΰɽ
+* menu_t **pp : ˥塼ꥹ
+* menu_t **dflt : ˥塼Υǥեȹ
+* return : ˥塼ΰư
+***************************************************************/
 
 char	*cb_menu_sel_request_bar( menu_t **pp, menu_t **dflt )
 {
@@ -2239,12 +2535,58 @@ char	*cb_menu_sel_request_bar( menu_t **pp, menu_t **dflt )
 	}
 
 	if( flg_yes )
-		return "/Bar/Request";
+		return "/bar/request";
 
 	return STR_MENU_CANCEL;
 }
 
-/**/
+/***************************************************************
+* ΥꥹȤեå夷ƿʪ촹
+* menu_t **pp : ˥塼ꥹ
+* menu_t **dflt : ˥塼Υǥեȹ
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_request_refresh( menu_t **pp, menu_t **dflt )
+{
+	ask_t	ask;
+	long	i;
+
+	/* ץ쥤䡼˳ǧ */
+
+	ask = exec_menu_ask( MSG_TTL_MENU_REQUEST_REFRESH_ASK,
+			ASK_NO, TRUE );
+
+	if( ask != ASK_YES )
+		return STR_MENU_CANCEL;
+
+	/* ΥꥹȤեå */
+
+	for( i = 0; i < REQUEST_MAX_N; i++ ){
+		if( g_request[i].kind == REQUEST_KIND_NULL )
+			continue;
+
+		/* СƤϥåפ */
+		if( g_request[i].flg_contract_mbr )
+			continue;
+
+		free_request( &(g_request[i]) );
+	}
+
+	make_request_all();
+
+	/* ʧ */
+
+	sub_party_gold( REQUEST_REFRESH_PRIZE );
+
+	return "/bar/request";
+}
+
+/***************************************************************
+* 뤫ץ쥤䡼Ф
+* request_t *req : 
+* return : ?
+***************************************************************/
 
 bool_t	ask_contract_request( request_t *req )
 {
@@ -2266,7 +2608,11 @@ bool_t	ask_contract_request( request_t *req )
 	return( chr_contract_request( req, CHR_KIND_MBR, -1, FEMALE ) );
 }
 
-/**/
+/***************************************************************
+* 򥭥󥻥뤹뤫ץ쥤䡼Ф
+* request_t *req : 
+* return : 򥭥󥻥뤷?
+***************************************************************/
 
 bool_t	ask_cancel_request( request_t *req )
 {
@@ -2279,14 +2625,14 @@ bool_t	ask_cancel_request( request_t *req )
 
 	penalty = req->prize * REQUEST_PENALTY_RATE / _100_PERCENT;
 
-	sprintf( msg, MSG_TTL_MENU_REQUEST_MBR_CANCEL, penalty );
+	sprintf( msg, MSG_TTL_MENU_REQUEST_MBR_CANCEL, fmt_gold( penalty ) );
 	ask = exec_menu_ask( msg, ASK_NO, TRUE );
 	if( ask != ASK_YES )
 		return FALSE;
 
 	if( get_party_gold() < penalty ){
 		print_msg( FLG_MSG_ERR, MSG_ERR_MENU_REQUEST_MBR_CANCEL,
-				penalty - get_party_gold() );
+				fmt_gold( penalty - get_party_gold() ) );
 		return FALSE;
 	}
 	sub_party_gold( penalty );
@@ -2301,7 +2647,11 @@ bool_t	ask_cancel_request( request_t *req )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ΥꥹȤΥǥååѴ
+* request_t *req : 
+* return : å
+***************************************************************/
 
 char	*cv_idx_to_request_fmt( request_t *req )
 {
@@ -2334,7 +2684,11 @@ char	*cv_idx_to_request_fmt( request_t *req )
 	return( MSG_NULL );
 }
 
-/**/
+/***************************************************************
+*  NPC ΥꥹȤΥǥå NPC ̾Ѵ
+* request_t *req : 
+* return : NPC ̾
+***************************************************************/
 
 char	*cv_idx_to_contract_name( request_t *req )
 {
@@ -2352,7 +2706,11 @@ char	*cv_idx_to_contract_name( request_t *req )
 	return( MSG( n_msg ) );
 }
 
-/**/
+/***************************************************************
+*  NPC ΥꥹȤΥǥå NPC ̾Ѵ
+* request_t *req : 
+* return : NPC ̾
+***************************************************************/
 
 char	*cv_idx_to_client_name( request_t *req )
 {
@@ -2370,7 +2728,11 @@ char	*cv_idx_to_client_name( request_t *req )
 	return( MSG( n_msg ) );
 }
 
-/**/
+/***************************************************************
+* 󥹥 NPC ΥꥹȤΥǥå NPC ̾Ѵ
+* request_t *req : 
+* return : NPC ̾
+***************************************************************/
 
 char	*cv_idx_to_mnstr_name( request_t *req )
 {
@@ -2398,7 +2760,11 @@ char	*cv_idx_to_mnstr_name( request_t *req )
 	return( MSG_MNSTR_UNKNOWN );
 }
 
-/**/
+/***************************************************************
+* ߽ɸ NPC ΥꥹȤΥǥå NPC ̾Ѵ
+* request_t *req : 
+* return : NPC ̾
+***************************************************************/
 
 char	*cv_idx_to_rescue_trgt_name( request_t *req )
 {
@@ -2416,7 +2782,11 @@ char	*cv_idx_to_rescue_trgt_name( request_t *req )
 	return( MSG( n_msg ) );
 }
 
-/**/
+/***************************************************************
+* β² NPC ΥꥹȤΥǥå NPC ̾Ѵ
+* request_t *req : 
+* return : NPC ̾
+***************************************************************/
 
 char	*cv_idx_to_client_family_name( request_t *req )
 {
@@ -2434,7 +2804,11 @@ char	*cv_idx_to_client_family_name( request_t *req )
 	return( MSG( n_msg ) );
 }
 
-/**/
+/***************************************************************
+* ֤ NPC ΥꥹȤΥǥå NPC ̾Ѵ
+* request_t *req : 
+* return : NPC ̾
+***************************************************************/
 
 char	*cv_idx_to_client_mate_name( request_t *req )
 {
@@ -2452,5 +2826,3 @@ char	*cv_idx_to_client_mate_name( request_t *req )
 	return( MSG( n_msg ) );
 }
 
-/**/
-
