@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-kind.h,v 1.3 2004/12/12 08:04:54 bowkenken Exp $
+* $Id: spell-kind.h,v 1.7 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_KIND_H
@@ -51,6 +51,7 @@ typedef enum {
 	SPELL_KIND_SHELTER,
 	SPELL_KIND_CREATE_FOOD,
 	SPELL_KIND_IDENTIFY_ITEM,
+	SPELL_KIND_IDENTIFY_ALL_ITEM,
 	SPELL_KIND_SEARCHING,
 	SPELL_KIND_ANALYZE_DWEOMER,
 	SPELL_KIND_DETECT_ITEM,
@@ -124,6 +125,7 @@ typedef enum {
 	SPELL_KIND_SUMMON_EFREET,
 	SPELL_KIND_SUMMON_DJINNI,
 	SPELL_KIND_SUMMON_PHOENIX,
+	SPELL_KIND_SUMMON_BONE,
 	SPELL_KIND_SUMMON_RANDOM,
 	SPELL_KIND_CREATE_UNDEAD,
 	SPELL_KIND_DISMISSAL,
