@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.6 2004/12/12 09:56:14 bowkenken Exp $
+* $Id: spell-tab.h,v 1.12 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -44,7 +44,7 @@ spell_tab_t	spell_tab[] = {
 
 menu_t	ls_menu_spell[] = {
 	{
-		"/Spell",
+		"/spell",
 		"<Branch>",
 		'\0',
 		"",
@@ -54,7 +54,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ] */
 	{
-		"/Spell/MAG",
+		"/spell/MAG",
 		"<Branch>",
 		'M',
 		"",
@@ -64,7 +64,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Spell/MAG/Title Misc",
+		"/spell/MAG/title misc",
 		"<Title>",
 		'\0',
 		"",
@@ -74,7 +74,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/LIGHT",
+		"/spell/MAG/light",
 		"<Branch>",
 		'\0',
 		"",
@@ -84,7 +84,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DARKNESS",
+		"/spell/MAG/darkness",
 		"<Branch>",
 		'\0',
 		"",
@@ -94,7 +94,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/TELEPORT_PARTY",
+		"/spell/MAG/teleport_party",
 		"<Branch>",
 		'\0',
 		"",
@@ -104,7 +104,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/TELEPORT",
+		"/spell/MAG/teleport",
 		"<Branch>",
 		'\0',
 		"",
@@ -114,7 +114,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/RECALL",
+		"/spell/MAG/recall",
 		"<Branch>",
 		'\0',
 		"",
@@ -124,7 +124,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/KNOCK",
+		"/spell/MAG/knock",
 		"<Branch>",
 		'\0',
 		"",
@@ -134,7 +134,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/LOCK",
+		"/spell/MAG/lock",
 		"<Branch>",
 		'\0',
 		"",
@@ -144,7 +144,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DISARM_TRAP",
+		"/spell/MAG/disarm_trap",
 		"<Branch>",
 		'\0',
 		"",
@@ -154,7 +154,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DISPEL_MAGIC",
+		"/spell/MAG/dispel_magic",
 		"<Branch>",
 		'\0',
 		"",
@@ -164,7 +164,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/MIRROR_IMAGE",
+		"/spell/MAG/mirror_image",
 		"<Branch>",
 		'\0',
 		"",
@@ -174,7 +174,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/ANIMATE_OBJECTS",
+		"/spell/MAG/animate_objects",
 		"<Branch>",
 		'\0',
 		"",
@@ -184,7 +184,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/SHELTER",
+		"/spell/MAG/shelter",
 		"<Branch>",
 		'\0',
 		"",
@@ -194,7 +194,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/CREATE_FOOD",
+		"/spell/MAG/create_food",
 		"<Branch>",
 		'\0',
 		"",
@@ -204,7 +204,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/NO_LEARN Misc",
+		"/spell/MAG/no_learn misc",
 		"<Item>",
 		'Z',
 		"",
@@ -214,7 +214,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/--",
+		"/spell/MAG/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -224,7 +224,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ] õ */
 	{
-		"/Spell/MAG/Title Detect",
+		"/spell/MAG/title detect",
 		"<Title>",
 		'\0',
 		"",
@@ -234,7 +234,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/IDENTIFY_ITEM",
+		"/spell/MAG/identify_item",
 		"<Branch>",
 		'\0',
 		"",
@@ -244,7 +244,17 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/SEARCHING",
+		"/spell/MAG/identify_all_item",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_IDENTIFY_ALL_ITEM, "",
+		cb_menu_spell, (void *)SPELL_KIND_IDENTIFY_ALL_ITEM,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/MAG/searching",
 		"<Branch>",
 		'\0',
 		"",
@@ -254,7 +264,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/ANALYZE_DWEOMER",
+		"/spell/MAG/analyze_dweomer",
 		"<Branch>",
 		'\0',
 		"",
@@ -264,7 +274,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DETECT_MAGIC",
+		"/spell/MAG/detect_magic",
 		"<Branch>",
 		'\0',
 		"",
@@ -274,7 +284,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DETECT_ITEM",
+		"/spell/MAG/detect_item",
 		"<Branch>",
 		'\0',
 		"",
@@ -284,7 +294,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DETECT_DOORS",
+		"/spell/MAG/detect_doors",
 		"<Branch>",
 		'\0',
 		"",
@@ -294,7 +304,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DETECT_TRAPS",
+		"/spell/MAG/detect_traps",
 		"<Branch>",
 		'\0',
 		"",
@@ -304,7 +314,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DETECT_MONSTER",
+		"/spell/MAG/detect_monster",
 		"<Branch>",
 		'\0',
 		"",
@@ -314,7 +324,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/SENSE_INVISIBLE",
+		"/spell/MAG/sense_invisible",
 		"<Branch>",
 		'\0',
 		"",
@@ -324,7 +334,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/NO_LEARN Detect",
+		"/spell/MAG/no_learn detect",
 		"<Item>",
 		'Z',
 		"",
@@ -334,7 +344,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/--",
+		"/spell/MAG/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -344,7 +354,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ] Ѳ */
 	{
-		"/Spell/MAG/Title Change Status",
+		"/spell/MAG/title change status",
 		"<Title>",
 		'\0',
 		"",
@@ -354,7 +364,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/FLY",
+		"/spell/MAG/fly",
 		"<Branch>",
 		'\0',
 		"",
@@ -364,7 +374,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/FEATHER_FALL",
+		"/spell/MAG/feather_fall",
 		"<Branch>",
 		'\0',
 		"",
@@ -374,7 +384,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/VANISH",
+		"/spell/MAG/vanish",
 		"<Branch>",
 		'\0',
 		"",
@@ -384,7 +394,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/DARKVISION",
+		"/spell/MAG/darkvision",
 		"<Branch>",
 		'\0',
 		"",
@@ -394,7 +404,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/PASSWALL",
+		"/spell/MAG/passwall",
 		"<Branch>",
 		'\0',
 		"",
@@ -404,7 +414,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/POLYMORPH_OTHER",
+		"/spell/MAG/polymorph_other",
 		"<Branch>",
 		'\0',
 		"",
@@ -414,7 +424,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/POLYMORPH_SELF",
+		"/spell/MAG/polymorph_self",
 		"<Branch>",
 		'\0',
 		"",
@@ -424,7 +434,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/STEALTH",
+		"/spell/MAG/stealth",
 		"<Branch>",
 		'\0',
 		"",
@@ -434,7 +444,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/NO_LEARN Change Status",
+		"/spell/MAG/no_learn change status",
 		"<Item>",
 		'Z',
 		"",
@@ -444,7 +454,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/MAG/--",
+		"/spell/MAG/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -454,7 +464,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [Ʈˡ] */
 	{
-		"/Spell/SOR",
+		"/spell/SOR",
 		"<Branch>",
 		'O',
 		"",
@@ -464,7 +474,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [Ʈˡ]  */
 	{
-		"/Spell/SOR/Title Attack",
+		"/spell/SOR/title attack",
 		"<Title>",
 		'\0',
 		"",
@@ -474,7 +484,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/MAGIC_MISSILE",
+		"/spell/SOR/magic_missile",
 		"<Branch>",
 		'\0',
 		"",
@@ -484,7 +494,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/FIRE_BALL",
+		"/spell/SOR/fire_ball",
 		"<Branch>",
 		'\0',
 		"",
@@ -494,7 +504,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/ICE_BLIZZARD",
+		"/spell/SOR/ice_blizzard",
 		"<Branch>",
 		'\0',
 		"",
@@ -504,7 +514,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/MIND_STORM",
+		"/spell/SOR/mind_storm",
 		"<Branch>",
 		'\0',
 		"",
@@ -514,7 +524,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/ACID_RAIN",
+		"/spell/SOR/acid_rain",
 		"<Branch>",
 		'\0',
 		"",
@@ -524,7 +534,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/LIGHTNING_BOLT",
+		"/spell/SOR/lightning_bolt",
 		"<Branch>",
 		'\0',
 		"",
@@ -534,7 +544,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/POISON_CLOUD",
+		"/spell/SOR/poison_cloud",
 		"<Branch>",
 		'\0',
 		"",
@@ -544,7 +554,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/DEATH_SPELL",
+		"/spell/SOR/death_spell",
 		"<Branch>",
 		'\0',
 		"",
@@ -554,7 +564,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/WORD_OF_DESTRUCTION",
+		"/spell/SOR/word_of_destruction",
 		"<Branch>",
 		'\0',
 		"",
@@ -563,7 +573,7 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 	{
-		"/Spell/SOR/NO_LEARN Attack",
+		"/spell/SOR/no_learn attack",
 		"<Item>",
 		'Z',
 		"",
@@ -573,7 +583,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/--",
+		"/spell/SOR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -583,7 +593,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [Ʈˡ] ɸ */
 	{
-		"/Spell/SOR/Title Defense",
+		"/spell/SOR/title defense",
 		"<Title>",
 		'\0',
 		"",
@@ -593,7 +603,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/MAGIC_SHIELD",
+		"/spell/SOR/magic_shield",
 		"<Branch>",
 		'\0',
 		"",
@@ -603,7 +613,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/MAGE_ARMOR",
+		"/spell/SOR/mage_armor",
 		"<Branch>",
 		'\0',
 		"",
@@ -613,7 +623,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/STONESKIN",
+		"/spell/SOR/stoneskin",
 		"<Branch>",
 		'\0',
 		"",
@@ -623,7 +633,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/IRON_BODY",
+		"/spell/SOR/iron_body",
 		"<Branch>",
 		'\0',
 		"",
@@ -633,7 +643,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/SPELL_RESISTANCE",
+		"/spell/SOR/spell_resistance",
 		"<Branch>",
 		'\0',
 		"",
@@ -643,7 +653,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/COUNTER_MAGIC",
+		"/spell/SOR/counter_magic",
 		"<Branch>",
 		'\0',
 		"",
@@ -653,7 +663,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/NO_LEARN Defense",
+		"/spell/SOR/no_learn defense",
 		"<Item>",
 		'Z',
 		"",
@@ -663,7 +673,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/--",
+		"/spell/SOR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -673,7 +683,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [Ʈˡ] ְ۾ */
 	{
-		"/Spell/SOR/Title Weaken Status",
+		"/spell/SOR/title weaken status",
 		"<Title>",
 		'\0',
 		"",
@@ -683,7 +693,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/STONE",
+		"/spell/SOR/stone",
 		"<Branch>",
 		'\0',
 		"",
@@ -693,7 +703,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/PARALYZE",
+		"/spell/SOR/paralyze",
 		"<Branch>",
 		'\0',
 		"",
@@ -703,7 +713,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/POISON",
+		"/spell/SOR/poison",
 		"<Branch>",
 		'\0',
 		"",
@@ -713,7 +723,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/CONFUSION",
+		"/spell/SOR/confusion",
 		"<Branch>",
 		'\0',
 		"",
@@ -723,7 +733,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/BLINDNESS",
+		"/spell/SOR/blindness",
 		"<Branch>",
 		'\0',
 		"",
@@ -733,7 +743,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/SLEEP",
+		"/spell/SOR/sleep",
 		"<Branch>",
 		'\0',
 		"",
@@ -743,7 +753,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/SILENCE",
+		"/spell/SOR/silence",
 		"<Branch>",
 		'\0',
 		"",
@@ -753,7 +763,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/FEAR",
+		"/spell/SOR/fear",
 		"<Branch>",
 		'\0',
 		"",
@@ -763,7 +773,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/HALLUCINATION",
+		"/spell/SOR/hallucination",
 		"<Branch>",
 		'\0',
 		"",
@@ -773,7 +783,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/CHARM",
+		"/spell/SOR/charm",
 		"<Branch>",
 		'\0',
 		"",
@@ -783,7 +793,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/NO_LEARN Weaken Status",
+		"/spell/SOR/no_learn weaken status",
 		"<Item>",
 		'Z',
 		"",
@@ -793,7 +803,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SOR/--",
+		"/spell/SOR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -803,7 +813,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ] */
 	{
-		"/Spell/ENC",
+		"/spell/ENC",
 		"<Branch>",
 		'E',
 		"",
@@ -813,7 +823,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ] ǽͶ */
 	{
-		"/Spell/ENC/Title Strengthen ability",
+		"/spell/ENC/title strengthen ability",
 		"<Title>",
 		'\0',
 		"",
@@ -823,7 +833,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/SHARPNESS",
+		"/spell/ENC/sharpness",
 		"<Branch>",
 		'\0',
 		"",
@@ -833,7 +843,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/STRENGTH",
+		"/spell/ENC/strength",
 		"<Branch>",
 		'\0',
 		"",
@@ -843,7 +853,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/QUICKNESS",
+		"/spell/ENC/quickness",
 		"<Branch>",
 		'\0',
 		"",
@@ -853,7 +863,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/BRAINY",
+		"/spell/ENC/brainy",
 		"<Branch>",
 		'\0',
 		"",
@@ -863,7 +873,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/WISE",
+		"/spell/ENC/wise",
 		"<Branch>",
 		'\0',
 		"",
@@ -873,7 +883,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/ATTRACTIVE",
+		"/spell/ENC/attractive",
 		"<Branch>",
 		'\0',
 		"",
@@ -883,7 +893,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/NO_LEARN Strengthen ability",
+		"/spell/ENC/no_learn strengthen ability",
 		"<Item>",
 		'Z',
 		"",
@@ -893,7 +903,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/--",
+		"/spell/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -903,7 +913,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Spell/ENC/Title Strengthen misc",
+		"/spell/ENC/title strengthen misc",
 		"<Title>",
 		'\0',
 		"",
@@ -913,7 +923,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/POWER_UP_HP",
+		"/spell/ENC/power_up_hp",
 		"<Branch>",
 		'\0',
 		"",
@@ -923,7 +933,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/HASTE",
+		"/spell/ENC/haste",
 		"<Branch>",
 		'\0',
 		"",
@@ -933,7 +943,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/NO_LEARN Strengthen misc",
+		"/spell/ENC/no_learn strengthen misc",
 		"<Item>",
 		'Z',
 		"",
@@ -943,7 +953,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/--",
+		"/spell/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -953,7 +963,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ] ǽͼ */
 	{
-		"/Spell/ENC/Title Weaken ability",
+		"/spell/ENC/title weaken ability",
 		"<Title>",
 		'\0',
 		"",
@@ -963,7 +973,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/DULLNESS",
+		"/spell/ENC/dullness",
 		"<Branch>",
 		'\0',
 		"",
@@ -973,7 +983,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/WEAKNESS",
+		"/spell/ENC/weakness",
 		"<Branch>",
 		'\0',
 		"",
@@ -983,7 +993,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/SLOWNESS",
+		"/spell/ENC/slowness",
 		"<Branch>",
 		'\0',
 		"",
@@ -993,7 +1003,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/BRAINLESS",
+		"/spell/ENC/brainless",
 		"<Branch>",
 		'\0',
 		"",
@@ -1003,7 +1013,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/FOOLISH",
+		"/spell/ENC/foolish",
 		"<Branch>",
 		'\0',
 		"",
@@ -1013,7 +1023,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/UNATTRACTIVE",
+		"/spell/ENC/unattractive",
 		"<Branch>",
 		'\0',
 		"",
@@ -1023,7 +1033,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/NO_LEARN Weaken ability",
+		"/spell/ENC/no_learn weaken ability",
 		"<Item>",
 		'Z',
 		"",
@@ -1033,7 +1043,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/--",
+		"/spell/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1043,7 +1053,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Spell/ENC/Title Weaken misc",
+		"/spell/ENC/title weaken misc",
 		"<Title>",
 		'\0',
 		"",
@@ -1053,7 +1063,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/ENERGY_DRAIN",
+		"/spell/ENC/energy_drain",
 		"<Branch>",
 		'\0',
 		"",
@@ -1063,7 +1073,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/SLOW",
+		"/spell/ENC/slow",
 		"<Branch>",
 		'\0',
 		"",
@@ -1073,7 +1083,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/HUNGER",
+		"/spell/ENC/hunger",
 		"<Branch>",
 		'\0',
 		"",
@@ -1083,7 +1093,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/CANCELLATION",
+		"/spell/ENC/cancellation",
 		"<Branch>",
 		'\0',
 		"",
@@ -1093,7 +1103,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/NO_LEARN Weaken misc",
+		"/spell/ENC/no_learn weaken misc",
 		"<Item>",
 		'Z',
 		"",
@@ -1103,7 +1113,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/ENC/--",
+		"/spell/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1113,7 +1123,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ] */
 	{
-		"/Spell/SUM",
+		"/spell/SUM",
 		"<Branch>",
 		'U',
 		"",
@@ -1123,7 +1133,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Spell/SUM/Title Summon",
+		"/spell/SUM/title summon",
 		"<Title>",
 		'\0',
 		"",
@@ -1133,7 +1143,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/SKELETON_WARRIOR",
+		"/spell/SUM/skeleton_warrior",
 		"<Branch>",
 		'\0',
 		"",
@@ -1143,7 +1153,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/SUMMON_UNICORN",
+		"/spell/SUM/summon_unicorn",
 		"<Branch>",
 		'\0',
 		"",
@@ -1153,7 +1163,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/SUMMON_EFREET",
+		"/spell/SUM/summon_efreet",
 		"<Branch>",
 		'\0',
 		"",
@@ -1163,7 +1173,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/SUMMON_DJINNI",
+		"/spell/SUM/summon_djinni",
 		"<Branch>",
 		'\0',
 		"",
@@ -1173,7 +1183,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/SUMMON_PHOENIX",
+		"/spell/SUM/summon_phoenix",
 		"<Branch>",
 		'\0',
 		"",
@@ -1183,7 +1193,17 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/CREATE_UNDEAD",
+		"/spell/SUM/summon_bone",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_BONE, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_BONE,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SUM/create_undead",
 		"<Branch>",
 		'\0',
 		"",
@@ -1193,7 +1213,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/DISMISSAL",
+		"/spell/SUM/dismissal",
 		"<Branch>",
 		'\0',
 		"",
@@ -1203,7 +1223,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/NO_LEARN Summon",
+		"/spell/SUM/no_learn summon",
 		"<Item>",
 		'Z',
 		"",
@@ -1213,7 +1233,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SUM/--",
+		"/spell/SUM/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1223,7 +1243,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ηʸ] */
 	{
-		"/Spell/PRI",
+		"/spell/PRI",
 		"<Branch>",
 		'P',
 		"",
@@ -1233,7 +1253,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ηʸ]  */
 	{
-		"/Spell/PRI/Title Cure",
+		"/spell/PRI/title cure",
 		"<Title>",
 		'\0',
 		"",
@@ -1243,7 +1263,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_HP_LIGHT",
+		"/spell/PRI/cure_hp_light",
 		"<Branch>",
 		'\0',
 		"",
@@ -1253,7 +1273,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_HP_MODERATE",
+		"/spell/PRI/cure_hp_moderate",
 		"<Branch>",
 		'\0',
 		"",
@@ -1263,7 +1283,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_HP_SERIOUS",
+		"/spell/PRI/cure_hp_serious",
 		"<Branch>",
 		'\0',
 		"",
@@ -1273,7 +1293,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_HP_MAX",
+		"/spell/PRI/cure_hp_max",
 		"<Branch>",
 		'\0',
 		"",
@@ -1283,7 +1303,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_MP",
+		"/spell/PRI/cure_mp",
 		"<Branch>",
 		'\0',
 		"",
@@ -1293,7 +1313,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/TRANSFER_MP",
+		"/spell/PRI/transfer_mp",
 		"<Branch>",
 		'\0',
 		"",
@@ -1303,7 +1323,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/REGENERATION",
+		"/spell/PRI/regeneration",
 		"<Branch>",
 		'\0',
 		"",
@@ -1313,7 +1333,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESTORE_EXPERIENCE",
+		"/spell/PRI/restore_experience",
 		"<Branch>",
 		'\0',
 		"",
@@ -1323,7 +1343,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESURRECTION",
+		"/spell/PRI/resurrection",
 		"<Branch>",
 		'\0',
 		"",
@@ -1333,7 +1353,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/HEAL",
+		"/spell/PRI/heal",
 		"<Branch>",
 		'\0',
 		"",
@@ -1343,7 +1363,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/NO_LEARN Cure",
+		"/spell/PRI/no_learn cure",
 		"<Item>",
 		'Z',
 		"",
@@ -1353,7 +1373,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/--",
+		"/spell/PRI/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1363,7 +1383,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ηʸ] ֲ */
 	{
-		"/Spell/PRI/Title Cure Status",
+		"/spell/PRI/title cure status",
 		"<Title>",
 		'\0',
 		"",
@@ -1373,7 +1393,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_STATUS",
+		"/spell/PRI/cure_status",
 		"<Branch>",
 		'\0',
 		"",
@@ -1383,7 +1403,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_STONE",
+		"/spell/PRI/cure_stone",
 		"<Branch>",
 		'\0',
 		"",
@@ -1393,7 +1413,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_PARALYZE",
+		"/spell/PRI/cure_paralyze",
 		"<Branch>",
 		'\0',
 		"",
@@ -1403,7 +1423,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_BLINDNESS",
+		"/spell/PRI/cure_blindness",
 		"<Branch>",
 		'\0',
 		"",
@@ -1413,7 +1433,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_POISON",
+		"/spell/PRI/cure_poison",
 		"<Branch>",
 		'\0',
 		"",
@@ -1423,7 +1443,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_CONFUSION",
+		"/spell/PRI/cure_confusion",
 		"<Branch>",
 		'\0',
 		"",
@@ -1433,7 +1453,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_SILENCE",
+		"/spell/PRI/cure_silence",
 		"<Branch>",
 		'\0',
 		"",
@@ -1443,7 +1463,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_SLEEP",
+		"/spell/PRI/cure_sleep",
 		"<Branch>",
 		'\0',
 		"",
@@ -1453,7 +1473,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_FEAR",
+		"/spell/PRI/cure_fear",
 		"<Branch>",
 		'\0',
 		"",
@@ -1463,7 +1483,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/CURE_CHARM",
+		"/spell/PRI/cure_charm",
 		"<Branch>",
 		'\0',
 		"",
@@ -1473,7 +1493,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/NO_LEARN Cure Status",
+		"/spell/PRI/no_learn cure status",
 		"<Item>",
 		'Z',
 		"",
@@ -1483,7 +1503,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/--",
+		"/spell/PRI/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1493,7 +1513,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ηʸ]  */
 	{
-		"/Spell/PRI/Title Resist",
+		"/spell/PRI/title resist",
 		"<Title>",
 		'\0',
 		"",
@@ -1503,7 +1523,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/PROTECTION",
+		"/spell/PRI/protection",
 		"<Branch>",
 		'\0',
 		"",
@@ -1513,7 +1533,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESIST_PHYSICAL",
+		"/spell/PRI/resist_physical",
 		"<Branch>",
 		'\0',
 		"",
@@ -1523,7 +1543,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESIST_HEAT",
+		"/spell/PRI/resist_heat",
 		"<Branch>",
 		'\0',
 		"",
@@ -1533,7 +1553,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESIST_COLD",
+		"/spell/PRI/resist_cold",
 		"<Branch>",
 		'\0',
 		"",
@@ -1543,7 +1563,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESIST_MIND",
+		"/spell/PRI/resist_mind",
 		"<Branch>",
 		'\0',
 		"",
@@ -1553,7 +1573,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESIST_ACID",
+		"/spell/PRI/resist_acid",
 		"<Branch>",
 		'\0',
 		"",
@@ -1563,7 +1583,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESIST_ELECTRICITY",
+		"/spell/PRI/resist_electricity",
 		"<Branch>",
 		'\0',
 		"",
@@ -1573,7 +1593,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/RESIST_POISON",
+		"/spell/PRI/resist_poison",
 		"<Branch>",
 		'\0',
 		"",
@@ -1583,7 +1603,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/NO_LEARN Resist",
+		"/spell/PRI/no_learn resist",
 		"<Item>",
 		'Z',
 		"",
@@ -1593,7 +1613,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/--",
+		"/spell/PRI/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1603,7 +1623,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [ηʸ]  */
 	{
-		"/Spell/PRI/Title Holy",
+		"/spell/PRI/title holy",
 		"<Title>",
 		'\0',
 		"",
@@ -1613,7 +1633,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/BLESS",
+		"/spell/PRI/bless",
 		"<Branch>",
 		'\0',
 		"",
@@ -1623,7 +1643,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/REMOVE_CURSE",
+		"/spell/PRI/remove_curse",
 		"<Branch>",
 		'\0',
 		"",
@@ -1633,7 +1653,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/DISPEL_UNDEAD",
+		"/spell/PRI/dispel_undead",
 		"<Branch>",
 		'\0',
 		"",
@@ -1643,7 +1663,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/ESCAPE",
+		"/spell/PRI/escape",
 		"<Branch>",
 		'\0',
 		"",
@@ -1653,7 +1673,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/SANCTUARY",
+		"/spell/PRI/sanctuary",
 		"<Branch>",
 		'\0',
 		"",
@@ -1663,7 +1683,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/WISH",
+		"/spell/PRI/wish",
 		"<Branch>",
 		'\0',
 		"",
@@ -1673,7 +1693,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/NO_LEARN Holy",
+		"/spell/PRI/no_learn holy",
 		"<Item>",
 		'Z',
 		"",
@@ -1683,7 +1703,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/PRI/--",
+		"/spell/PRI/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1693,7 +1713,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* []  */
 	{
-		"/Spell/SHA",
+		"/spell/SHA",
 		"<Branch>",
 		'H',
 		"",
@@ -1703,7 +1723,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* []  */
 	{
-		"/Spell/SHA/Title Weak Elemental",
+		"/spell/SHA/title weak elemental",
 		"<Title>",
 		'\0',
 		"",
@@ -1713,7 +1733,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/WEAK_FIRE_ELEMENTAL",
+		"/spell/SHA/weak_fire_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1723,7 +1743,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/WEAK_WATER_ELEMENTAL",
+		"/spell/SHA/weak_water_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1733,7 +1753,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/WEAK_AIR_ELEMENTAL",
+		"/spell/SHA/weak_air_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1743,7 +1763,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/WEAK_EARTH_ELEMENTAL",
+		"/spell/SHA/weak_earth_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1753,7 +1773,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/WEAK_LIGHT_ELEMENTAL",
+		"/spell/SHA/weak_light_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1763,7 +1783,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/WEAK_DARK_ELEMENTAL",
+		"/spell/SHA/weak_dark_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1773,7 +1793,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/NO_LEARN Weak Elemental",
+		"/spell/SHA/no_learn weak elemental",
 		"<Item>",
 		'Z',
 		"",
@@ -1783,7 +1803,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/--",
+		"/spell/SHA/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1793,7 +1813,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* []  */
 	{
-		"/Spell/SHA/Title Summon Elemental",
+		"/spell/SHA/title summon elemental",
 		"<Title>",
 		'\0',
 		"",
@@ -1803,7 +1823,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_FIRE_ELEMENTAL",
+		"/spell/SHA/summon_fire_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1813,7 +1833,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_SALAMANDER",
+		"/spell/SHA/summon_salamander",
 		"<Branch>",
 		'\0',
 		"",
@@ -1823,7 +1843,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_WATER_ELEMENTAL",
+		"/spell/SHA/summon_water_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1833,7 +1853,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_UNDINE",
+		"/spell/SHA/summon_undine",
 		"<Branch>",
 		'\0',
 		"",
@@ -1843,7 +1863,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_AIR_ELEMENTAL",
+		"/spell/SHA/summon_air_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1853,7 +1873,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_SYLPH",
+		"/spell/SHA/summon_sylph",
 		"<Branch>",
 		'\0',
 		"",
@@ -1863,7 +1883,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_EARTH_ELEMENTAL",
+		"/spell/SHA/summon_earth_elemental",
 		"<Branch>",
 		'\0',
 		"",
@@ -1873,7 +1893,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_GNOME",
+		"/spell/SHA/summon_gnome",
 		"<Branch>",
 		'\0',
 		"",
@@ -1883,7 +1903,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_WILL_O_WISP",
+		"/spell/SHA/summon_will_o_wisp",
 		"<Branch>",
 		'\0',
 		"",
@@ -1893,7 +1913,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/SUMMON_SHADE",
+		"/spell/SHA/summon_shade",
 		"<Branch>",
 		'\0',
 		"",
@@ -1903,7 +1923,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/NO_LEARN SUMMON ELEMENTAL",
+		"/spell/SHA/no_learn summon elemental",
 		"<Item>",
 		'Z',
 		"",
@@ -1913,7 +1933,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/SHA/--",
+		"/spell/SHA/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1923,9 +1943,9 @@ menu_t	ls_menu_spell[] = {
 	},
 /* []  */
 	{
-		"/Spell/BAR",
+		"/spell/BAR",
 		"<Branch>",
-		'H',
+		'B',
 		"",
 		N_MSG_BAR, "",
 		cb_menu_dflt_spell_bar, NULL,
@@ -1933,7 +1953,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* []  */
 	{
-		"/Spell/BAR/Title Cure",
+		"/spell/BAR/title cure",
 		"<Title>",
 		'\0',
 		"",
@@ -1943,7 +1963,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_CURE_HP",
+		"/spell/BAR/song_cure_hp",
 		"<Branch>",
 		'\0',
 		"",
@@ -1953,7 +1973,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_CURE_MP",
+		"/spell/BAR/song_cure_mp",
 		"<Branch>",
 		'\0',
 		"",
@@ -1963,7 +1983,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/NO_LEARN Cure",
+		"/spell/BAR/no_learn cure",
 		"<Item>",
 		'Z',
 		"",
@@ -1973,7 +1993,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/--",
+		"/spell/BAR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1983,7 +2003,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [] ǽͶ */
 	{
-		"/Spell/BAR/Title Strengthen ability",
+		"/spell/BAR/title strengthen ability",
 		"<Title>",
 		'\0',
 		"",
@@ -1993,7 +2013,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_SHARPNESS",
+		"/spell/BAR/song_sharpness",
 		"<Branch>",
 		'\0',
 		"",
@@ -2003,7 +2023,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_STRENGTH",
+		"/spell/BAR/song_strength",
 		"<Branch>",
 		'\0',
 		"",
@@ -2013,7 +2033,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_QUICKNESS",
+		"/spell/BAR/song_quickness",
 		"<Branch>",
 		'\0',
 		"",
@@ -2023,7 +2043,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_BRAINY",
+		"/spell/BAR/song_brainy",
 		"<Branch>",
 		'\0',
 		"",
@@ -2033,7 +2053,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_WISE",
+		"/spell/BAR/song_wise",
 		"<Branch>",
 		'\0',
 		"",
@@ -2043,7 +2063,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_ATTRACTIVE",
+		"/spell/BAR/song_attractive",
 		"<Branch>",
 		'\0',
 		"",
@@ -2053,7 +2073,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/NO_LEARN Strengthen ability",
+		"/spell/BAR/no_learn strengthen ability",
 		"<Item>",
 		'Z',
 		"",
@@ -2063,7 +2083,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/--",
+		"/spell/BAR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -2073,7 +2093,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [] ǽͼ */
 	{
-		"/Spell/BAR/Title Weaken ability",
+		"/spell/BAR/title weaken ability",
 		"<Title>",
 		'\0',
 		"",
@@ -2083,7 +2103,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_DULLNESS",
+		"/spell/BAR/song_dullness",
 		"<Branch>",
 		'\0',
 		"",
@@ -2093,7 +2113,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_WEAKNESS",
+		"/spell/BAR/song_weakness",
 		"<Branch>",
 		'\0',
 		"",
@@ -2103,7 +2123,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_SLOWNESS",
+		"/spell/BAR/song_slowness",
 		"<Branch>",
 		'\0',
 		"",
@@ -2113,7 +2133,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_BRAINLESS",
+		"/spell/BAR/song_brainless",
 		"<Branch>",
 		'\0',
 		"",
@@ -2123,7 +2143,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_FOOLISH",
+		"/spell/BAR/song_foolish",
 		"<Branch>",
 		'\0',
 		"",
@@ -2133,7 +2153,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_UNATTRACTIVE",
+		"/spell/BAR/song_unattractive",
 		"<Branch>",
 		'\0',
 		"",
@@ -2143,7 +2163,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/NO_LEARN Weaken ability",
+		"/spell/BAR/no_learn weaken ability",
 		"<Item>",
 		'Z',
 		"",
@@ -2153,7 +2173,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/--",
+		"/spell/BAR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -2163,7 +2183,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* []  */
 	{
-		"/Spell/BAR/Title Resist Status",
+		"/spell/BAR/title resist status",
 		"<Title>",
 		'\0',
 		"",
@@ -2173,7 +2193,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_STONE",
+		"/spell/BAR/song_resi_stat_stone",
 		"<Branch>",
 		'\0',
 		"",
@@ -2183,7 +2203,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_PARALYZE",
+		"/spell/BAR/song_resi_stat_paralyze",
 		"<Branch>",
 		'\0',
 		"",
@@ -2193,7 +2213,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_POISON",
+		"/spell/BAR/song_resi_stat_poison",
 		"<Branch>",
 		'\0',
 		"",
@@ -2203,7 +2223,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_CONFUSION",
+		"/spell/BAR/song_resi_stat_confusion",
 		"<Branch>",
 		'\0',
 		"",
@@ -2213,7 +2233,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_BLIND",
+		"/spell/BAR/song_resi_stat_blind",
 		"<Branch>",
 		'\0',
 		"",
@@ -2223,7 +2243,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_SLEEP",
+		"/spell/BAR/song_resi_stat_sleep",
 		"<Branch>",
 		'\0',
 		"",
@@ -2233,7 +2253,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_SILENCE",
+		"/spell/BAR/song_resi_stat_silence",
 		"<Branch>",
 		'\0',
 		"",
@@ -2243,7 +2263,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_FEAR",
+		"/spell/BAR/song_resi_stat_fear",
 		"<Branch>",
 		'\0',
 		"",
@@ -2253,7 +2273,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_HALLUCINATION",
+		"/spell/BAR/song_resi_stat_hallucination",
 		"<Branch>",
 		'\0',
 		"",
@@ -2263,7 +2283,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_CHARM",
+		"/spell/BAR/song_resi_stat_charm",
 		"<Branch>",
 		'\0',
 		"",
@@ -2273,7 +2293,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/SONG_RESI_STAT_DRUNK",
+		"/spell/BAR/song_resi_stat_drunk",
 		"<Branch>",
 		'\0',
 		"",
@@ -2283,7 +2303,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/NO_LEARN Resist Status",
+		"/spell/BAR/no_learn resist status",
 		"<Item>",
 		'Z',
 		"",
@@ -2293,7 +2313,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/BAR/--",
+		"/spell/BAR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -2303,7 +2323,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [Ǧ] */
 	{
-		"/Spell/NIN",
+		"/spell/NIN",
 		"<Branch>",
 		'N',
 		"",
@@ -2313,7 +2333,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [Ǧ] ŷϰ */
 	{
-		"/Spell/NIN/Title Disaster",
+		"/spell/NIN/title disaster",
 		"<Title>",
 		'\0',
 		"",
@@ -2323,7 +2343,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/TYPHOON",
+		"/spell/NIN/typhoon",
 		"<Branch>",
 		'\0',
 		"",
@@ -2333,7 +2353,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/CONFLAGRATION",
+		"/spell/NIN/conflagration",
 		"<Branch>",
 		'\0',
 		"",
@@ -2343,7 +2363,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/EARTHQUAKE",
+		"/spell/NIN/earthquake",
 		"<Branch>",
 		'\0',
 		"",
@@ -2353,7 +2373,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/THUNDERCLOUD",
+		"/spell/NIN/thundercloud",
 		"<Branch>",
 		'\0',
 		"",
@@ -2363,7 +2383,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/INUNDATION",
+		"/spell/NIN/inundation",
 		"<Branch>",
 		'\0',
 		"",
@@ -2373,7 +2393,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/NO_LEARN Disaster",
+		"/spell/NIN/no_learn disaster",
 		"<Item>",
 		'Z',
 		"",
@@ -2383,7 +2403,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/--",
+		"/spell/NIN/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -2393,7 +2413,7 @@ menu_t	ls_menu_spell[] = {
 	},
 /* [Ǧ] ν */
 	{
-		"/Spell/NIN/Title Misc",
+		"/spell/NIN/title misc",
 		"<Title>",
 		'\0',
 		"",
@@ -2403,7 +2423,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/SUBSTITUTE",
+		"/spell/NIN/substitute",
 		"<Branch>",
 		'\0',
 		"",
@@ -2413,7 +2433,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/BURNING_HANDS",
+		"/spell/NIN/burning_hands",
 		"<Branch>",
 		'\0',
 		"",
@@ -2423,7 +2443,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/MIND_READING",
+		"/spell/NIN/mind_reading",
 		"<Branch>",
 		'\0',
 		"",
@@ -2433,7 +2453,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/NO_LEARN Misc",
+		"/spell/NIN/no_learn misc",
 		"<Item>",
 		'Z',
 		"",
@@ -2443,7 +2463,7 @@ menu_t	ls_menu_spell[] = {
 	},
 
 	{
-		"/Spell/NIN/--",
+		"/spell/NIN/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -2465,7 +2485,7 @@ menu_t	ls_menu_spell[] = {
 
 menu_t	ls_menu_spell_extent[] = {
 	{
-		"/Spell Extent",
+		"/spell extent",
 		"<Branch>",
 		'\0',
 		"",
@@ -2474,7 +2494,7 @@ menu_t	ls_menu_spell_extent[] = {
 		FLG_NULL,
 	},
 	{
-		"/Spell Extent/Normal",
+		"/spell extent/normal",
 		"<Item>",
 		'N',
 		"",
@@ -2483,7 +2503,7 @@ menu_t	ls_menu_spell_extent[] = {
 		FLG_NULL,
 	},
 	{
-		"/Spell Extent/Spread",
+		"/spell extent/spread",
 		"<Item>",
 		'S',
 		"",
@@ -2492,7 +2512,7 @@ menu_t	ls_menu_spell_extent[] = {
 		FLG_NULL,
 	},
 	{
-		"/Spell Extent/Mass",
+		"/spell extent/mass",
 		"<Item>",
 		'M',
 		"",
@@ -2501,7 +2521,7 @@ menu_t	ls_menu_spell_extent[] = {
 		FLG_NULL,
 	},
 	{
-		"/Spell Extent/Limit",
+		"/spell extent/limit",
 		"<Item>",
 		'H',
 		"",
@@ -2510,7 +2530,7 @@ menu_t	ls_menu_spell_extent[] = {
 		FLG_NULL,
 	},
 	{
-		"/Spell Extent/Half",
+		"/spell extent/half",
 		"<Item>",
 		'H',
 		"",
