@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.5 2004/12/07 12:44:22 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.13 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -46,7 +46,7 @@ menu_t	ls_menu_shop[LS_MENU_SHOP_MAX_N + 1];
 
 menu_t	ls_menu_temple[] = {
 	{
-		"/Temple",
+		"/temple",
 		"<Branch>",
 		'\0',
 		"",
@@ -55,7 +55,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Title",
+		"/temple/title",
 		"<Title>",
 		'\0',
 		"",
@@ -64,7 +64,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Remove curse",
+		"/temple/remove curse",
 		"<Item>",
 		'C',
 		"",
@@ -73,7 +73,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Cure status",
+		"/temple/cure status",
 		"<Item>",
 		'S',
 		"",
@@ -82,7 +82,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Resurrection",
+		"/temple/resurrection",
 		"<Item>",
 		'R',
 		"",
@@ -91,7 +91,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Contribution",
+		"/temple/contribution",
 		"<Item>",
 		'O',
 		"",
@@ -100,7 +100,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Data",
+		"/temple/data",
 		"<Item>",
 		'D',
 		"",
@@ -109,7 +109,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Collect gold",
+		"/temple/collect gold",
 		"<Item>",
 		'L',
 		"",
@@ -118,7 +118,7 @@ menu_t	ls_menu_temple[] = {
 		FLG_NULL,
 	},
 	{
-		"/Temple/Divide gold",
+		"/temple/divide gold",
 		"<Item>",
 		'V',
 		"",
@@ -126,6 +126,15 @@ menu_t	ls_menu_temple[] = {
 		cb_menu_shop_divide_gold, NULL,
 		FLG_NULL,
 	},
+	{
+		"/temple/give gold",
+		"<Item>",
+		'G',
+		"",
+		N_MSG_MENU_SHOP_GIVE_GOLD, "",
+		cb_menu_shop_give_gold, NULL,
+		FLG_NULL,
+	},
 	{
 		"",
 		"",
@@ -139,7 +148,7 @@ menu_t	ls_menu_temple[] = {
 
 menu_t	ls_menu_magic_guild[] = {
 	{
-		"/Magic Guild",
+		"/magic guild",
 		"<Branch>",
 		'\0',
 		"",
@@ -149,7 +158,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* ȥ */
 	{
-		"/Magic Guild/Title",
+		"/magic guild/title",
 		"<Title>",
 		'\0',
 		"",
@@ -159,7 +168,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] */
 	{
-		"/Magic Guild/MAG",
+		"/magic guild/MAG",
 		"<Branch>",
 		'M',
 		"",
@@ -169,7 +178,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] ¾ */
 	{
-		"/Magic Guild/MAG/Title Misc",
+		"/magic guild/MAG/title misc",
 		"<Title>",
 		'\0',
 		"",
@@ -179,7 +188,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/LIGHT",
+		"/magic guild/MAG/light",
 		"<Branch>",
 		'\0',
 		"",
@@ -189,7 +198,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DARKNESS",
+		"/magic guild/MAG/darkness",
 		"<Branch>",
 		'\0',
 		"",
@@ -199,7 +208,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/TELEPORT_PARTY",
+		"/magic guild/MAG/teleport_party",
 		"<Branch>",
 		'\0',
 		"",
@@ -209,7 +218,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/TELEPORT",
+		"/magic guild/MAG/teleport",
 		"<Branch>",
 		'\0',
 		"",
@@ -219,7 +228,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/RECALL",
+		"/magic guild/MAG/recall",
 		"<Branch>",
 		'\0',
 		"",
@@ -229,7 +238,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/KNOCK",
+		"/magic guild/MAG/knock",
 		"<Branch>",
 		'\0',
 		"",
@@ -239,7 +248,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/LOCK",
+		"/magic guild/MAG/lock",
 		"<Branch>",
 		'\0',
 		"",
@@ -249,7 +258,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DISARM_TRAP",
+		"/magic guild/MAG/disarm_trap",
 		"<Branch>",
 		'\0',
 		"",
@@ -259,7 +268,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DISPEL_MAGIC",
+		"/magic guild/MAG/dispel_magic",
 		"<Branch>",
 		'\0',
 		"",
@@ -269,7 +278,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/MIRROR_IMAGE",
+		"/magic guild/MAG/mirror_image",
 		"<Branch>",
 		'\0',
 		"",
@@ -279,7 +288,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/ANIMATE_OBJECTS",
+		"/magic guild/MAG/animate_objects",
 		"<Branch>",
 		'\0',
 		"",
@@ -289,7 +298,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/SHELTER",
+		"/magic guild/MAG/shelter",
 		"<Branch>",
 		'\0',
 		"",
@@ -299,7 +308,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/CREATE_FOOD",
+		"/magic guild/MAG/create_food",
 		"<Branch>",
 		'\0',
 		"",
@@ -309,7 +318,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/NO_LEARN Misc",
+		"/magic guild/MAG/no_learn misc",
 		"<Item>",
 		'Z',
 		"",
@@ -319,7 +328,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/--",
+		"/magic guild/MAG/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -329,7 +338,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] õ */
 	{
-		"/Magic Guild/MAG/Title Detect",
+		"/magic guild/MAG/title detect",
 		"<Title>",
 		'\0',
 		"",
@@ -339,7 +348,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/IDENTIFY_ITEM",
+		"/magic guild/MAG/identify_item",
 		"<Branch>",
 		'\0',
 		"",
@@ -349,7 +358,17 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/SEARCHING",
+		"/magic guild/MAG/identify_all_item",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_IDENTIFY_ALL_ITEM, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_IDENTIFY_ALL_ITEM,
+		FLG_NULL,
+	},
+
+	{
+		"/magic guild/MAG/searching",
 		"<Branch>",
 		'\0',
 		"",
@@ -359,7 +378,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/ANALYZE_DWEOMER",
+		"/magic guild/MAG/analyze_dweomer",
 		"<Branch>",
 		'\0',
 		"",
@@ -369,7 +388,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DETECT_MAGIC",
+		"/magic guild/MAG/detect_magic",
 		"<Branch>",
 		'\0',
 		"",
@@ -379,7 +398,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DETECT_ITEM",
+		"/magic guild/MAG/detect_item",
 		"<Branch>",
 		'\0',
 		"",
@@ -389,7 +408,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DETECT_DOORS",
+		"/magic guild/MAG/detect_doors",
 		"<Branch>",
 		'\0',
 		"",
@@ -399,7 +418,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DETECT_TRAPS",
+		"/magic guild/MAG/detect_traps",
 		"<Branch>",
 		'\0',
 		"",
@@ -409,7 +428,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DETECT_MONSTER",
+		"/magic guild/MAG/detect_monster",
 		"<Branch>",
 		'\0',
 		"",
@@ -419,7 +438,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/SENSE_INVISIBLE",
+		"/magic guild/MAG/sense_invisible",
 		"<Branch>",
 		'\0',
 		"",
@@ -429,7 +448,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/NO_LEARN Detect",
+		"/magic guild/MAG/no_learn detect",
 		"<Item>",
 		'Z',
 		"",
@@ -439,7 +458,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/--",
+		"/magic guild/MAG/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -449,7 +468,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] ƥѲ */
 	{
-		"/Magic Guild/MAG/Title Change status",
+		"/magic guild/MAG/title change status",
 		"<Title>",
 		'\0',
 		"",
@@ -459,7 +478,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/FLY",
+		"/magic guild/MAG/fly",
 		"<Branch>",
 		'\0',
 		"",
@@ -469,7 +488,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/FEATHER_FALL",
+		"/magic guild/MAG/feather_fall",
 		"<Branch>",
 		'\0',
 		"",
@@ -479,7 +498,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/VANISH",
+		"/magic guild/MAG/vanish",
 		"<Branch>",
 		'\0',
 		"",
@@ -489,7 +508,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/DARKVISION",
+		"/magic guild/MAG/darkvision",
 		"<Branch>",
 		'\0',
 		"",
@@ -499,7 +518,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/PASSWALL",
+		"/magic guild/MAG/passwall",
 		"<Branch>",
 		'\0',
 		"",
@@ -509,7 +528,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] üե饰Ѳ */
 	{
-		"/Magic Guild/MAG/POLYMORPH_OTHER",
+		"/magic guild/MAG/polymorph_other",
 		"<Branch>",
 		'\0',
 		"",
@@ -519,7 +538,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/POLYMORPH_SELF",
+		"/magic guild/MAG/polymorph_self",
 		"<Branch>",
 		'\0',
 		"",
@@ -529,7 +548,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/STEALTH",
+		"/magic guild/MAG/stealth",
 		"<Branch>",
 		'\0',
 		"",
@@ -539,7 +558,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/NO_LEARN Change status",
+		"/magic guild/MAG/no_learn change status",
 		"<Item>",
 		'Z',
 		"",
@@ -549,7 +568,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/MAG/--",
+		"/magic guild/MAG/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -559,7 +578,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [Ʈˡ] */
 	{
-		"/Magic Guild/SOR",
+		"/magic guild/SOR",
 		"<Branch>",
 		'O',
 		"",
@@ -569,7 +588,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [Ʈˡ]  */
 	{
-		"/Magic Guild/SOR/Title Attack",
+		"/magic guild/SOR/title attack",
 		"<Title>",
 		'\0',
 		"",
@@ -579,7 +598,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/MAGIC_MISSILE",
+		"/magic guild/SOR/magic_missile",
 		"<Branch>",
 		'\0',
 		"",
@@ -589,7 +608,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/FIRE_BALL",
+		"/magic guild/SOR/fire_ball",
 		"<Branch>",
 		'\0',
 		"",
@@ -599,7 +618,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/ICE_BLIZZARD",
+		"/magic guild/SOR/ice_blizzard",
 		"<Branch>",
 		'\0',
 		"",
@@ -609,7 +628,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/MIND_STORM",
+		"/magic guild/SOR/mind_storm",
 		"<Branch>",
 		'\0',
 		"",
@@ -619,7 +638,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/ACID_RAIN",
+		"/magic guild/SOR/acid_rain",
 		"<Branch>",
 		'\0',
 		"",
@@ -629,7 +648,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/LIGHTNING_BOLT",
+		"/magic guild/SOR/lightning_bolt",
 		"<Branch>",
 		'\0',
 		"",
@@ -639,7 +658,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/POISON_CLOUD",
+		"/magic guild/SOR/poison_cloud",
 		"<Branch>",
 		'\0',
 		"",
@@ -649,7 +668,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/DEATH_SPELL",
+		"/magic guild/SOR/death_spell",
 		"<Branch>",
 		'\0',
 		"",
@@ -659,7 +678,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/NO_LEARN Attack",
+		"/magic guild/SOR/no_learn attack",
 		"<Item>",
 		'Z',
 		"",
@@ -669,7 +688,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/--",
+		"/magic guild/SOR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -679,7 +698,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [Ʈˡ] ɸ */
 	{
-		"/Magic Guild/SOR/Title Defense",
+		"/magic guild/SOR/title defense",
 		"<Title>",
 		'\0',
 		"",
@@ -689,7 +708,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/MAGIC_SHIELD",
+		"/magic guild/SOR/magic_shield",
 		"<Branch>",
 		'\0',
 		"",
@@ -699,7 +718,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/MAGE_ARMOR",
+		"/magic guild/SOR/mage_armor",
 		"<Branch>",
 		'\0',
 		"",
@@ -709,7 +728,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/STONESKIN",
+		"/magic guild/SOR/stoneskin",
 		"<Branch>",
 		'\0',
 		"",
@@ -719,7 +738,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/IRON_BODY",
+		"/magic guild/SOR/iron_body",
 		"<Branch>",
 		'\0',
 		"",
@@ -729,7 +748,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/SPELL_RESISTANCE",
+		"/magic guild/SOR/spell_resistance",
 		"<Branch>",
 		'\0',
 		"",
@@ -739,7 +758,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/COUNTER_MAGIC",
+		"/magic guild/SOR/counter_magic",
 		"<Branch>",
 		'\0',
 		"",
@@ -749,7 +768,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/NO_LEARN Defense",
+		"/magic guild/SOR/no_learn defense",
 		"<Item>",
 		'Z',
 		"",
@@ -759,7 +778,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/--",
+		"/magic guild/SOR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -769,7 +788,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [Ʈˡ] ơ۾ */
 	{
-		"/Magic Guild/SOR/Title Weaken status",
+		"/magic guild/SOR/title weaken status",
 		"<Title>",
 		'\0',
 		"",
@@ -779,7 +798,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/STONE",
+		"/magic guild/SOR/stone",
 		"<Branch>",
 		'\0',
 		"",
@@ -789,7 +808,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/PARALYZE",
+		"/magic guild/SOR/paralyze",
 		"<Branch>",
 		'\0',
 		"",
@@ -799,7 +818,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/POISON",
+		"/magic guild/SOR/poison",
 		"<Branch>",
 		'\0',
 		"",
@@ -809,7 +828,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/CONFUSION",
+		"/magic guild/SOR/confusion",
 		"<Branch>",
 		'\0',
 		"",
@@ -819,7 +838,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/BLINDNESS",
+		"/magic guild/SOR/blindness",
 		"<Branch>",
 		'\0',
 		"",
@@ -829,7 +848,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/SLEEP",
+		"/magic guild/SOR/sleep",
 		"<Branch>",
 		'\0',
 		"",
@@ -839,7 +858,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/SILENCE",
+		"/magic guild/SOR/silence",
 		"<Branch>",
 		'\0',
 		"",
@@ -849,7 +868,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/FEAR",
+		"/magic guild/SOR/fear",
 		"<Branch>",
 		'\0',
 		"",
@@ -859,7 +878,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/HALLUCINATION",
+		"/magic guild/SOR/hallucination",
 		"<Branch>",
 		'\0',
 		"",
@@ -869,7 +888,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/CHARM",
+		"/magic guild/SOR/charm",
 		"<Branch>",
 		'\0',
 		"",
@@ -879,7 +898,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/NO_LEARN Weaken status",
+		"/magic guild/SOR/no_learn weaken status",
 		"<Item>",
 		'Z',
 		"",
@@ -889,7 +908,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SOR/--",
+		"/magic guild/SOR/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -899,7 +918,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] */
 	{
-		"/Magic Guild/ENC",
+		"/magic guild/ENC",
 		"<Branch>",
 		'E',
 		"",
@@ -909,7 +928,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] ӥƥ */
 	{
-		"/Magic Guild/ENC/Title Strengthen ability",
+		"/magic guild/ENC/title strengthen ability",
 		"<Title>",
 		'\0',
 		"",
@@ -919,7 +938,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/SHARPNESS",
+		"/magic guild/ENC/sharpness",
 		"<Branch>",
 		'\0',
 		"",
@@ -929,7 +948,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/STRENGTH",
+		"/magic guild/ENC/strength",
 		"<Branch>",
 		'\0',
 		"",
@@ -939,7 +958,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/QUICKNESS",
+		"/magic guild/ENC/quickness",
 		"<Branch>",
 		'\0',
 		"",
@@ -949,7 +968,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/BRAINY",
+		"/magic guild/ENC/brainy",
 		"<Branch>",
 		'\0',
 		"",
@@ -959,7 +978,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/WISE",
+		"/magic guild/ENC/wise",
 		"<Branch>",
 		'\0',
 		"",
@@ -969,7 +988,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/ATTRACTIVE",
+		"/magic guild/ENC/attractive",
 		"<Branch>",
 		'\0',
 		"",
@@ -979,7 +998,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/NO_LEARN Strengthen ability",
+		"/magic guild/ENC/no_learn strengthen ability",
 		"<Item>",
 		'Z',
 		"",
@@ -989,7 +1008,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/--",
+		"/magic guild/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -999,7 +1018,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Magic Guild/ENC/Title Strengthen misc",
+		"/magic guild/ENC/title strengthen misc",
 		"<Title>",
 		'\0',
 		"",
@@ -1009,7 +1028,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/POWER_UP_HP",
+		"/magic guild/ENC/power_up_hp",
 		"<Branch>",
 		'\0',
 		"",
@@ -1019,7 +1038,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Magic Guild/ENC/HASTE",
+		"/magic guild/ENC/haste",
 		"<Branch>",
 		'\0',
 		"",
@@ -1029,7 +1048,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/NO_LEARN Strengthen misc",
+		"/magic guild/ENC/no_learn strengthen misc",
 		"<Item>",
 		'Z',
 		"",
@@ -1039,7 +1058,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/--",
+		"/magic guild/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1049,7 +1068,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] ӥƥ */
 	{
-		"/Magic Guild/ENC/Title Weaken ability",
+		"/magic guild/ENC/title weaken ability",
 		"<Title>",
 		'\0',
 		"",
@@ -1059,7 +1078,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/DULLNESS",
+		"/magic guild/ENC/dullness",
 		"<Branch>",
 		'\0',
 		"",
@@ -1069,7 +1088,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/WEAKNESS",
+		"/magic guild/ENC/weakness",
 		"<Branch>",
 		'\0',
 		"",
@@ -1079,7 +1098,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/SLOWNESS",
+		"/magic guild/ENC/slowness",
 		"<Branch>",
 		'\0',
 		"",
@@ -1089,7 +1108,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/BRAINLESS",
+		"/magic guild/ENC/brainless",
 		"<Branch>",
 		'\0',
 		"",
@@ -1099,7 +1118,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/FOOLISH",
+		"/magic guild/ENC/foolish",
 		"<Branch>",
 		'\0',
 		"",
@@ -1109,7 +1128,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/UNATTRACTIVE",
+		"/magic guild/ENC/unattractive",
 		"<Branch>",
 		'\0',
 		"",
@@ -1119,7 +1138,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/NO_LEARN Weaken ability",
+		"/magic guild/ENC/no_learn weaken ability",
 		"<Item>",
 		'Z',
 		"",
@@ -1129,7 +1148,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/--",
+		"/magic guild/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1139,7 +1158,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Magic Guild/ENC/Title Weaken misc",
+		"/magic guild/ENC/title weaken misc",
 		"<Title>",
 		'\0',
 		"",
@@ -1149,7 +1168,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/ENERGY_DRAIN",
+		"/magic guild/ENC/energy_drain",
 		"<Branch>",
 		'\0',
 		"",
@@ -1159,7 +1178,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Magic Guild/ENC/SLOW",
+		"/magic guild/ENC/slow",
 		"<Branch>",
 		'\0',
 		"",
@@ -1169,7 +1188,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/HUNGER",
+		"/magic guild/ENC/hunger",
 		"<Branch>",
 		'\0',
 		"",
@@ -1179,7 +1198,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/CANCELLATION",
+		"/magic guild/ENC/cancellation",
 		"<Branch>",
 		'\0',
 		"",
@@ -1189,7 +1208,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/NO_LEARN Weaken misc",
+		"/magic guild/ENC/no_learn weaken misc",
 		"<Item>",
 		'Z',
 		"",
@@ -1199,7 +1218,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/ENC/--",
+		"/magic guild/ENC/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1209,7 +1228,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ] */
 	{
-		"/Magic Guild/SUM",
+		"/magic guild/SUM",
 		"<Branch>",
 		'U',
 		"",
@@ -1219,7 +1238,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 /* [ˡ]  */
 	{
-		"/Magic Guild/SUM/Title Summon",
+		"/magic guild/SUM/title summon",
 		"<Title>",
 		'\0',
 		"",
@@ -1229,7 +1248,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/SKELETON_WARRIOR",
+		"/magic guild/SUM/skeleton_warrior",
 		"<Branch>",
 		'\0',
 		"",
@@ -1239,17 +1258,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/CREATE_UNDEAD",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_CREATE_UNDEAD, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_CREATE_UNDEAD,
-		FLG_NULL,
-	},
-
-	{
-		"/Magic Guild/SUM/SUMMON_UNICORN",
+		"/magic guild/SUM/summon_unicorn",
 		"<Branch>",
 		'\0',
 		"",
@@ -1259,7 +1268,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/SUMMON_EFREET",
+		"/magic guild/SUM/summon_efreet",
 		"<Branch>",
 		'\0',
 		"",
@@ -1269,7 +1278,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/SUMMON_DJINNI",
+		"/magic guild/SUM/summon_djinni",
 		"<Branch>",
 		'\0',
 		"",
@@ -1279,7 +1288,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/SUMMON_PHOENIX",
+		"/magic guild/SUM/summon_phoenix",
 		"<Branch>",
 		'\0',
 		"",
@@ -1289,7 +1298,27 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/DISMISSAL",
+		"/magic guild/SUM/summon_bone",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_BONE, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_SUMMON_BONE,
+		FLG_NULL,
+	},
+
+	{
+		"/magic guild/SUM/create_undead",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_CREATE_UNDEAD, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_CREATE_UNDEAD,
+		FLG_NULL,
+	},
+
+	{
+		"/magic guild/SUM/dismissal",
 		"<Branch>",
 		'\0',
 		"",
@@ -1299,7 +1328,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/NO_LEARN Summon",
+		"/magic guild/SUM/no_learn summon",
 		"<Item>",
 		'Z',
 		"",
@@ -1309,7 +1338,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/SUM/--",
+		"/magic guild/SUM/--",
 		"<PageSeparator>",
 		'\0',
 		"",
@@ -1323,7 +1352,7 @@ menu_t	ls_menu_magic_guild[] = {
 /* [Ǧ] */
 /*  */
 	{
-		"/Magic Guild/Collect gold",
+		"/magic guild/collect gold",
 		"<Item>",
 		'L',
 		"",
@@ -1333,7 +1362,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/Magic Guild/Divide gold",
+		"/magic guild/divide gold",
 		"<Item>",
 		'V',
 		"",
@@ -1342,6 +1371,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/give gold",
+		"<Item>",
+		'G',
+		"",
+		N_MSG_MENU_SHOP_GIVE_GOLD, "",
+		cb_menu_shop_give_gold, NULL,
+		FLG_NULL,
+	},
+
 	{
 		"",
 		"",
@@ -1357,7 +1396,7 @@ menu_t	ls_menu_order_sel_mbr[1 + 1 + MBR_MAX_N + 1 + 1];
 
 menu_t	ls_menu_bar[] = {
 	{
-		"/Bar",
+		"/bar",
 		"<Branch>",
 		'\0',
 		"",
@@ -1366,7 +1405,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Title",
+		"/bar/title",
 		"<Title>",
 		'\0',
 		"",
@@ -1375,7 +1414,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Order",
+		"/bar/order",
 		"<Branch>",
 		'O',
 		"",
@@ -1384,7 +1423,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Request",
+		"/bar/request",
 		"<Branch>",
 		'R',
 		"",
@@ -1393,7 +1432,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form",
+		"/bar/form",
 		"<Branch>",
 		'V',
 		"",
@@ -1402,7 +1441,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Form",
+		"/bar/form/form",
 		"<Branch>",
 		'V',
 		"",
@@ -1411,7 +1450,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit member",
+		"/bar/form/edit member",
 		"<Branch>",
 		'P',
 		"",
@@ -1420,7 +1459,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit member/Edit member",
+		"/bar/form/edit member/edit member",
 		"<Branch>",
 		'E',
 		"",
@@ -1429,7 +1468,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit member/New member",
+		"/bar/form/edit member/new member",
 		"<OpenWinItem>",
 		'N',
 		"",
@@ -1438,7 +1477,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit member/Remove member",
+		"/bar/form/edit member/remove member",
 		"<Branch>",
 		'R',
 		"",
@@ -1447,7 +1486,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit class",
+		"/bar/form/edit class",
 		"<Branch>",
 		'C',
 		"",
@@ -1456,7 +1495,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit class/Edit class",
+		"/bar/form/edit class/edit class",
 		"<Branch>",
 		'E',
 		"",
@@ -1465,7 +1504,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit class/New class",
+		"/bar/form/edit class/new class",
 		"<OpenWinItem>",
 		'N',
 		"",
@@ -1474,7 +1513,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Form/Edit class/Remove class",
+		"/bar/form/edit class/remove class",
 		"<Branch>",
 		'R',
 		"",
@@ -1483,7 +1522,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Load",
+		"/bar/load",
 		"<OpenWinItem>",
 		'L',
 		"",
@@ -1492,7 +1531,7 @@ menu_t	ls_menu_bar[] = {
 		FLG_NULL,
 	},
 	{
-		"/Bar/Save",
+		"/bar/save",
 		"<OpenWinItem>",
 		'S',
 		"",
@@ -1517,7 +1556,7 @@ menu_t	ls_menu_bar_form[
 
 menu_t	ls_menu_bar_form_sub[] = {
 	{
-		"/Form",
+		"/form",
 		"<Branch>",
 		'\0',
 		"",
@@ -1526,7 +1565,7 @@ menu_t	ls_menu_bar_form_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/Form/Title",
+		"/form/title",
 		"<Title>",
 		'\0',
 		"",
@@ -1535,7 +1574,7 @@ menu_t	ls_menu_bar_form_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/Form/Join",
+		"/form/join",
 		"<Branch>",
 		'J',
 		"",
@@ -1544,7 +1583,7 @@ menu_t	ls_menu_bar_form_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/Form/Not join",
+		"/form/not join",
 		"<Item>",
 		'N',
 		"",
@@ -1553,7 +1592,7 @@ menu_t	ls_menu_bar_form_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/Form/Data",
+		"/form/data",
 		"<OpenWinItem>",
 		'P',
 		"",
@@ -1580,7 +1619,7 @@ menu_t	ls_menu_bar_sel_mbr[
 
 menu_t	ls_menu_bar_edit_mbr_sub[] = {
 	{
-		"/Edit member",
+		"/edit member",
 		"<Branch>",
 		'\0',
 		"",
@@ -1589,7 +1628,7 @@ menu_t	ls_menu_bar_edit_mbr_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit member/Title",
+		"/edit member/title",
 		"<Title>",
 		'\0',
 		"",
@@ -1598,7 +1637,7 @@ menu_t	ls_menu_bar_edit_mbr_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit member/Data",
+		"/edit member/data",
 		"<OpenWinItem>",
 		'P',
 		"",
@@ -1607,7 +1646,7 @@ menu_t	ls_menu_bar_edit_mbr_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/Edit member/Arrange",
+		"/edit member/arrange",
 		"<Item>",
 		'A',
 		"",
@@ -1628,7 +1667,7 @@ menu_t	ls_menu_bar_edit_mbr_sub[] = {
 
 menu_t	ls_menu_bar_sel_edit_class[] = {
 	{
-		"/Select edit class",
+		"/select edit class",
 		"<Branch>",
 		'\0',
 		"",
@@ -1637,7 +1676,7 @@ menu_t	ls_menu_bar_sel_edit_class[] = {
 		FLG_NULL,
 	},
 	{
-		"/Select edit class/Title",
+		"/select edit class/title",
 		"<Title>",
 		'\0',
 		"",
@@ -1646,7 +1685,7 @@ menu_t	ls_menu_bar_sel_edit_class[] = {
 		FLG_NULL,
 	},
 	{
-		"/Select edit class/Edit",
+		"/select edit class/edit",
 		"<OpenWinItem>",
 		'E',
 		"",
@@ -1655,7 +1694,7 @@ menu_t	ls_menu_bar_sel_edit_class[] = {
 		FLG_NULL,
 	},
 	{
-		"/Select edit class/Arrange",
+		"/select edit class/arrange",
 		"<Item>",
 		'A',
 		"",
@@ -1676,7 +1715,7 @@ menu_t	ls_menu_bar_sel_edit_class[] = {
 
 menu_t	ls_menu_inn[] = {
 	{
-		"/Inn",
+		"/inn",
 		"<Branch>",
 		'\0',
 		"",
@@ -1685,7 +1724,7 @@ menu_t	ls_menu_inn[] = {
 		FLG_NULL,
 	},
 	{
-		"/Inn/Title",
+		"/inn/title",
 		"<Title>",
 		'\0',
 		"",
@@ -1694,7 +1733,7 @@ menu_t	ls_menu_inn[] = {
 		FLG_NULL,
 	},
 	{
-		"/Inn/Stay",
+		"/inn/stay",
 		"<Item>",
 		'S',
 		"",
@@ -1703,7 +1742,7 @@ menu_t	ls_menu_inn[] = {
 		FLG_NULL,
 	},
 	{
-		"/Inn/Short Stay",
+		"/inn/short stay",
 		"<Item>",
 		'R',
 		"",
@@ -1712,7 +1751,7 @@ menu_t	ls_menu_inn[] = {
 		FLG_NULL,
 	},
 	{
-		"/Inn/Divide gold",
+		"/inn/divide gold",
 		"<Item>",
 		'V',
 		"",
@@ -1733,7 +1772,7 @@ menu_t	ls_menu_inn[] = {
 
 menu_t	ls_menu_pet_shop[] = {
 	{
-		"/Pet Shop",
+		"/pet shop",
 		"<Branch>",
 		'\0',
 		"",
@@ -1742,7 +1781,7 @@ menu_t	ls_menu_pet_shop[] = {
 		FLG_NULL,
 	},
 	{
-		"/Pet Shop/Title",
+		"/pet shop/title",
 		"<Title>",
 		'\0',
 		"",
@@ -1751,7 +1790,7 @@ menu_t	ls_menu_pet_shop[] = {
 		FLG_NULL,
 	},
 	{
-		"/Pet Shop/Buy",
+		"/pet shop/buy",
 		"<Branch>",
 		'B',
 		"",
@@ -1760,7 +1799,7 @@ menu_t	ls_menu_pet_shop[] = {
 		FLG_NULL,
 	},
 	{
-		"/Pet Shop/Take",
+		"/pet shop/take",
 		"<Branch>",
 		'T',
 		"",
@@ -1769,7 +1808,7 @@ menu_t	ls_menu_pet_shop[] = {
 		FLG_NULL,
 	},
 	{
-		"/Pet Shop/Leave",
+		"/pet shop/leave",
 		"<Branch>",
 		'L',
 		"",
@@ -1778,7 +1817,7 @@ menu_t	ls_menu_pet_shop[] = {
 		FLG_NULL,
 	},
 	{
-		"/Pet Shop/Name",
+		"/pet shop/name",
 		"<Branch>",
 		'N',
 		"",
@@ -1787,7 +1826,7 @@ menu_t	ls_menu_pet_shop[] = {
 		FLG_NULL,
 	},
 	{
-		"/Pet Shop/Remove",
+		"/pet shop/remove",
 		"<Branch>",
 		'R',
 		"",
