@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,53 +25,11 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.75 2004/12/25 06:33:08 bowkenken Exp $
+* $Id: tmenu.c,v 1.86 2006/01/15 15:16:09 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-#include	"town.h"
-#include	"item.h"
-#include	"spell.h"
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-#include	"mnstr.h"
-#include	"pet.h"
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-#include	"curs.h"
-#include	"menu.h"
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-#include	"gfile.h"
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-#include	"dun-prot.h"
-#include	"town-prot.h"
-#include	"item-prot.h"
-#include	"spell-prot.h"
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"pet-prot.h"
-/*#include	"fight-prot.h"*/
-#include	"fx-prot.h"
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-#include	"menu-prot.h"
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-#include	"gfile-prot.h"
-/*#include	"msg-prot.h"*/
+#define	TMENU_C
+#include	"inc.h"
 
 /**/
 
@@ -202,33 +160,33 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 		len = max_l( len, tmp_len );
 	}
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_TEMPLE,
 			get_shop_name( SHOP_N_TEMPLE ),
-			g_sel_mbr->name, g_sel_mbr->gold );
+			g_sel_mbr->name, fmt_gold( g_sel_mbr->gold ) );
 
 	price = get_price_temple_remove_curse( g_sel_mbr );
-	p = srch_menu( *pp, "Remove curse" );
+	p = srch_menu( *pp, "remove curse" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
-			len, MSG( p->n_msg ), price );
+			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_cure_status( g_sel_mbr );
-	p = srch_menu( *pp, "Cure status" );
+	p = srch_menu( *pp, "cure status" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
-			len, MSG( p->n_msg ), price );
+			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_resurrection( g_sel_mbr );
-	p = srch_menu( *pp, "Resurrection" );
+	p = srch_menu( *pp, "resurrection" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
-			len, MSG( p->n_msg ), price );
+			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	return NULL;
 }
@@ -275,7 +233,7 @@ char	*cb_menu_temple_remove_curse( menu_t **pp, menu_t **dflt )
 				g_sel_mbr->name );
 	}
 
-	return "/Temple";
+	return "/temple";
 }
 
 /**/
@@ -308,7 +266,7 @@ char	*cb_menu_temple_cure_status( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
-	if( fx_cure_all_status( g_sel_mbr ) ){
+	if( fx_cure_all_stat( g_sel_mbr ) ){
 		add_chr_gold( chr_pay, -price );
 
 		print_msg( FLG_NULL,
@@ -320,7 +278,7 @@ char	*cb_menu_temple_cure_status( menu_t **pp, menu_t **dflt )
 				g_sel_mbr->name );
 	}
 
-	return "/Temple";
+	return "/temple";
 }
 
 /**/
@@ -370,7 +328,7 @@ char	*cb_menu_temple_resurrection( menu_t **pp, menu_t **dflt )
 	/* ֤ʤƤʧ */
 	add_chr_gold( chr_pay, -price );
 
-	return "/Temple";
+	return "/temple";
 }
 
 /**/
@@ -415,10 +373,10 @@ char	*cb_menu_temple_contribution( menu_t **pp, menu_t **dflt )
 
 	add_chr_gold( chr_pay, -price );
 	print_msg( FLG_NULL, MSG_MENU_CONTRIBUTION,
-			g_sel_mbr->name, price );
+			g_sel_mbr->name, fmt_gold( price ) );
 	contribution( g_sel_mbr, price, spell_price );
 
-	return "/Temple";
+	return "/temple";
 }
 
 /**/
@@ -485,20 +443,20 @@ char	*menu_order_sel_mbr( void )
 	mbr_n = 0;
 	k = 0;
 
-	strncpy( p[k].path, "/Order", MENU_PATH_MAX_LEN );
+	strncpy( p[k].path, "/order", MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( p[k].path, "/Order/--", MENU_PATH_MAX_LEN );
+	strncpy( p[k].path, "/order/--", MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	strncpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_LEN );
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
@@ -519,10 +477,10 @@ char	*menu_order_sel_mbr( void )
 		if( (g_sel_mbr != NULL) && (g_sel_mbr->mbr_n == i) )
 			dflt = &(p[k]);
 
-		sprintf( p[k].path, "/Order/%ld", i );
+		sprintf( p[k].path, "/order/%ld", i );
 		strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-		p[k].key = (char)('A' + i);
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = (char)('A' + i);
+		p[k].short_key[0] = '\0';
 		if( g_mbr_order[i] == NULL )
 			name = MSG_MENU_ORDER_NULL;
 		else
@@ -536,10 +494,10 @@ char	*menu_order_sel_mbr( void )
 		mbr_n++;
 	}
 
-	strncpy( p[k].path, "/Order/Chose", MENU_PATH_MAX_LEN );
+	strncpy( p[k].path, "/order/chose", MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-	p[k].key = 'Z';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = 'Z';
+	p[k].short_key[0] = '\0';
 	strncpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_LEN );
 	p[k].call_back = cb_menu_order_chose;
 	p[k].arg = NULL;
@@ -630,7 +588,7 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 	if( flg_rumor )
 		hear_rumor();
 
-	return "/Order";
+	return "/order";
 }
 
 /**/
@@ -695,10 +653,10 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 	dflt = NULL;
 	k = 0;
 
-	strncpy( ls[k].path, "/Shop", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/shop", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
@@ -723,17 +681,17 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 			continue;
 
 		if( key_n == 0 ){
-			strncpy( ls[k].path, "/Shop/--",
+			strncpy( ls[k].path, "/shop/--",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[k].kind, "<Title>",
 					MENU_KIND_MAX_LEN );
-			ls[k].key = '\0';
-			ls[k].accel_key[0] = '\0';
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
 			sprintf( ls[k].msg,
 					MSG_FMT_MENU_SHOP,
 					get_shop_name( shop_n ),
 					mbr->name, buy_sale,
-					get_chr_gold( mbr ) );
+					fmt_gold( get_chr_gold( mbr ) ) );
 			ls[k].call_back = NULL;
 			ls[k].arg = NULL;
 			ls[k].flg = FLG_NULL;
@@ -752,10 +710,10 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		if( art == g_sel_art )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/Shop/%ld", key_n );
+		sprintf( ls[k].path, "/shop/%ld", key_n );
 		strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-		ls[k].key = (char)('A' + key_n);
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = (char)('A' + key_n);
+		ls[k].short_key[0] = '\0';
 		ls[k].msg[0] = '\0';
 		ls[k].call_back = cb_menu_shop;
 		ls[k].arg = (void *)art;
@@ -772,17 +730,17 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 	}
 
 	if( (ls_art_n != (page * ARTICLE_MAX_N_PER_PAGE)) || page == 0 ){
-		strncpy( ls[k].path, "/Shop/--",
+		strncpy( ls[k].path, "/shop/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( ls[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
-		ls[k].key = '\0';
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = '\0';
+		ls[k].short_key[0] = '\0';
 		sprintf( ls[k].msg,
 				MSG_FMT_MENU_SHOP,
 				get_shop_name( shop_n ),
 				mbr->name, buy_sale,
-				get_chr_gold( mbr ) );
+				fmt_gold( get_chr_gold( mbr ) ) );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -802,8 +760,8 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		sprintf( ls[i].msg,
 				MSG_FMT_ART_NAME,
 				max_len, ls_art[j]->art_name,
-				get_price( g_shop_n, ls_art[j],
-				g_deal_kind ) );
+				fmt_gold( get_price(
+				g_shop_n, ls_art[j], g_deal_kind ) ) );
 		j++;
 	}
 
@@ -820,10 +778,10 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* Data */
 
-	strncpy( ls[*k].path, "/Shop/Data", MENU_PATH_MAX_LEN );
+	strncpy( ls[*k].path, "/shop/data", MENU_PATH_MAX_LEN );
 	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-	ls[*k].key = 'U';
-	ls[*k].accel_key[0] = '\0';
+	ls[*k].accel_key = 'T';
+	ls[*k].short_key[0] = '\0';
 	strncpy( ls[*k].msg, MSG_MENU_SHOP_DATA, MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_shop_data;
 	ls[*k].arg = NULL;
@@ -832,10 +790,10 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* Collect gold */
 
-	strncpy( ls[*k].path, "/Shop/Collect gold", MENU_PATH_MAX_LEN );
+	strncpy( ls[*k].path, "/shop/collect gold", MENU_PATH_MAX_LEN );
 	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-	ls[*k].key = 'V';
-	ls[*k].accel_key[0] = '\0';
+	ls[*k].accel_key = 'U';
+	ls[*k].short_key[0] = '\0';
 	strncpy( ls[*k].msg, MSG_MENU_SHOP_COLLECT_GOLD,
 			MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_shop_collect_gold;
@@ -845,10 +803,10 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* Divide gold */
 
-	strncpy( ls[*k].path, "/Shop/Divide gold", MENU_PATH_MAX_LEN );
+	strncpy( ls[*k].path, "/shop/divide gold", MENU_PATH_MAX_LEN );
 	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-	ls[*k].key = 'W';
-	ls[*k].accel_key[0] = '\0';
+	ls[*k].accel_key = 'V';
+	ls[*k].short_key[0] = '\0';
 	strncpy( ls[*k].msg, MSG_MENU_SHOP_DIVIDE_GOLD,
 			MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_shop_divide_gold;
@@ -856,14 +814,27 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].flg = FLG_NULL;
 	(*k)++;
 
+	/* Give gold */
+
+	strncpy( ls[*k].path, "/shop/give gold", MENU_PATH_MAX_LEN );
+	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	ls[*k].accel_key = 'W';
+	ls[*k].short_key[0] = '\0';
+	strncpy( ls[*k].msg, MSG_MENU_SHOP_GIVE_GOLD,
+			MENU_MSG_MAX_LEN );
+	ls[*k].call_back = cb_menu_shop_give_gold;
+	ls[*k].arg = NULL;
+	ls[*k].flg = FLG_NULL;
+	(*k)++;
+
 	if( !chk_shop_order( g_shop_n ) ){
 		/* Sale equip */
 		if( g_deal_kind != DEAL_KIND_SALE_EQUIP ){
-			strncpy( ls[*k].path, "/Shop/Sale equip",
+			strncpy( ls[*k].path, "/shop/sale equip",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-			ls[*k].key = 'X';
-			ls[*k].accel_key[0] = '\0';
+			ls[*k].accel_key = 'X';
+			ls[*k].short_key[0] = '\0';
 			strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
 					MENU_MSG_MAX_LEN );
 			ls[*k].call_back = cb_menu_shop_sale_equip;
@@ -874,11 +845,11 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 		/* Sale item */
 		if( g_deal_kind != DEAL_KIND_SALE_ITEM ){
-			strncpy( ls[*k].path, "/Shop/Sale item",
+			strncpy( ls[*k].path, "/shop/sale item",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-			ls[*k].key = 'Y';
-			ls[*k].accel_key[0] = '\0';
+			ls[*k].accel_key = 'Y';
+			ls[*k].short_key[0] = '\0';
 			strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
 					MENU_MSG_MAX_LEN );
 			ls[*k].call_back = cb_menu_shop_sale_item;
@@ -889,10 +860,10 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 		/* Buy */
 		if( g_deal_kind != DEAL_KIND_BUY ){
-			strncpy( ls[*k].path, "/Shop/Buy", MENU_PATH_MAX_LEN );
+			strncpy( ls[*k].path, "/shop/buy", MENU_PATH_MAX_LEN );
 			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
-			ls[*k].key = 'Z';
-			ls[*k].accel_key[0] = '\0';
+			ls[*k].accel_key = 'Z';
+			ls[*k].short_key[0] = '\0';
 			strncpy( ls[*k].msg, MSG_MENU_SHOP_BUY,
 					MENU_MSG_MAX_LEN );
 			ls[*k].call_back = cb_menu_shop_buy;
@@ -904,10 +875,10 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* <PageSeparator> */
 
-	strncpy( ls[*k].path, "/Shop/--", MENU_PATH_MAX_LEN );
+	strncpy( ls[*k].path, "/shop/--", MENU_PATH_MAX_LEN );
 	strncpy( ls[*k].kind, "<PageSeparator>", MENU_KIND_MAX_LEN );
-	ls[*k].key = '\0';
-	ls[*k].accel_key[0] = '\0';
+	ls[*k].accel_key = '\0';
+	ls[*k].short_key[0] = '\0';
 	ls[*k].msg[0] = '\0';
 	ls[*k].call_back = NULL;
 	ls[*k].arg = NULL;
@@ -991,6 +962,15 @@ char	*cb_menu_shop_divide_gold( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_shop_give_gold( menu_t **pp, menu_t **dflt )
+{
+	menu_mbr_give_gold( g_sel_mbr );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
 char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 {
 	item_t	*art;
@@ -1000,7 +980,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 	g_sel_art = art;
 
 	if( chk_shop_order( g_shop_n ) )
-		return "/Order";
+		return "/order";
 
 	chk_item_data( g_sel_art );
 
@@ -1030,7 +1010,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 		add_chr_gold( g_sel_mbr, +price );
 	}
 
-	return "/Shop";
+	return "/shop";
 }
 
 /**/
@@ -1078,7 +1058,7 @@ bool_t	menu_shop_buy(
 		return FALSE;
 
 	/* 㤦ǧ */
-	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, FALSE );
+	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, TRUE );
 	switch( ask ){
 	case ASK_YES:
 		break;
@@ -1140,7 +1120,7 @@ bool_t	menu_shop_sale(
 	print_msg( FLG_NULL, MSG_MENU_SALE, item->name );
 
 	/* 뤫ǧ */
-	ask = exec_menu_ask( MSG_TTL_MENU_SALE, ASK_NO, FALSE );
+	ask = exec_menu_ask( MSG_TTL_MENU_SALE, ASK_NO, TRUE );
 	switch( ask ){
 	case ASK_YES:
 		break;
@@ -1477,12 +1457,12 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 	p = ls_menu_bar_form;
 
 	k = 0;
-	strncpy( p[k].path, "/Bar form",
+	strncpy( p[k].path, "/bar form",
 			MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
 	p[k].call_back = cb_menu_bar_form_init;
 	p[k].arg = NULL;
@@ -1493,12 +1473,12 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 
-		strncpy( p[k].path, "/Bar form/--",
+		strncpy( p[k].path, "/bar form/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
-		p[k].key = '\0';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
 		strncpy( p[k].msg, MSG_TTL_MENU_BAR_FORM,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
@@ -1515,11 +1495,11 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 				break;
 			}
 
-			sprintf( p[k].path, "/Bar form/%ld", ls_mbr_n );
+			sprintf( p[k].path, "/bar form/%ld", ls_mbr_n );
 			strncpy( p[k].kind, "<CheckItem>",
 					MENU_KIND_MAX_LEN );
-			p[k].key = (char)('A' + j);
-			p[k].accel_key[0] = '\0';
+			p[k].accel_key = (char)('A' + j);
+			p[k].short_key[0] = '\0';
 			strncpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
 					MENU_MSG_MAX_LEN );
 			p[k].call_back = cb_menu_bar_form_sub;
@@ -1530,12 +1510,12 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 			ls_mbr_n++;
 		}
 
-		strncpy( p[k].path, "/Bar form/--",
+		strncpy( p[k].path, "/bar form/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
-		p[k].key = '\0';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
 		p[k].msg[0] = '\0';
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
@@ -1592,7 +1572,7 @@ char	*cb_menu_bar_form_sub( menu_t **pp, menu_t **dflt )
 	*pp = ls_menu_bar_form_sub;
 	*dflt = NULL;
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	strncpy( p->msg, g_sel_ls_mbr->name, MENU_MSG_MAX_LEN );
@@ -1614,17 +1594,17 @@ char	*cb_menu_bar_form_sub_init( menu_t **pp, menu_t **dflt )
 
 	if( g_sel_ls_mbr->mbr_n == MBR_N_NOT_JOIN ){
 		set_chk_off_menu( ls_menu_bar_form, sub_path );
-		set_flg_menu( *pp, "Not join", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "not join", FLG_MENU_HIDDEN );
 	} else {
 		set_chk_on_menu( ls_menu_bar_form, sub_path );
-		set_flg_menu( *pp, "Join", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "join", FLG_MENU_HIDDEN );
 	}
 
 	for( i = 0; i < MBR_MAX_N; i++ )
 		if( chk_flg( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 	if( i >= MBR_MAX_N )
-		set_flg_menu( *pp, "Join", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "join", FLG_MENU_HIDDEN );
 
 	return NULL;
 }
@@ -1648,12 +1628,12 @@ char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 
 	k = 0;
-	strncpy( p[k].path, "/Join",
+	strncpy( p[k].path, "/join",
 			MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
 	p[k].call_back = cb_menu_bar_join_sub_init;
 	p[k].arg = NULL;
@@ -1662,11 +1642,11 @@ char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt )
 
 	n = 0;
 	for( i = 0; i < MBR_MAX_N; i++ ){
-		sprintf( p[k].path, "/Join/%ld", i );
+		sprintf( p[k].path, "/join/%ld", i );
 		strncpy( p[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
-		p[k].key = (char)('A' + i);
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = (char)('A' + i);
+		p[k].short_key[0] = '\0';
 		sprintf( p[k].msg, "%ld", i + 1 );
 		p[k].call_back = cb_menu_bar_join_sub;
 		p[k].arg = (void *)i;
@@ -1730,7 +1710,7 @@ char	*cb_menu_bar_join_sub( menu_t **pp, menu_t **dflt )
 
 	next_g_sel_ls_mbr();
 
-	return "/Bar/Form/Form";
+	return "/bar/form/form";
 }
 
 /**/
@@ -1749,7 +1729,7 @@ char	*cb_menu_bar_not_join( menu_t **pp, menu_t **dflt )
 
 	next_g_sel_ls_mbr();
 
-	return "/Bar/Form/Form";
+	return "/bar/form/form";
 }
 
 /**/
@@ -1785,12 +1765,12 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 	p = ls_menu_bar_sel_mbr;
 
 	k = 0;
-	strncpy( p[k].path, "/Edit member",
+	strncpy( p[k].path, "/edit member",
 			MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
 	p[k].call_back = cb_menu_bar_edit_mbr_init;
 	p[k].arg = NULL;
@@ -1801,12 +1781,12 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 
-		strncpy( p[k].path, "/Edit member/--",
+		strncpy( p[k].path, "/edit member/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
-		p[k].key = '\0';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
 		strncpy( p[k].msg, MSG_TTL_MENU_BAR_EDIT_MBR,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
@@ -1823,12 +1803,12 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 				break;
 			}
 
-			sprintf( p[k].path, "/Edit member/%ld",
+			sprintf( p[k].path, "/edit member/%ld",
 					ls_mbr_n );
 			strncpy( p[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
-			p[k].key = (char)('A' + j);
-			p[k].accel_key[0] = '\0';
+			p[k].accel_key = (char)('A' + j);
+			p[k].short_key[0] = '\0';
 			strncpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
 					MENU_MSG_MAX_LEN );
 			p[k].call_back = cb_menu_bar_edit_mbr_sub;
@@ -1839,12 +1819,12 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 			ls_mbr_n++;
 		}
 
-		strncpy( p[k].path, "/Edit member/--",
+		strncpy( p[k].path, "/edit member/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
-		p[k].key = '\0';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
 		p[k].msg[0] = '\0';
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
@@ -1895,7 +1875,7 @@ char	*cb_menu_bar_edit_mbr_sub( menu_t **pp, menu_t **dflt )
 	*pp = ls_menu_bar_edit_mbr_sub;
 	*dflt = NULL;
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_BAR_EDIT_MBR_SUB,
@@ -1910,7 +1890,7 @@ char	*cb_menu_bar_data_form( menu_t **pp, menu_t **dflt )
 {
 	menu_town_mbr_data( MBR_DATA_EDIT_KIND_EDIT, TRUE );
 
-	return "/Bar/Form/Form";
+	return "/bar/form/form";
 }
 
 /**/
@@ -1919,7 +1899,7 @@ char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt )
 {
 	menu_town_mbr_data( MBR_DATA_EDIT_KIND_EDIT, TRUE );
 
-	return "/Bar/Form/Edit member/Edit member";
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
@@ -1946,7 +1926,7 @@ char	*cb_menu_bar_arrange( menu_t **pp, menu_t **dflt )
 
 	g_sel_ls_mbr = ls_mbr[0];
 
-	return "/Bar/Form/Edit member/Edit member";
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
@@ -2018,12 +1998,12 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 	p = ls_menu_bar_sel_mbr;
 
 	k = 0;
-	strncpy( p[k].path, "/Bar remove member",
+	strncpy( p[k].path, "/bar remove member",
 			MENU_PATH_MAX_LEN );
 	strncpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
-	p[k].key = '\0';
-	p[k].accel_key[0] = '\0';
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
@@ -2034,12 +2014,12 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 
-		strncpy( p[k].path, "/Bar remove member/--",
+		strncpy( p[k].path, "/bar remove member/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
-		p[k].key = '\0';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
 		strncpy( p[k].msg, MSG_TTL_MENU_BAR_REMOVE_MBR,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
@@ -2056,12 +2036,12 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 				break;
 			}
 
-			sprintf( p[k].path, "/Bar remove member/%ld",
+			sprintf( p[k].path, "/bar remove member/%ld",
 					ls_mbr_n );
 			strncpy( p[k].kind, "<OpenWinItem>",
 					MENU_KIND_MAX_LEN );
-			p[k].key = (char)('A' + j);
-			p[k].accel_key[0] = '\0';
+			p[k].accel_key = (char)('A' + j);
+			p[k].short_key[0] = '\0';
 			strncpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
 					MENU_MSG_MAX_LEN );
 			p[k].call_back = cb_menu_bar_remove_mbr_sub;
@@ -2072,12 +2052,12 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 			ls_mbr_n++;
 		}
 
-		strncpy( p[k].path, "/Bar remove member/--",
+		strncpy( p[k].path, "/bar remove member/--",
 				MENU_PATH_MAX_LEN );
 		strncpy( p[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
-		p[k].key = '\0';
-		p[k].accel_key[0] = '\0';
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
 		p[k].msg[0] = '\0';
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
@@ -2110,7 +2090,8 @@ char	*cb_menu_bar_remove_mbr_sub( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_REMOVE_MBR_NAME, mbr->name );
 	curs_attrset_dflt();
 	print_msg( FLG_NULL, MSG_MENU_REMOVE_MBR_LEV, lev );
-	print_msg( FLG_MSG_MORE, MSG_MENU_REMOVE_MBR_GOLD, mbr->gold );
+	print_msg( FLG_MSG_MORE, MSG_MENU_REMOVE_MBR_GOLD,
+			fmt_gold( mbr->gold ) );
 
 	ask = exec_menu_ask( MSG_TTL_MENU_ASK_REMOVE_MBR, ASK_NO, TRUE );
 	switch( ask ){
@@ -2133,7 +2114,7 @@ char	*cb_menu_bar_remove_mbr_sub( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
-	return "/Bar/Form/Edit member/Remove member";
+	return "/bar/form/edit member/remove member";
 }
 
 /**/
@@ -2272,15 +2253,15 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 
 	while( 1 ){
 		if( n > EDIT_CLASS_MAX_N - 1 )
-			n = EDIT_CLASS_NULL + 1;
+			n = (edit_class_t)(EDIT_CLASS_NULL + 1);
 		if( n < EDIT_CLASS_NULL + 1 )
-			n = EDIT_CLASS_MAX_N - 1;
+			n = (edit_class_t)(EDIT_CLASS_MAX_N - 1);
 
 		draw_edit_class( org, work, prev_n, FALSE, flg_sel_add );
 		draw_edit_class( org, work, n, TRUE, flg_sel_add );
 		prev_n = n;
 
-		switch( get_key( TRUE ) ){
+		switch( get_key( g_flg_clr_key_buf_menu ) ){
 		case CASE_CANCEL:
 			if( exec_menu_ask_edit_class( org, work, flg_new ) )
 				return 0;
@@ -2324,10 +2305,10 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 			flg_sel_add = FALSE;
 			break;
 		case CASE_CRSR_DOWN:
-			n++;
+			n = (edit_class_t)(n + 1);
 			break;
 		case CASE_CRSR_UP:
-			n--;
+			n = (edit_class_t)(n - 1);
 			break;
 		default:
 			break;
@@ -2371,7 +2352,7 @@ char	*cb_menu_bar_remove_class( menu_t **pp, menu_t **dflt )
 rate_t	calc_abl_total( class_t *p )
 {
 	rate_t	sum;
-	abl_kind_t	abl;
+	long	abl;
 
 	sum = 0;
 
@@ -2551,19 +2532,19 @@ char	*menu_inn( void )
 
 	/*  */
 
-	p = srch_menu( ls_menu_inn, "Stay" );
+	p = srch_menu( ls_menu_inn, "stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_INN_STAY,
-			(long)get_price_inn( FALSE ) );
+			fmt_gold( get_price_inn( FALSE ) ) );
 
 	/* ٷ */
 
-	p = srch_menu( ls_menu_inn, "Short Stay" );
+	p = srch_menu( ls_menu_inn, "short stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_MENU_INN_SHORT_STAY,
-			(long)get_price_inn( TRUE ) );
+			fmt_gold( get_price_inn( TRUE ) ) );
 
 	/**/
 
@@ -2620,12 +2601,13 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 
 	ls = *pp;
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_MAGIC_GUILD,
 			get_shop_name( SHOP_N_MAGIC ),
-			g_sel_mbr->name, g_sel_mbr->gold );
+			g_sel_mbr->name,
+			fmt_gold( g_sel_mbr->gold ) );
 
 	key = 'A';
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
@@ -2638,7 +2620,7 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 			key = 'A';
 			continue;
 		}
-		if( ls[i].key == 'Z' ){
+		if( ls[i].accel_key == 'Z' ){
 			if( key == 'A' )
 				ls[i].flg &= ~FLG_MENU_HIDDEN;
 			else
@@ -2650,24 +2632,27 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 
 		/**/
 
-		kind = (spell_kind_t)(ls[i].arg);
+		kind = (spell_kind_t)(long)(ls[i].arg);
 
 		tab = get_spell_tab( kind );
 		if( tab == NULL ){
 			sprintf( ls[i].msg, MSG_FMT_MENU_MAGIC_GUILD,
-					"", 0, 0 );
+					"", 0, fmt_gold( 0 ) );
 		} else {
+			gold_t	gold;
+
+			gold = get_price_spell( kind );
 			sprintf( ls[i].msg, MSG_FMT_MENU_MAGIC_GUILD,
 					tab->name, tab->lev,
-					get_price_spell( kind ) );
+					fmt_gold( gold ) );
 		}
 
 		if( chk_chr_learned_spell( g_sel_mbr, kind ) ){
 			ls[i].flg |= FLG_MENU_HIDDEN;
-			ls[i].key = '\0';
+			ls[i].accel_key = '\0';
 		} else {
 			ls[i].flg &= ~FLG_MENU_HIDDEN;
-			ls[i].key = key;
+			ls[i].accel_key = key;
 			key++;
 		}
 	}
@@ -2721,7 +2706,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
 
-	kind = (spell_kind_t)((*pp)->arg);
+	kind = (spell_kind_t)(long)((*pp)->arg);
 	tab = get_spell_tab( kind );
 	if( tab == NULL )
 		return STR_MENU_ERR;
@@ -2733,7 +2718,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_BUY, tab->name );
 
 	/* 㤦ǧ */
-	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, FALSE );
+	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, TRUE );
 	switch( ask ){
 	case ASK_YES:
 		break;
@@ -2746,7 +2731,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	add_chr_gold( g_sel_mbr, -get_price_spell( kind ) );
 	set_chr_learned_spell( g_sel_mbr, kind, TRUE );
 
-	return "/Magic Guild";
+	return "/magic guild";
 }
 
 /**/
@@ -2765,12 +2750,13 @@ char	*cb_menu_pet_shop_init( menu_t **pp, menu_t **dflt )
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
 
-	p = srch_menu( *pp, "Title" );
+	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
-			g_sel_mbr->name, g_sel_mbr->gold );
+			g_sel_mbr->name,
+			fmt_gold( g_sel_mbr->gold ) );
 
 	return NULL;
 }
@@ -2793,10 +2779,10 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = LS_PET_MAX_N;
 
-	strncpy( ls[k].path, "/Pet Shop Take", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop take", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
@@ -2804,10 +2790,10 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/Pet Shop Take/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop take/title", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_TAKE,
 			get_shop_name( SHOP_N_PET_SHOP ),
@@ -2825,10 +2811,10 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 		if( !chk_can_join_pet( ls_pet[i] ) )
 			continue;
 
-		sprintf( ls[k].path, "/Pet Shop Take/%ld", (long)(i + 1) );
+		sprintf( ls[k].path, "/pet shop take/%ld", (long)(i + 1) );
 		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[k].key = key;
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
 		strncpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_pet_shop_take_sel;
@@ -2841,12 +2827,12 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
 			strncpy( ls[k].path,
-					"/Pet Shop Take/Page Separator",
+					"/pet shop take/page separator",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
-			ls[k].key = '\0';
-			ls[k].accel_key[0] = '\0';
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			ls[k].msg[0] = '\0';
 			ls[k].call_back = NULL;
@@ -2885,7 +2871,7 @@ char	*cb_menu_pet_shop_take_sel( menu_t **pp, menu_t **dflt )
 	join_pet( pet );
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_TAKE_SUCCESS, pet->name );
 
-	return "/Pet Shop";
+	return "/pet shop";
 }
 
 /**/
@@ -2906,10 +2892,10 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = PET_MAX_N;
 
-	strncpy( ls[k].path, "/Pet Shop Leave", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop leave", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
@@ -2917,10 +2903,10 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/Pet Shop Leave/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop leave/title", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_LEAVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
@@ -2938,10 +2924,10 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 		if( !chk_can_not_join_pet( party_pet[i] ) )
 			continue;
 
-		sprintf( ls[k].path, "/Pet Shop Leave/%ld", (long)(i + 1) );
+		sprintf( ls[k].path, "/pet shop leave/%ld", (long)(i + 1) );
 		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[k].key = key;
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
 		strncpy( ls[k].msg, party_pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_pet_shop_leave_sel;
@@ -2954,12 +2940,12 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
 			strncpy( ls[k].path,
-					"/Pet Shop Leave/Page Separator",
+					"/pet shop leave/page separator",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
-			ls[k].key = '\0';
-			ls[k].accel_key[0] = '\0';
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			ls[k].msg[0] = '\0';
 			ls[k].call_back = NULL;
@@ -2997,7 +2983,7 @@ char	*cb_menu_pet_shop_leave_sel( menu_t **pp, menu_t **dflt )
 	not_join_pet( pet );
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_LEAVE_SUCCESS, pet->name );
 
-	return "/Pet Shop";
+	return "/pet shop";
 }
 
 /**/
@@ -3019,10 +3005,10 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = PET_MAX_N;
 
-	strncpy( ls[k].path, "/Pet Shop Name", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop name", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
@@ -3030,10 +3016,10 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/Pet Shop Name/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop name/title", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_NAME,
 			get_shop_name( SHOP_N_PET_SHOP ),
@@ -3054,10 +3040,10 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 		else
 			mnstr_name = ls_pet[i]->mnstr_tab->name;
 
-		sprintf( ls[k].path, "/Pet Shop Name/%ld", (long)(i + 1) );
+		sprintf( ls[k].path, "/pet shop name/%ld", (long)(i + 1) );
 		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[k].key = key;
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
 		sprintf( ls[k].msg, MSG_MENU_PET_SHOP_NAME_LS,
 				ls_pet[i]->name, mnstr_name );
@@ -3071,12 +3057,12 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
 			strncpy( ls[k].path,
-					"/Pet Shop Name/Page Separator",
+					"/pet shop name/page separator",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
-			ls[k].key = '\0';
-			ls[k].accel_key[0] = '\0';
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			ls[k].msg[0] = '\0';
 			ls[k].call_back = NULL;
@@ -3118,7 +3104,7 @@ char	*cb_menu_pet_shop_name_sel( menu_t **pp, menu_t **dflt )
 	}
 	redraw_all();
 
-	return "/Pet Shop";
+	return "/pet shop";
 }
 
 /**/
@@ -3139,10 +3125,10 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = LS_PET_MAX_N;
 
-	strncpy( ls[k].path, "/Pet Shop Remove", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop remove", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
@@ -3150,10 +3136,10 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/Pet Shop Remove/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop remove/title", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_REMOVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
@@ -3169,10 +3155,10 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_pet[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		sprintf( ls[k].path, "/Pet Shop Remove/%ld", (long)(i + 1) );
+		sprintf( ls[k].path, "/pet shop remove/%ld", (long)(i + 1) );
 		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[k].key = key;
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
 		strncpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_pet_shop_remove_sel;
@@ -3185,12 +3171,12 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
 			strncpy( ls[k].path,
-					"/Pet Shop Remove/Page Separator",
+					"/pet shop remove/page separator",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
-			ls[k].key = '\0';
-			ls[k].accel_key[0] = '\0';
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			ls[k].msg[0] = '\0';
 			ls[k].call_back = NULL;
@@ -3247,7 +3233,7 @@ char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt )
 
 	remove_pet( pet );
 
-	return "/Pet Shop";
+	return "/pet shop";
 }
 
 /**/
@@ -3267,10 +3253,10 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	key = 'A';
 	max_n = PET_SHOP_PET_MAX_N;
 
-	strncpy( ls[k].path, "/Pet Shop Buy", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop buy", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
 	ls[k].call_back = NULL;
@@ -3278,14 +3264,15 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/Pet Shop Buy/Title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].path, "/pet shop buy/title", MENU_PATH_MAX_LEN );
 	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	ls[k].key = '\0';
-	ls[k].accel_key[0] = '\0';
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
-			g_sel_mbr->name, g_sel_mbr->gold );
+			g_sel_mbr->name,
+			fmt_gold( g_sel_mbr->gold ) );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -3297,12 +3284,12 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 
 		if( (i != 0) && ((i % PET_SHOP_PET_N_PER_PAGE) == 0) ){
 			strncpy( ls[k].path,
-					"/Pet Shop Buy/Page Separator",
+					"/pet shop buy/page separator",
 					MENU_PATH_MAX_LEN );
 			strncpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
-			ls[k].key = '\0';
-			ls[k].accel_key[0] = '\0';
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
 			ls[k].msg[0] = '\0';
 			ls[k].call_back = NULL;
@@ -3313,14 +3300,14 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 			key = 'A';
 		}
 
-		sprintf( ls[k].path, "/Pet Shop Buy/%ld", (long)(i + 1) );
+		sprintf( ls[k].path, "/pet shop buy/%ld", (long)(i + 1) );
 		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		ls[k].key = key;
-		ls[k].accel_key[0] = '\0';
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
 		sprintf( ls[k].msg, MSG_FMT_MENU_PET_SHOP,
 				get_mnstr_name( art_ls_pet_shop[i].kind ),
-				art_ls_pet_shop[i].price );
+				fmt_gold( art_ls_pet_shop[i].price ) );
 		ls[k].call_back = cb_menu_pet_shop_buy_sel;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -3390,7 +3377,7 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 
 	add_chr_gold( g_sel_mbr, (gold_t)(-price) );
 
-	return "/Pet Shop";
+	return "/pet shop";
 }
 
 /**/
