@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,53 +25,11 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.102 2004/12/08 04:56:17 bowkenken Exp $
+* $Id: town.c,v 1.112 2006/01/15 15:16:09 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-#include	"turn.h"
-/*#include	"dun.h"*/
-#include	"town.h"
-#include	"item.h"
-#include	"spell.h"
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-#include	"mnstr.h"
-#include	"pet.h"
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-#include	"menu.h"
-/*#include	"amenu.h"*/
-#include	"request.h"
-#include	"gfile.h"
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-#include	"turn-prot.h"
-#include	"dun-prot.h"
-#include	"town-prot.h"
-#include	"item-prot.h"
-#include	"spell-prot.h"
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"pet-prot.h"
-/*#include	"fight-prot.h"*/
-#include	"fx-prot.h"
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-#include	"menu-prot.h"
-#include	"tmenu-prot.h"
-/*#include	"amenu-prot.h"*/
-#include	"request-prot.h"
-#include	"gfile-prot.h"
-/*#include	"msg-prot.h"*/
+#define	TOWN_C
+#include	"inc.h"
 
 /**/
 
@@ -220,7 +178,7 @@
 /*  */
 
 #define	DAY_OF_WEEK_DISCOUNT	DAY_OF_WEEK_PHYS
-#define	DISCOUNT_RATE	((rate_t)20)
+#define	DISCOUNT_RATE	((rate_t)10)
 
 #define	DISCOUNT_BEGIN_HOUR	6
 #define	DISCOUNT_OPEN_HOUR	10
@@ -382,8 +340,8 @@ bool_t	set_town_ptn_head( town_ptn_t *ptn, char *s )
 
 bool_t	set_town_ptn_col( town_ptn_t *ptn, char *s )
 {
-	unsigned long	col_code;
-	unsigned char	col_chr, col_chr_dmy;
+	long	col_code;
+	char	col_chr, col_chr_dmy;
 	town_ptn_col_tab_t	*col_tab;
 	long	col_tab_max_n;
 	long	i;
@@ -417,8 +375,8 @@ bool_t	set_town_ptn_col( town_ptn_t *ptn, char *s )
 		return FALSE;
 
 	if( ptn->col_str_len == 1 ){
-		ptn->col_mjr[col_chr] = col_tab[i].mjr;
-		ptn->col_mnr[col_chr] = col_tab[i].mnr;
+		ptn->col_mjr[(unsigned)col_chr] = col_tab[i].mjr;
+		ptn->col_mnr[(unsigned)col_chr] = col_tab[i].mnr;
 	}
 
 	return TRUE;
@@ -521,7 +479,6 @@ bool_t	trans_town_ptn( town_ptn_t *dst, town_ptn_t *src )
 void	make_town( void )
 {
 	long	npc_n, npc_max_n;
-	long	request_n, request_max_n;
 	long	n;
 	long	i;
 
@@ -614,13 +571,7 @@ void	make_town( void )
 
 	/*  */
 
-	request_n = get_request_n();
-	request_max_n = roll_dice( REQUEST_AVE_N, TRUE );
-	for( i = request_n; i < request_max_n; i++ )
-		make_request_randm();
-
-	chk_request_limit();
-	chk_request_contract();
+	make_request_all();
 }
 
 /**/
@@ -1044,6 +995,8 @@ bool_t	make_art_town( shop_n_t shop_n, void *art_ls )
 		break;
 	case ITEM_KIND_RARE_GOODS:
 		return TRUE;
+	case ITEM_KIND_BONE:
+		return TRUE;
 	}
 
 	if( ave_stock == 1 )
@@ -1257,6 +1210,12 @@ bool_t	appear_party_town( void )
 
 	appear_all_pet();
 
+	next_pos_square( 0 );
+	scroll_center_appear_party();
+	set_flg_find_all_mnstr();
+
+	redraw_all();
+
 	return TRUE;
 }
 
@@ -1559,6 +1518,7 @@ bool_t	chk_package_item( item_t *item )
 		return FALSE;
 	case ITEM_KIND_SPIKE:
 	case ITEM_KIND_TOBACCO:
+	case ITEM_KIND_BONE:
 		return TRUE;
 	case ITEM_KIND_PIPE:
 		if( chk_flg( item->tab.pipe->flg, FLG_PIPE_CONSUMPTION ) )
@@ -1701,15 +1661,15 @@ bool_t	set_art_name( mbr_t *mbr, item_t *art, deal_kind_t kind )
 			for( j = 0; j < EQUIP_KIND_MAX_N; j++ ){
 				if( art == &(p[j]) ){
 					set_art_name_equip( pty->mbr[i],
-							art, j );
+							art,
+							(equip_kind_t)j );
 					return TRUE;
 				}
 			}
 		}
 	}
 
-	strcpy( art->art_name, get_str_can_use_item( mbr, art ) );
-	strcat( art->art_name, art->name );
+	strcpy( art->art_name, art->name );
 
 	return TRUE;
 }
@@ -1772,12 +1732,10 @@ bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq )
 	}
 	if( eq_name != NULL ){
 		sprintf( art->art_name, MSG_FMT_ART_NAME_EQUIP,
-				get_str_can_use_item( mbr, art ),
-				get_equip_ttl_max_len(),
-				eq_name, art->name );
+				get_equip_ttl_max_len(), eq_name,
+				art->name );
 	} else {
-		strcpy( art->art_name, get_str_can_use_item( mbr, art ) );
-		strcat( art->art_name, art->name );
+		strcpy( art->art_name, art->name );
 	}
 
 	return TRUE;
@@ -1796,7 +1754,7 @@ bool_t	chk_pay( mbr_t *mbr, gold_t price )
 
 	if( gold < price ){
 		print_msg( FLG_MSG_ERR, MSG_ERR_MENU_WANTING,
-				mbr->name, price - gold );
+				mbr->name, fmt_gold( price - gold ) );
 		return FALSE;
 	}
 
@@ -1873,6 +1831,9 @@ gold_t	get_price( shop_n_t shop_n, item_t *item, deal_kind_t deal_kind )
 	case ITEM_KIND_RARE_GOODS:
 		price = (gold_t)0;
 		break;
+	case ITEM_KIND_BONE:
+		price = (gold_t)0;
+		break;
 	case ITEM_KIND_COIN:
 		price = (gold_t)1;
 		break;
@@ -2804,7 +2765,7 @@ void	set_discount()
 {
 	door_t	*dr;
 
-	g_discount_queue.shop_n = randm( SHOP_N_MAX_N );
+	g_discount_queue.shop_n = (shop_n_t)randm( SHOP_N_MAX_N );
 	g_discount_queue.flg_sold_out = FALSE;
 
 	dr = get_shop_door( g_discount_queue.shop_n );
