@@ -7,11 +7,12 @@ extern "C" {
 void	init_trap( void );
 void	reset_trap( void );
 trap_t	*make_trap( long x, long y, long dun_lev );
-bool_t	make_trap_std( long dun_lev, trap_t *trap, long n );
+trap_t	*make_trap_std( trap_kind_t kind, long x, long y, long dun_lev );
+bool_t	make_trap_alloc( long dun_lev, trap_t *trap, long tab_n );
 bool_t	set_trap( long x, long y, trap_t *trap );
 bool_t	set_trap_face_mnr( trap_t *trap );
-void	make_trap_room( long area_x, long area_y, long lev );
-void	chk_trap_chest( item_t *item, chr_t *chr, rate_t rate );
+void	make_trap_room( long area_x, long area_y, long dun_lev );
+void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate );
 void	chk_trap( chr_t *chr, chr_t *thief );
 void	find_trap( trap_t *trap );
 void	caught_trap( trap_t *trap, chr_t *chr );
@@ -20,6 +21,8 @@ void	caught_trap_pit( chr_t *chr );
 void	caught_trap_chute( chr_t *chr );
 void	disarm_trap( trap_t *p );
 void	detect_trap( long x, long y, long r );
+bool_t	chk_through_trap( long x, long y );
+bool_t	chk_map_sanctuary( long x, long y );
 void	ins_ls_trap( trap_t *ls, trap_t *p );
 trap_t	*alloc_trap( void );
 void	free_trap_chest( item_t *chest );
@@ -28,6 +31,7 @@ trap_t	*get_trap_free_next( void );
 trap_t	*get_dun_trap_asgn( void );
 trap_t	*get_trap( long x, long y );
 trap_tab_t	*get_trap_tab( trap_kind_t kind );
+long	get_trap_tab_n( trap_kind_t kind );
 
 #ifdef __cplusplus
 }
