@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,117 +25,125 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.45 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: trap.c,v 1.51 2006/01/15 15:16:09 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-#include	"dun.h"
-/*#include	"town.h"*/
-#include	"item.h"
-#include	"spell.h"
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-#include	"pet.h"
-#include	"fight.h"
-#include	"fx.h"
-#include	"trap.h"
-#include	"draw.h"
-/*#include	"curs.h"*/
-#include	"menu.h"
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-#include	"dun-prot.h"
-/*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
-#include	"spell-prot.h"
-#include	"chr-prot.h"
-/*#include	"party-prot.h"*/
-/*#include	"mnstr-prot.h"*/
-#include	"pet-prot.h"
-#include	"fight-prot.h"
-#include	"fx-prot.h"
-#include	"trap-prot.h"
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-#include	"menu-prot.h"
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* 
+***************************************************************/
 
-/**/
+#define	TRAP_C
+#include	"inc.h"
 
+/***************************************************************/
+
+/*  */
 #define	TRAP_DIFFICULTY_LEV_RATE	RATE_LEV_PER_DUN_LEV
 #define	TRAP_DIFFICULTY_LEV_ADD	1
 
-#define	TRAP_MAX_RATE	100
-#define	TRAP_MIN_RATE	50
-
-#define	TRAP_ROOM_RATE	1
+/* ˻ųݤƤΨ */
+#define	TRAP_ROOM_RATE	((rate_t)1)
+/* ˻ųݤƤ */
 #define	TRAP_ROOM_N	50
 
-#define	PIT_DAM_RATE	25
+/* Υ᡼( HP  %) */
+#define	PIT_DAM_RATE	((rate_t)25)
 #define	PIT_DAM_ADD	1
 
-/**/
+/***************************************************************
+* Хѿ
+***************************************************************/
 
+/* ס */
 static trap_t	trap_buf[TRAP_MAX_N];
+/* ե꡼Υإå */
 static trap_t	trap_free;
+/* µܤγƥΥإå */
 static trap_t	dun_trap_asgn;
 
+/* ǡơ֥κ */
 static long	trap_tab_max_n;
 
+/* ǡơ֥ */
 static trap_tab_t	trap_tab[] = {
-	{ TRAP_KIND_SLEEP, NULL, N_MSG_TRAP_SLEEP,
+	{
+		TRAP_KIND_SLEEP,
+		N_MSG_TRAP_SLEEP, NULL,
 		100, FACE_MNR_TRAP_SLEEP,
-		1, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_ARW, NULL, N_MSG_TRAP_ARW,
+		1, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_ARW,
+		N_MSG_TRAP_ARW, NULL,
 		100, FACE_MNR_TRAP_ARW,
-		2, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_POISON_DARTS, NULL, N_MSG_TRAP_POISON_DARTS,
+		2, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_POISON_DARTS,
+		N_MSG_TRAP_POISON_DARTS, NULL,
 		100, FACE_MNR_TRAP_POISON_DARTS,
-		3, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_BOMB, NULL, N_MSG_TRAP_BOMB,
+		3, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_BOMB,
+		N_MSG_TRAP_BOMB, NULL,
 		100, FACE_MNR_TRAP_BOMB,
-		10, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_TELEPORT_PARTY, NULL, N_MSG_TRAP_TELEPORT_PARTY,
+		10, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_TELEPORT_PARTY,
+		N_MSG_TRAP_TELEPORT_PARTY, NULL,
 		100, FACE_MNR_TRAP_TELEPORT_PARTY,
-		20, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_TELEPORT, NULL, N_MSG_TRAP_TELEPORT,
+		20, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_TELEPORT,
+		N_MSG_TRAP_TELEPORT, NULL,
 		100, FACE_MNR_TRAP_TELEPORT,
-		30, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_PIT, NULL, N_MSG_TRAP_PIT,
+		30, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_PIT,
+		N_MSG_TRAP_PIT, NULL,
 		100, FACE_MNR_TRAP_PIT,
-		4, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_CHUTE, NULL, N_MSG_TRAP_CHUTE,
+		4, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_CHUTE,
+		N_MSG_TRAP_CHUTE, NULL,
 		80, FACE_MNR_TRAP_CHUTE,
-		10, DUN_MAX_LEV_BASE, -1 },
-
-	{ TRAP_KIND_NULL, NULL, N_MSG_NULL,
+		10, DUN_MAX_LEV_BASE, -1,
+		TRUE,
+	},
+	{
+		TRAP_KIND_SANCTUARY,
+		N_MSG_TRAP_SANCTUARY, NULL,
+		0, FACE_MNR_TRAP_SANCTUARY,
+		DUN_MAX_LEV_BASE, DUN_MAX_LEV_BASE, 0,
+		FALSE,
+	},
+	{
+		TRAP_KIND_NULL,
+		N_MSG_NULL, NULL,
 		0, FACE_MNR_NULL,
-		DUN_MAX_LEV_BASE, DUN_MAX_LEV_BASE, 0 },
+		DUN_MAX_LEV_BASE, DUN_MAX_LEV_BASE, 0,
+		TRUE,
+	},
 };
 
+/* 櫤ˡȯưΥߡΥ饯 */
 chr_t	g_dmy_chr;
 
-/**/
+/***************************************************************
+* 櫤ν
+***************************************************************/
 
 void	init_trap( void )
 {
@@ -165,7 +173,9 @@ void	init_trap( void )
 	trap_free.prev = &(trap_buf[i]);
 }
 
-/**/
+/***************************************************************
+* ޥå׾櫤ƥꥻåȤ
+***************************************************************/
 
 void	reset_trap( void )
 {
@@ -176,7 +186,13 @@ void	reset_trap( void )
 		free_trap( p->prev );
 }
 
-/**/
+/***************************************************************
+* 櫤Ϥ
+* long x : X ɸ
+* long y : Y ɸ
+* long dun_lev : µܥ٥
+* return : Ϥä
+***************************************************************/
 
 trap_t	*make_trap( long x, long y, long dun_lev )
 {
@@ -226,30 +242,72 @@ trap_t	*make_trap( long x, long y, long dun_lev )
 		return NULL;
 
 	do {
-		if( !make_trap_std( dun_lev, trap, n ) )
+		if( !make_trap_alloc( dun_lev, trap, n ) )
 			break;
 		if( clip_pos( x, y ) )
 			if( !set_trap( x, y, trap ) )
 				break;
 
+		/*  */
+
 		return trap;
 	} while( 0 );
 
+	/*  */
+
 	free_trap( trap );
 
 	return NULL;
 }
 
-/**/
+trap_t	*make_trap_std( trap_kind_t kind, long x, long y, long dun_lev )
+{
+	long	tab_n;
+	trap_t	*trap;
 
-bool_t	make_trap_std( long dun_lev, trap_t *trap, long n )
+	tab_n = get_trap_tab_n( kind );
+	if( tab_n <= -1 )
+		return NULL;
+
+	trap = alloc_trap();
+	if( trap == NULL )
+		return NULL;
+
+	do {
+		if( !make_trap_alloc( dun_lev, trap, tab_n ) )
+			break;
+		if( clip_pos( x, y ) )
+			if( !set_trap( x, y, trap ) )
+				break;
+
+		/*  */
+
+		return trap;
+	} while( 0 );
+
+	/*  */
+
+	free_trap( trap );
+
+	return NULL;
+}
+
+/***************************************************************
+* ɸŪ櫤Ϥ
+* long dun_lev : µܥ٥
+* trap_t *trap : 
+* long tab_n : ǡơ֥Υǥå
+* return : ?
+***************************************************************/
+
+bool_t	make_trap_alloc( long dun_lev, trap_t *trap, long tab_n )
 {
 	long	difficulty;
 
 	if( trap == NULL )
 		return FALSE;
 
-	trap->kind = trap_tab[n].kind;
+	trap->kind = trap_tab[tab_n].kind;
 	trap->x = MAP_DEL_X;
 	trap->y = MAP_DEL_Y;
 	trap->lev = dun_lev;
@@ -261,12 +319,18 @@ bool_t	make_trap_std( long dun_lev, trap_t *trap, long n )
 	trap->difficulty = difficulty;
 
 	trap->flg_chked = FALSE;
-	trap->tab = get_trap_tab( trap_tab[n].kind );
+	trap->tab = get_trap_tab( trap_tab[tab_n].kind );
 
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 櫤ųݤ
+* long x : X ɸ
+* long y : Y ɸ
+* trap_t *trap : 
+* return : ?
+***************************************************************/
 
 bool_t	set_trap( long x, long y, trap_t *trap )
 {
@@ -295,7 +359,11 @@ bool_t	set_trap( long x, long y, trap_t *trap )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* 櫤Υޥʡδʸ
+* trap_t *trap : 
+* return : ?
+***************************************************************/
 
 bool_t	set_trap_face_mnr( trap_t *trap )
 {
@@ -328,9 +396,14 @@ bool_t	set_trap_face_mnr( trap_t *trap )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ʣ櫤Ϥ
+* long area_x : X ꥢɸ
+* long area_y : Y ꥢɸ
+* long dun_lev : µܥ٥
+***************************************************************/
 
-void	make_trap_room( long area_x, long area_y, long lev )
+void	make_trap_room( long area_x, long area_y, long dun_lev )
 {
 	dun_t	*dun = get_dun();
 	long	n;
@@ -350,7 +423,7 @@ void	make_trap_room( long area_x, long area_y, long lev )
 		if( dun->map.obj.mjr[my][mx] != FACE_MJR_FLOOR )
 			continue;
 
-		trap = make_trap( mx, my, lev );
+		trap = make_trap( mx, my, dun_lev );
 		if( trap != NULL )
 			n++;
 		if( n >= TRAP_ROOM_N )
@@ -358,28 +431,37 @@ void	make_trap_room( long area_x, long area_y, long lev )
 	}
 }
 
-/**/
+/***************************************************************
+* Ȣ櫤Ĵ٤
+* item_t *chest : Ȣ
+* chr_t *chr : Ĵ٤륭饯
+* rate_t rate : 櫤ȯưΨ
+***************************************************************/
 
-void	chk_trap_chest( item_t *item, chr_t *chr, rate_t rate )
+void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate )
 {
 	if( chr == NULL )
 		return;
 	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return;
-	if( item == NULL )
+	if( chest == NULL )
 		return;
-	if( item->kind != ITEM_KIND_CHEST )
+	if( chest->kind != ITEM_KIND_CHEST )
 		return;
 
 	if( !rate_randm( rate ) )
 		return;
 
-	caught_trap( item->dat.chest.trap, chr );
+	caught_trap( chest->dat.chest.trap, chr );
 
-	free_trap_chest( item );
+	free_trap_chest( chest );
 }
 
-/**/
+/***************************************************************
+* 櫤Ĵ٤
+* chr_t *chr : Ĵ٤륭饯
+* chr_t *thief : Ĵ٤Τ򥵥ݡȤ륭饯
+***************************************************************/
 
 void	chk_trap( chr_t *chr, chr_t *thief )
 {
@@ -422,7 +504,10 @@ void	chk_trap( chr_t *chr, chr_t *thief )
 		caught_trap( trap, chr );
 }
 
-/**/
+/***************************************************************
+* 櫤ȯ
+* trap_t *trap : 
+***************************************************************/
 
 void	find_trap( trap_t *trap )
 {
@@ -439,7 +524,11 @@ void	find_trap( trap_t *trap )
 	draw_trap( trap );
 }
 
-/**/
+/***************************************************************
+* 櫤ȯư
+* trap_t *trap : 
+* chr_t *chr : 櫤ȯư饯
+***************************************************************/
 
 void	caught_trap( trap_t *trap, chr_t *chr )
 {
@@ -459,8 +548,10 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 			find_trap( trap );
 	}
 
-	print_msg_mbr( chr, FLG_NULL, MSG_TRAPPED,
-			chr->name, trap->tab->name );
+	if( trap->tab->flg_draw_msg ){
+		print_msg_mbr( chr, FLG_NULL, MSG_TRAPPED,
+				chr->name, trap->tab->name );
+	}
 
 	g_dmy_chr.kind = CHR_KIND_NULL;
 	strncpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_LEN );
@@ -510,10 +601,17 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	case TRAP_KIND_CHUTE:
 		caught_trap_chute( chr );
 		break;
+	case TRAP_KIND_SANCTUARY:
+		break;
 	}
 }
 
-/**/
+/***************************************************************
+* 櫤ȯͤɤκɸ
+* chr_t *chr : 櫤ȯư饯
+* long *x : X ɸ֤
+* long *y : Y ɸ֤
+***************************************************************/
 
 void	set_trap_arw_pos( chr_t *chr, long *x, long *y )
 {
@@ -566,7 +664,10 @@ void	set_trap_arw_pos( chr_t *chr, long *x, long *y )
 	}
 }
 
-/**/
+/***************************************************************
+* 櫤ȯư
+* chr_t *chr : 櫤ȯư饯
+***************************************************************/
 
 void	caught_trap_pit( chr_t *chr )
 {
@@ -578,7 +679,10 @@ void	caught_trap_pit( chr_t *chr )
 	add_hp( chr, -dam, TRUE, FALSE );
 }
 
-/**/
+/***************************************************************
+* 塼Ȥ櫤ȯư
+* chr_t *chr : 櫤ȯư饯
+***************************************************************/
 
 void	caught_trap_chute( chr_t *chr )
 {
@@ -598,7 +702,10 @@ void	caught_trap_chute( chr_t *chr )
 		up_dun( -1 );
 }
 
-/**/
+/***************************************************************
+* 櫤
+* trap_t *trap : 
+***************************************************************/
 
 void	disarm_trap( trap_t *p )
 {
@@ -616,7 +723,12 @@ void	disarm_trap( trap_t *p )
 	free_trap( p );
 }
 
-/**/
+/***************************************************************
+* ϰ櫤ȯ
+* long x : X ɸ
+* long y : Y ɸ
+* long r : Ⱦ
+***************************************************************/
 
 void	detect_trap( long x, long y, long r )
 {
@@ -636,7 +748,49 @@ void	detect_trap( long x, long y, long r )
 	}
 }
 
-/**/
+/***************************************************************
+* ޥåפλɸ櫤̤ȴǽĴ٤
+* long x : X ɸ
+* long y : Y ɸ
+* return : ̤ȴǽ?
+***************************************************************/
+
+bool_t	chk_through_trap( long x, long y )
+{
+	dun_t	*dun = get_dun();
+
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_TRAP )
+		return TRUE;
+	if( dun->map.obj.mnr[y][x] == FACE_MNR_TRAP_SANCTUARY )
+		return TRUE;
+
+	return FALSE;
+}
+
+/***************************************************************
+* ޥåפλɸ褬ͭ뤫Ĵ٤
+* long x : X ɸ
+* long y : Y ɸ
+* return : 褬ͭ뤫?
+***************************************************************/
+
+bool_t	chk_map_sanctuary( long x, long y )
+{
+	dun_t	*dun = get_dun();
+
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_TRAP )
+		return FALSE;
+	if( dun->map.obj.mnr[y][x] != FACE_MNR_TRAP_SANCTUARY )
+		return FALSE;
+
+	return TRUE;
+}
+
+/***************************************************************
+* 櫤ꥹȤ˥󥯤
+* trap_t *ls : 櫤Υꥹ
+* trap_t *p : 󥯤
+***************************************************************/
 
 void	ins_ls_trap( trap_t *ls, trap_t *p )
 {
@@ -658,7 +812,10 @@ void	ins_ls_trap( trap_t *ls, trap_t *p )
 	ls->prev = p;
 }
 
-/**/
+/***************************************************************
+* 櫤Ƥ
+* return : Ƥ
+***************************************************************/
 
 trap_t	*alloc_trap( void )
 {
@@ -668,7 +825,7 @@ trap_t	*alloc_trap( void )
 	if( p == NULL )
 		return NULL;
 
-	p->kind = ITEM_KIND_NULL;
+	p->kind = TRAP_KIND_NULL;
 	p->x = MAP_DEL_X;
 	p->y = MAP_DEL_Y;
 
@@ -685,7 +842,10 @@ trap_t	*alloc_trap( void )
 	return p;
 }
 
-/**/
+/***************************************************************
+* Ȣ櫤γƤ
+* item_t *chest : Ȣ
+***************************************************************/
 
 void	free_trap_chest( item_t *chest )
 {
@@ -698,7 +858,10 @@ void	free_trap_chest( item_t *chest )
 	chest->dat.chest.trap = NULL;
 }
 
-/**/
+/***************************************************************
+* 櫤γƤ
+* trap_t *p : 
+***************************************************************/
 
 void	free_trap( trap_t *p )
 {
@@ -711,7 +874,10 @@ void	free_trap( trap_t *p )
 	ins_ls_trap( ls, p );
 }
 
-/**/
+/***************************************************************
+* 櫤Υե꡼κǽǤ֤
+* return : 
+***************************************************************/
 
 trap_t	*get_trap_free_next( void )
 {
@@ -721,14 +887,22 @@ trap_t	*get_trap_free_next( void )
 	return trap_free.next;
 }
 
-/**/
+/***************************************************************
+* µܤγƥΥإå֤
+* return : إå
+***************************************************************/
 
 trap_t	*get_dun_trap_asgn( void )
 {
 	return &dun_trap_asgn;
 }
 
-/**/
+/***************************************************************
+* ɸ櫤򸡺
+* long x : X ɸ
+* long y : Y ɸ
+* return : 
+***************************************************************/
 
 trap_t	*get_trap( long x, long y )
 {
@@ -741,18 +915,37 @@ trap_t	*get_trap( long x, long y )
 	return NULL;
 }
 
-/**/
+/***************************************************************
+* 櫤Υǡơ֥򸡺
+* trap_kind_t kind : 櫤μ
+* return : ǡơ֥
+***************************************************************/
 
 trap_tab_t	*get_trap_tab( trap_kind_t kind )
+{
+	long	n;
+
+	n = get_trap_tab_n( kind );
+	if( n <= -1 )
+		return NULL;
+
+	return( &(trap_tab[n]) );
+}
+
+/***************************************************************
+* 櫤Υǡơ֥Υǥå򸡺
+* trap_kind_t kind : 櫤μ
+* return : ǡơ֥Υǥå
+***************************************************************/
+
+long	get_trap_tab_n( trap_kind_t kind )
 {
 	long	i;
 
 	for( i = 0; i < LOOP_MAX_1000; i++ )
 		if( trap_tab[i].kind == kind )
-			return( &(trap_tab[i]) );
+			return i;
 
-	return NULL;
+	return -1;
 }
 
-/**/
-
